--///////////////////////////////////////////////////////////////////////////////////////////////////

-------------   Copyright (C) 2020 Digital Twins Inc.  ----------------------
--
--
-- Modification History:
-- ------------------------------------------------------------------
-- Version  Author            Date           Description
-- ------------------------------------------------------------------

LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

---------- ENTITY DECLARATION ----------
ENTITY friction_rotational_v_02_a IS

       PORT (
				QUANTITY CTL: real   := 1.0;	--Load Equation Control CTL=1 Physical Equation
              QUANTITY M_SLIP: TORQUE   := 0.01;	--friction during slip mode [Nm]
              TERMINAL rot1: ROTATIONAL_V
       );

END ENTITY friction_rotational_v_02_a;
---------- ARCHITECTURE DECLARATION ----------
ARCHITECTURE behav OF friction_rotational_v_02_a IS

	QUANTITY omega ACROSS m THROUGH rot1 TO ROTATIONAL_V_REF;
BEGIN

if CTL > 0.0 use

	if (abs(omega)>1.0e-3) use
	    m == M_SLIP;
	ELSE
           m == 0.0;
	END USE;
else
	m==0.0;
end use;

END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Torque Sensor                                            --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY fm_rot IS
  PORT(
    QUANTITY torque : OUT TORQUE;
    TERMINAL rot1, rot2 : ROTATIONAL_V);
END ENTITY fm_rot;
ARCHITECTURE behav OF fm_rot IS
  QUANTITY omega_zero ACROSS m_val THROUGH rot1 TO rot2;
BEGIN
  m_val == torque;
  omega_zero == 0.0;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Angular Velocity Sensor                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY vm_rot IS
  PORT(
    QUANTITY omega: OUT ANGULAR_VELOCITY; 
    TERMINAL rot1: ROTATIONAL_V);
END ENTITY vm_rot;
ARCHITECTURE behav OF vm_rot IS
  QUANTITY omega_val ACROSS rot1 TO rotational_v_ref;
  QUANTITY phi: ANGLE;
BEGIN
  omega_val == omega;
  omega == phi'dot;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Negator                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY NEG IS
    GENERIC(TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY NEG;
ARCHITECTURE behav OF NEG IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
	temp_val == -INPUT;
	VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Summation                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY SUM IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY SUM;
ARCHITECTURE behav OF SUM IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT0 + INPUT1;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Gain                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY GAIN IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY KP : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL);
END ENTITY GAIN;
ARCHITECTURE behav OF GAIN IS
BEGIN
	VAL == KP*INPUT'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Limiter                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY LMT IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY UL : IN REAL := 0.0;
          QUANTITY LL : IN REAL := 0.0;
          QUANTITY VAL : OUT REAL);
END ENTITY LMT;
ARCHITECTURE behav OF LMT IS
  QUANTITY temp_val : REAL := 0.0;
  SIGNAL lower_crossing : BOOLEAN := FALSE;
  SIGNAL upper_crossing : BOOLEAN := FALSE;
BEGIN
    ASSERT (UL >= LL) REPORT "Upper Limit should be greater than Lower limit" SEVERITY error;

    lower_crossing <= NOT INPUT'ABOVE(LL);
    upper_crossing <= INPUT'ABOVE(UL);
    BREAK ON lower_crossing;
    BREAK ON upper_crossing;

    IF ((lower_crossing) AND (INPUT < LL)) USE
        temp_val == LL;
    ELSIF ((upper_crossing) AND (INPUT > UL)) USE
        temp_val == UL;
    ELSE
        temp_val == INPUT;
    END USE;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Damper                                                   --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY damp_rot IS
  PORT(
    QUANTITY damping : IN ANGULAR_DAMPING := 1.0;
    TERMINAL rot1, rot2 : ROTATIONAL_V);
END ENTITY damp_rot;
ARCHITECTURE beha OF damp_rot IS
  QUANTITY omega ACROSS m THROUGH rot1 TO rot2;
  QUANTITY phi : ANGLE;
BEGIN
  m == damping*omega;
  omega == phi'dot;
END ARCHITECTURE beha;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY BK_PNT1 IS
	PORT (
		TERMINAL rot_df : ROTATIONAL_V;
		TERMINAL rot_tire : ROTATIONAL_V;
		QUANTITY bk_trq_brake : IN REAL := 0.0;
		QUANTITY CTL : IN REAL := 0.0;
		QUANTITY bk_trq_Hikizuri_brake : IN REAL := 0.0 
	);
BEGIN 
END ENTITY BK_PNT1;

ARCHITECTURE struct OF BK_PNT1 IS
	TERMINAL net_15 : ROTATIONAL_V;
	TERMINAL n0020 : ROTATIONAL_V;
	TERMINAL n0032 : ROTATIONAL_V;
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
BEGIN
	friction_rotational_v_02_a1 : ENTITY WORK.friction_rotational_v_02_a(behav)
		PORT MAP ( rot1 => N0020, m_slip => bk_trq_Hikizuri_brake , ctl => CTL );

	fm_rot1 : ENTITY WORK.fm_rot(behav)
		PORT MAP ( rot2 => N0032, rot1 => rot_df, torque => Q_10 );

	fm_rot2 : ENTITY WORK.fm_rot(behav)
		PORT MAP ( rot2 => rot_tire, rot1 => N0032, torque => Q_9 );

	fm_rot3 : ENTITY WORK.fm_rot(behav)
		PORT MAP ( rot2 => N0020, rot1 => N0032, torque => Q_8 );

	vm_rot1 : ENTITY WORK.vm_rot(behav)
		PORT MAP ( rot1 => rot_df, omega => Q_7 );

	fm_rot4 : ENTITY WORK.fm_rot(behav)
		PORT MAP ( rot2 => net_15, rot1 => rot_df, torque => Q_6 );

	neg3 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , input => Q_6 );

	sum2 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , input1 => Q_5 , input0 => bk_trq_brake );

	gain2 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , kp => 10.0 , input => Q_4 );

	lmt5 : ENTITY WORK.lmt(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , ll => 0.0 , ul => 100000.0 , input => Q_3 );

	damp_rot3 : ENTITY WORK.damp_rot(beha)
		PORT MAP ( rot2 => rotational_velocity_ref, rot1 => net_15, damping => Q_2 );
END ARCHITECTURE struct;
----------------------------------------------------------------------
