--///////////////////////////////////////////////////////////////////////////////////////////////////

-- ----------------------------------------------------------------------------
-- Copyright (C) 2004-2011 VDA/FAT
--
-- This model is a component of the open source library created by the VDA/FAT 
-- working group number 30 and is covered by this license agreement. This model
-- including any updates, modifications, revisions, copies, and documentation
-- are copyrighted works of the VDA/FAT. Use of this model indicates your
-- complete and unconditional acceptance of the terms and conditions set forth
-- in this license agreement.
--  
-- The VDA/FAT grants a non-exclusive license to use, reproduce, modify and
-- distribute this model under the condition, that:
-- (a) no fee or other consideration is charged for any distribution except 
--     compilations distributed in accordance with Section (d) of this license 
--     agreement;
-- (b) the comment text embedded in this model is included verbatim in each
--     copy of this model made or distributed by you, whether or not such
--     version is modified;
-- (c) any modified version must include a conspicuous notice that this model
--     has been modified and the date of modification; and
-- (d) any compilations sold by you that include this model must include a 
--     conspicuous notice that this model is available from the VDA/FAT in 
--     its original form at no charge.
--
-- THIS MODEL IS LICENSED TO YOU "AS IT IS" AND WITH NO WARRANTIES, EXPRESSED
-- OR IMPLIED. THE VDA/FAT AND ALL COMPANIES CONTRIBUTING TO THIS LIBRARY
-- SPECIFICALLY DISCLAIM ALL IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
-- FOR A PARTICULAR PURPOSE. THE VDA/FAT AND ALL COMPANIES ORGANIZED WITHIN
-- MUST NOT HAVE ANY RESPONSIBILITY FOR ANY DAMAGES, FINANCIAL OR LEGAL CLAIMS 
-- WHATEVER.
-- ----------------------------------------------------------------------------
-- Literature:
--
--  
-- Dependencies: 
-- --------------------------------------------------------------------
-- Logical Library         Design unit
-- --------------------------------------------------------------------
-- IEEE                    ELECTRICAL_SYSTEMS
--
-- Author(s):
-- Joachim Haase 
--
-- Validator:
-- 
--
-- Source:
-- voltage2q_sensor_vda.vhd
--
-- Development simulator:
-- SystemVision Professional 
--
-- Tested on: 
-- ------------------------------------------------------------------
-- Version  Simulator      Version   OS    Validator      Date
-- ------------------------------------------------------------------
-- 1.1      
--
--
-- Modification History:
-- ------------------------------------------------------------------
-- Version  Author            Date           Description
-- ------------------------------------------------------------------
--  1.1    J. Haase           2005/02/06     Initial version
--
-- ----------------------------------------------------------------------------
-- $Version: 3.0.0 $
-- $Revision: 2627 $
-- $Date: 2010-12-20 19:11:06 +0100 (Mon, 20 Dec 2010) $
-- $Author: andre $
-- ----------------------------------------------------------------------------
	

--/**
--	
-- Voltage (Nature ELECTRICAL) Sensor.
-- The model measures the voltage between EL_1 and EL_1 and converts
-- it to an output quantity. The model has to be connected in parallel
-- to EL_1 to EL_2.
-- 
-- 
-- @port      EL_1	 electrical plus terminal
-- @port      EL_2	 electrical minus terminal  
-- @port      Q_OUT	 quantity output 
--	
-- @library   FUNDAMENTALS_VDA
-- @structure domains/electrics/sensors
-- @test      sensors_test
--
--*/					




library IEEE;
    use IEEE.ELECTRICAL_SYSTEMS.all;
 
entity VOLTAGE2Q_SENSOR_VDA is
   port     (
      terminal EL_1  : ELECTRICAL;
      terminal EL_2  : ELECTRICAL;
      quantity Q_OUT : out REAL     -- quantity output [V]
      );
end entity VOLTAGE2Q_SENSOR_VDA;

architecture SIMPLE of VOLTAGE2Q_SENSOR_VDA is 
   quantity V across EL_1 to EL_2;
begin

   Q_OUT == V;

end architecture SIMPLE;
-- ----------------------------------------------------------------------------
-- Copyright (C) 2004-2011 VDA/FAT
-- ----------------------------------------------------------------------------


--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

-------------------------------------------------------------------------------
-- Diode 
-------------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;
USE IEEE.MATH_REAL.ALL;

ENTITY D_jsae IS
    GENERIC (
        RR : RESISTANCE := 100.0e3; -- Reverse resistance
		VF : VOLTAGE := 0.8; -- Forward voltage
		RB : RESISTANCE := 1.0e-3 -- Bulk Resistance
);      
    PORT (TERMINAL p,m : ELECTRICAL);
END ENTITY D_jsae;


ARCHITECTURE equiv OF D_jsae IS
	CONSTANT vlimit : VOLTAGE := VF/(1.0 - (RB/RR));
	QUANTITY v ACROSS i THROUGH p TO m;
BEGIN
	IF (v < vlimit) USE
		i == v/RR;
    ELSE
		i == (v-VF)/RB;
	END USE;
END ARCHITECTURE equiv;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

-- ----------------------------------------------------------------------------
-- Copyright (C) 2004-2011 VDA/FAT
--
-- This model is a component of the open source library created by the VDA/FAT 
-- working group number 30 and is covered by this license agreement. This model
-- including any updates, modifications, revisions, copies, and documentation
-- are copyrighted works of the VDA/FAT. Use of this model indicates your
-- complete and unconditional acceptance of the terms and conditions set forth
-- in this license agreement.
--  
-- The VDA/FAT grants a non-exclusive license to use, reproduce, modify and
-- distribute this model under the condition, that:
-- (a) no fee or other consideration is charged for any distribution except 
--     compilations distributed in accordance with Section (d) of this license 
--     agreement;
-- (b) the comment text embedded in this model is included verbatim in each
--     copy of this model made or distributed by you, whether or not such
--     version is modified;
-- (c) any modified version must include a conspicuous notice that this model
--     has been modified and the date of modification; and
-- (d) any compilations sold by you that include this model must include a 
--     conspicuous notice that this model is available from the VDA/FAT in 
--     its original form at no charge.
--
-- THIS MODEL IS LICENSED TO YOU "AS IT IS" AND WITH NO WARRANTIES, EXPRESSED
-- OR IMPLIED. THE VDA/FAT AND ALL COMPANIES CONTRIBUTING TO THIS LIBRARY
-- SPECIFICALLY DISCLAIM ALL IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
-- FOR A PARTICULAR PURPOSE. THE VDA/FAT AND ALL COMPANIES ORGANIZED WITHIN
-- MUST NOT HAVE ANY RESPONSIBILITY FOR ANY DAMAGES, FINANCIAL OR LEGAL CLAIMS 
-- WHATEVER.
-- ----------------------------------------------------------------------------
-- Literature:
--
--  
-- Dependencies: 
-- --------------------------------------------------------------------
-- Logical Library         Design unit
-- --------------------------------------------------------------------
-- IEEE                    ELECTRICAL_SYSTEMS
--
-- Author(s):
-- Joachim Haase 
--
-- Validator:
-- 
--
-- Source:
-- currentq2_sensor_vda.vhd
--
-- Development simulator:
-- SystemVision Professional 
--
-- Tested on: 
-- ------------------------------------------------------------------
-- Version  Simulator      Version   OS    Validator      Date
-- ------------------------------------------------------------------
-- 1.1      
--
--
-- Modification History:
-- ------------------------------------------------------------------
-- Version  Author            Date           Description
-- ------------------------------------------------------------------
--  1.1    J. Haase           2005/02/06     Initial version
--
-- ----------------------------------------------------------------------------
-- $Version: 3.0.0 $
-- $Revision: 2627 $
-- $Date: 2010-12-20 19:11:06 +0100 (Mon, 20 Dec 2010) $
-- $Author: andre $
-- ----------------------------------------------------------------------------
	

--/**
--	
-- Current (Nature ELECTRICAL) Sensor.
-- The model measures the current between EL_1 and EL_2 and 
-- converts it to an output quantity. The model has to be
-- connected in series to other branches.
-- 
-- 
-- @port      EL_1	 electrical plus terminal
-- @port      EL_2	 electrical minus terminal  
-- @port      Q_OUT	 quantity output 
--	
-- @library   FUNDAMENTALS_VDA
-- @structure domains/electrics/sensors
-- @test      sensors_test
--
--*/					




library IEEE;
    use IEEE.ELECTRICAL_SYSTEMS.all;
 
entity CURRENT2Q_SENSOR_VDA is
   port     (
      terminal EL_1  : ELECTRICAL;
      terminal EL_2  : ELECTRICAL;
      quantity Q_OUT : out REAL     -- quantity output [A]

      );
end entity CURRENT2Q_SENSOR_VDA;

architecture SIMPLE of CURRENT2Q_SENSOR_VDA is 
   quantity V across I through EL_1 to EL_2;
begin
   V == 0.0;
   if DOMAIN = QUIESCENT_DOMAIN use
      Q_OUT == I;
   else
      Q_OUT == I;
   end use;
end architecture SIMPLE;
-- ----------------------------------------------------------------------------
-- Copyright (C) 2004-2011 VDA/FAT
-- ----------------------------------------------------------------------------


--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

---------- VHDLAMS MODEL soc_cal ----------

---------- ENTITY DECLARATION soc_cal ----------
ENTITY soc_cal IS

	GENERIC (
	init_soc : REAL := 0.0;		--Initial SOC[%]
	ah : REAL := 0.0			--Battery ratings capacity[Ah]
	);

	PORT (
	QUANTITY batt_i : IN REAL;		--Electrical charge and discharge current[A] ***charge:minus discharge:plus***
	QUANTITY soc : OUT REAL;		--Battery SOC[%]
	QUANTITY q_a : OUT REAL		--Amount of electrical charge and discharge[Ah] ***charge:minus discharge:plus***
	);

END ENTITY soc_cal;
---------- ARCHITECTURE DECLARATION behav ----------
ARCHITECTURE behav OF soc_cal  IS

	QUANTITY AHR : REAL := init_soc;	--For SOC operation
	signal 	sw :boolean :=false;		--
	
BEGIN
	assert ah > 0.0
	report "ah > 0 !!" severity Error;
	assert -60.0 <= init_soc and init_soc <= 100.0
	report "0 <= init_soc <= 100 !!" severity Error;
	
	BREAK soc => init_soc;
	sw  <=  soc'above(100.0)  ;	-- when soc>100 then  sw=true
	break on sw;
	
--	q_a == batt_i'INTEG/3600.0;

	if (sw and (soc > 100.0 ))  use
		q_a'dot == 0.0 ;
	else
		q_a'dot == batt_i / 3600.0;
	end use;

	AHR == init_soc + q_a/ah *100.0;
	soc == AHR;


END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

---------- VHDLAMS MODEL all_cal ----------

---------- ENTITY DECLARATION all_cal ----------
LIBRARY FUNDAMENTALS_VDA;
USE FUNDAMENTALS_VDA.TLU_VDA.ALL;

ENTITY all_cal_m42 IS
 --GENERIC( Capa_Nom_AH : REAL := 33.0;    -- [Ah]
 --         INITIAL_SOC : REAL := 90.0    -- SOC0[%]
 --		); 
 PORT (

	     QUANTITY batt_i   : IN REAL := 0.0; --[A]  
         QUANTITY soc_in   : IN REAL := 0.0; --[%]   

         QUANTITY ocv   : OUT REAL  := 0.0;   --[v]
         QUANTITY dcir  : OUT REAL  := 0.0e-3;   --[Ohm]
         QUANTITY Rc    : OUT REAL  := 0.0e-3;   --[Ohm]
         QUANTITY Rd    : OUT REAL  := 0.0e-3;   --[Ohm]
         QUANTITY Cap1  : OUT REAL  := 0.0  --[F]

       );
END ENTITY all_cal_m42 ;

---------- ARCHITECTURE DECLARATION arch_all_cal ----------
ARCHITECTURE DEFAULT OF all_cal_m42 IS
	constant batt_i_map : real_vector :=  ( -300.0,   -45.0) ;
	constant soc_in_map : real_vector :=  ( 90.0, 100.0) ;

   	constant ocv_map  : real_vector :=  (12.80, 12.88) ; 
	constant dcir_map : real_vector :=  (7.354e-3, 7.177e-3) ; 
	constant Rc_map   : real_vector :=  (21.84e-3, 53.44e-3) ; 
	constant Rd_map   : real_vector :=  (1.10e-3,  5.57e-3,
                                         1.50e-3,  6.20e-3) ;    
	constant Cap1_map  : real_vector :=  (364.06, 487.63) ; 

BEGIN

	ocv  == lookup_1D( soc_in, soc_in_map, ocv_map ); 
	dcir  == lookup_1D( soc_in, soc_in_map, dcir_map ); 
	Rc  == lookup_1D( soc_in, soc_in_map, Rc_map ); 
	Rd  == lookup_2D( batt_i, soc_in, batt_i_map, soc_in_map, Rd_map ); 
	Cap1  == lookup_1D( soc_in, soc_in_map, Cap1_map ); 

END ARCHITECTURE DEFAULT; 
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

-- ----------------------------------------------------------------------------
-- Copyright (C) 2004-2011 VDA/FAT
--
-- This model is a component of the open source library created by the VDA/FAT 
-- working group number 30 and is covered by this license agreement. This model
-- including any updates, modifications, revisions, copies, and documentation
-- are copyrighted works of the VDA/FAT. Use of this model indicates your
-- complete and unconditional acceptance of the terms and conditions set forth
-- in this license agreement.
--  
-- The VDA/FAT grants a non-exclusive license to use, reproduce, modify and
-- distribute this model under the condition, that:
-- (a) no fee or other consideration is charged for any distribution except 
--     compilations distributed in accordance with Section (d) of this license 
--     agreement;
-- (b) the comment text embedded in this model is included verbatim in each
--     copy of this model made or distributed by you, whether or not such
--     version is modified;
-- (c) any modified version must include a conspicuous notice that this model
--     has been modified and the date of modification; and
-- (d) any compilations sold by you that include this model must include a 
--     conspicuous notice that this model is available from the VDA/FAT in 
--     its original form at no charge.
--
-- THIS MODEL IS LICENSED TO YOU "AS IT IS" AND WITH NO WARRANTIES, EXPRESSED
-- OR IMPLIED. THE VDA/FAT AND ALL COMPANIES CONTRIBUTING TO THIS LIBRARY
-- SPECIFICALLY DISCLAIM ALL IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
-- FOR A PARTICULAR PURPOSE. THE VDA/FAT AND ALL COMPANIES ORGANIZED WITHIN
-- MUST NOT HAVE ANY RESPONSIBILITY FOR ANY DAMAGES, FINANCIAL OR LEGAL CLAIMS 
-- WHATEVER.
-- ----------------------------------------------------------------------------
-- Literature:
--
--  
-- Dependencies: 
-- --------------------------------------------------------------------
-- Logical Library         Design unit
-- --------------------------------------------------------------------
-- IEEE                    ELECTRICAL_SYSTEMS
--
-- Author(s):
-- Joachim Haase 
--
-- Validator:
-- 
--
-- Source:
-- q2voltage_vda.vhd
--
-- Development simulator:
-- SystemVision Professional 
--
-- Tested on: 
-- ------------------------------------------------------------------
-- Version  Simulator      Version   OS    Validator      Date
-- ------------------------------------------------------------------
-- 1.1      
--
--
-- Modification History:
-- ------------------------------------------------------------------
-- Version  Author            Date           Description
-- ------------------------------------------------------------------
--  1.1    Joachim Haase      2004/10/14     Original Version     
--  1.2    J. Haase           2005/02/06     DEFAULT included
--
-- ----------------------------------------------------------------------------
-- $Version: 3.0.0 $
-- $Revision: 2627 $
-- $Date: 2010-12-20 19:11:06 +0100 (Mon, 20 Dec 2010) $
-- $Author: andre $
-- ----------------------------------------------------------------------------
	

--/**
--	
-- Quantity to Voltage (Nature ELECTRICAL) Converter.
-- The model converts a quantity to a voltage source of 
-- nature ELECTRICAL. The voltage is directed from EL_1 to EL_2.
-- 
-- @generic   DEFAULT	 default value of unassociated port Q_IN  [V]
-- 
-- @port      Q_IN	 quantity input 
-- @port      EL_1	 electrical plus terminal
-- @port      EL_2	 electrical minus terminal  
--	
-- @library   FUNDAMENTALS_VDA
-- @structure domains/electrics/q2sources
-- @test      q2sources_test
--
--*/					




library IEEE;
    use IEEE.ELECTRICAL_SYSTEMS.all;
 
entity Q2VOLTAGE_VDA is
   generic (
      DEFAULT : REAL := 1.0  -- default value of unassociated port Q_IN [V]
      );
   port     (
      quantity Q_IN : in REAL := DEFAULT;
      terminal EL_1 : ELECTRICAL;
      terminal EL_2 : ELECTRICAL   -- electrical minus terminal  
      );
end entity Q2VOLTAGE_VDA;

architecture SIMPLE of Q2VOLTAGE_VDA is 
   quantity V across I through EL_1 to EL_2;
begin

   V == Q_IN;

end architecture SIMPLE;
-- ----------------------------------------------------------------------------
-- Copyright (C) 2004-2011 VDA/FAT
-- ----------------------------------------------------------------------------


--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

library IEEE;
    use IEEE.ELECTRICAL_SYSTEMS.all;

entity R_JSAE is
	port (
		quantity R : in real ; -- resistance (valied) 
		terminal  P, N : ELECTRICAL
	);
end entity R_JSAE;

architecture beh of R_JSAE is
  quantity V across I through P to N;

  begin

    V == R * I;

end architecture beh;

--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Capacitor                                                 --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------

LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;

ENTITY C IS
    GENERIC (V0     : VOLTAGE := 0.0;
			 Use_V0 : BOOLEAN := true);
    PORT (QUANTITY C : CAPACITANCE := 1.0e-6; 
          TERMINAL p,m  : ELECTRICAL);
END ENTITY C;
ARCHITECTURE behav OF c IS
    QUANTITY v ACROSS i THROUGH p TO m;
    QUANTITY charge : CHARGE := C*V0;
BEGIN
    IF (domain = quiescent_domain) USE
      if (Use_V0) use
		  charge == C*V0;
          v == V0;
	  else
		  charge == C*v;
    	  i == 0.0;
	  end use;
    ELSE
      charge == C * v ;
      i == charge'dot;
   END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY N_20150210_bat_M42 IS
	PORT (
		TERMINAL Pos : ELECTRICAL;
		TERMINAL Neg : ELECTRICAL;
		QUANTITY initial_SOC_percent : IN REAL := 0.0;
		QUANTITY Capacity_Ah : IN REAL := 0.0 
	);
BEGIN 
END ENTITY N_20150210_bat_M42;

ARCHITECTURE struct OF N_20150210_bat_M42 IS
	TERMINAL net_37 : ELECTRICAL;
	TERMINAL net_46 : ELECTRICAL;
	TERMINAL net_38 : ELECTRICAL;
	TERMINAL net_40 : ELECTRICAL;
	TERMINAL net_39 : ELECTRICAL;
	TERMINAL net_36 : ELECTRICAL;
	TERMINAL net_41 : ELECTRICAL;
	TERMINAL net_42 : ELECTRICAL;
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
	QUANTITY Q_11 : real := 0.0;
BEGIN
	OCV1 : ENTITY WORK.voltage2q_sensor_vda(simple)
		PORT MAP ( el_2 => Neg, el_1 => net_36, q_out => Q_11 );

	d_jsae5 : ENTITY WORK.d_jsae(equiv)
		GENERIC MAP ( rb => 0.0001 , vf => 0.0 , rr => 100000.0 )
		PORT MAP ( m => net_46, p => net_40);

	d_jsae6 : ENTITY WORK.d_jsae(equiv)
		GENERIC MAP ( rb => 0.0001 , vf => 0.0 , rr => 100000.0 )
		PORT MAP ( m => net_38, p => net_39);

	d_jsae7 : ENTITY WORK.d_jsae(equiv)
		GENERIC MAP ( rb => 0.0001 , vf => 0.0 , rr => 100000.0 )
		PORT MAP ( m => net_41, p => net_46);

	d_jsae8 : ENTITY WORK.d_jsae(equiv)
		GENERIC MAP ( rb => 0.0001 , vf => 0.0 , rr => 100000.0 )
		PORT MAP ( m => net_42, p => net_38);

	current2q_sensor_vda2 : ENTITY WORK.current2q_sensor_vda(simple)
		PORT MAP ( el_2 => net_38, el_1 => Pos, q_out => Q_8 );

	pol_v1 : ENTITY WORK.voltage2q_sensor_vda(simple)
		PORT MAP ( el_2 => net_37, el_1 => net_38, q_out => Q_10 );

	soc_cal : ENTITY WORK.soc_cal(behav)
		GENERIC MAP ( ah => Capacity_Ah , init_soc => initial_SOC_percent )
		PORT MAP ( q_a => Q_9 , soc => Q_7 , batt_i => Q_8 );

	all_cal_m42 : ENTITY WORK.all_cal_m42(default)
		PORT MAP ( cap1 => Q_2 , rd => Q_3 , rc => Q_5 , dcir => Q_4 , ocv => Q_6 , soc_in => Q_7 , batt_i => Q_8 );

	q2voltage_vda2 : ENTITY WORK.q2voltage_vda(simple)
		GENERIC MAP ( default => 1.0 )
		PORT MAP ( el_2 => Neg, el_1 => net_36, q_in => Q_6 );

	r_jsae6 : ENTITY WORK.r_jsae(beh)
		PORT MAP ( n => net_46, p => net_42, r => Q_5 );

	r_jsae7 : ENTITY WORK.r_jsae(beh)
		PORT MAP ( n => net_37, p => net_41, r => Q_5 );

	r_jsae8 : ENTITY WORK.r_jsae(beh)
		PORT MAP ( n => net_36, p => net_37, r => Q_4 );

	r_jsae9 : ENTITY WORK.r_jsae(beh)
		PORT MAP ( n => net_46, p => net_39, r => Q_3 );

	r_jsae10 : ENTITY WORK.r_jsae(beh)
		PORT MAP ( n => net_37, p => net_40, r => Q_3 );

	c1 : ENTITY WORK.c(behav)
		GENERIC MAP ( use_v0 => false , v0 => 0.0 )
		PORT MAP ( m => net_46, p => net_38, c => Q_2 );

	c2 : ENTITY WORK.c(behav)
		GENERIC MAP ( use_v0 => false , v0 => 0.0 )
		PORT MAP ( m => net_37, p => net_46, c => Q_2*10.0 );
END ARCHITECTURE struct;
----------------------------------------------------------------------


LIBRARY ieee;
USE ieee.all;

ENTITY BT_PB_PNT IS
	PORT (
		TERMINAL NEG : ELECTRICAL;
		TERMINAL POS : ELECTRICAL 
	);
BEGIN 
END ENTITY BT_PB_PNT;

ARCHITECTURE struct OF BT_PB_PNT IS
BEGIN
	batt4: ENTITY WORK.N_20150210_bat_M42(struct)
		PORT MAP ( pos => POS, neg => NEG, initial_SOC_percent => 95.0 , Capacity_Ah => 30.0 );
END ARCHITECTURE struct;
----------------------------------------------------------------------
