--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Comparator                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY COMP IS
   GENERIC (TS : REAL := 0.0);
   PORT (QUANTITY INPUT : IN REAL := 0.0;
         QUANTITY VAL1 : IN REAL := 1.0;
         QUANTITY VAL2 : IN REAL := -1.0;
         QUANTITY THRES : IN REAL := 0.0;
         QUANTITY VAL : OUT REAL);
END ENTITY COMP;
ARCHITECTURE behav OF COMP IS
  QUANTITY temp_val : REAL := 0.0;
  SIGNAL crossing : BOOLEAN := FALSE;
BEGIN
    crossing <= NOT INPUT'ABOVE(THRES);
    IF (crossing AND (INPUT < THRES)) USE
        temp_val == VAL1;
    ELSE
        temp_val == VAL2;
    END USE;
    BREAK ON crossing;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Constant                                                 --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.MATH_2_PI;

ENTITY CONST IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY CONST : IN REAL := 1.0;
          QUANTITY AC_MAG : REAL := 1.0e-3;
          QUANTITY AC_PHASE : REAL := 0.0;
          QUANTITY VAL : OUT REAL := 0.0);
END ENTITY CONST;
ARCHITECTURE behav OF CONST IS
    QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
    IF (domain = quiescent_domain) OR (domain = time_domain) USE
		val == const'ZOH(ts);
    ELSE
        val == ac_spec;
    END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Voltage Source                                                 --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------

LIBRARY IEEE;
USE IEEE.MATH_REAL.MATH_2_PI;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY E IS
    PORT (QUANTITY EMF : IN VOLTAGE := 1.0;
          QUANTITY AC_MAG : IN VOLTAGE := 1.0e-3;
          QUANTITY AC_PHASE : IN ANGLE := 0.0;
          TERMINAL p,m: ELECTRICAL);
END ENTITY E;
ARCHITECTURE behav OF E IS
    QUANTITY v ACROSS i THROUGH p TO m;
    QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
    IF (domain = quiescent_domain) OR (domain = time_domain) USE
	  v == -EMF;
    ELSE
      v == -ac_spec;
    END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Voltmeter                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;
                              
ENTITY VM IS
    PORT (QUANTITY V : OUT VOLTAGE;
          TERMINAL p,m : ELECTRICAL);
END ENTITY VM;
ARCHITECTURE behav of VM IS
    QUANTITY vg across p to m;
BEGIN
    V == vg;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Multiplier                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY MUL IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MUL;
ARCHITECTURE behav OF MUL IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
    temp_val == INPUT0*INPUT1;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

-------------   Copyright (C) 2020 Digital Twins Inc.  ----------------------

LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;
USE ieee.mechanical_systems.all;
USE IEEE.MATH_REAL.ALL;


ENTITY i_calc1 IS
	GENERIC (
		--MAX_V : real := 280.0;--500.0;
		MAX_V : real := 500.0;--500.0;	LK kido 08.02.22
		MIN_V : real := 1.0;
		LMT_I : real := 100.0);

    PORT(   QUANTITY out_i : out real;
--			QUANTITY current_t : in real;
--			QUANTITY max_v : in real := 500.0;
--			QUANTITY min_v : in real := 1.0;
--			QUANTITY lmt_i : in real := 100.0;
			QUANTITY v_in : in real;
			QUANTITY p_in : in real :=0.0);

END ENTITY i_calc1;
ARCHITECTURE behav OF i_calc1 IS

QUANTITY tmp_i : real ;
QUANTITY tmp_v : real ;

BEGIN
--    BREAK
--	tmp_i => 0.0,
--	out_i => 0.0;

tmp_v == realmin(realmax(v_in, MIN_V), MAX_V);
	if(tmp_v = 0.0) use 
	tmp_i == 0.0 ; 
	else 
	tmp_i == p_in/ tmp_v  ;
 	end use ; 
out_i == realmin(realmax(tmp_i, -LMT_I), LMT_I) ;

--	tmp_v == bound_guard(v_in, MAX_V, MIN_V);
----	p_in == v_in * tmp_i;
--	p_in == tmp_v * tmp_i; 
--	out_i == bound_guard(tmp_i, LMT_I, -LMT_I);

--	if (tmp_i>lmt_i) use
--		out_i == lmt_i * 1.0;
--	elsif (tmp_i<-lmt_i) use
--		out_i == -lmt_i * 1.0;
--	else
--		out_i == tmp_i * 1.0;
-- 	end use;

--	p_in == v_in * out_i;


END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Current Source                                           --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------

LIBRARY IEEE;
USE IEEE.MATH_REAL.MATH_2_PI;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY I IS 
    PORT (QUANTITY I : IN CURRENT := 1.0; 
          QUANTITY AC_MAG : IN CURRENT := 1.0e-3;
          QUANTITY AC_PHASE : IN ANGLE := 0.0;
          TERMINAL p,m: ELECTRICAL);
END ENTITY I;
ARCHITECTURE behav OF I IS
    QUANTITY v ACROSS ic THROUGH p TO m;
    QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
    IF (domain = quiescent_domain) OR (domain = time_domain) USE
	  ic == I;
    ELSE
      ic == ac_spec;
    END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Ideal Switch                                             --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------

LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;

ENTITY S IS
    PORT (QUANTITY CTRL : IN REAL := 0.0;
          TERMINAL n1,n2  : ELECTRICAL);
END ENTITY S;
ARCHITECTURE behav OF S IS
    QUANTITY v ACROSS i THROUGH n1 to n2;
    SIGNAL sw_on : BOOLEAN;
BEGIN
    sw_on <= CTRL'ABOVE(0.0);
    BREAK ON sw_on;

    IF (sw_on AND (CTRL > 0.0)) USE
        v == 0.0;
    ELSE
        i == 0.0;
    END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;

ENTITY CHG_PNT IS
	PORT (
		QUANTITY SOC_sense : IN REAL := 0.0 ;
		QUANTITY Charge_end_soc : IN REAL := 0.95 ;
		QUANTITY Charge_Control : IN REAL := 0.0 ;
		QUANTITY Charge_Power : IN REAL := 50000.0 ;
		QUANTITY Charge_current : OUT REAL ; 
		TERMINAL Charge : ELECTRICAL
	);
BEGIN 
END ENTITY CHG_PNT;

ARCHITECTURE struct OF CHG_PNT IS
	TERMINAL net_147 : ELECTRICAL;
	TERMINAL net_146 : ELECTRICAL;
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
BEGIN
	SOC_stop : ENTITY WORK.comp(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_9 , thres => Charge_end_soc , val2 => 0.0 , val1 => 1.0 , input => SOC_sense );

	Charge_Control : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_10 , ac_phase => 0.0 , ac_mag => 0.001 , const => Charge_Control );

	e2 : ENTITY WORK.e(behav)
		PORT MAP ( m => net_146, p => electrical_ref, ac_phase => 0.0 , ac_mag => 0.001 , emf => 200.0 );

	vm4 : ENTITY WORK.vm(behav)
		PORT MAP ( m => electrical_ref, p => net_146, v => Q_7 );

	Charge_Power : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_8 , ac_phase => 0.0 , ac_mag => 0.001 , const => Charge_Power );

	vm2 : ENTITY WORK.vm(behav)
		PORT MAP ( m => electrical_ref, p => net_147, v => Q_5 );

	mul1 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , input1 => Q_9 , input0 => Q_10 );

	mul4 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , input1 => Q_2 , input0 => Q_8 );

	i_calc1 : ENTITY WORK.i_calc1(behav)
		GENERIC MAP ( lmt_i => 150.0 )
		PORT MAP ( p_in => Q_4 , v_in => Q_7 , out_i => Q_6 );

	i3 : ENTITY WORK.i(behav)
		PORT MAP ( m => electrical_ref, p => net_146, ac_phase => 0.0 , ac_mag => 0.001 , i => Q_6 );

	i_calc11 : ENTITY WORK.i_calc1(behav)
		GENERIC MAP ( lmt_i => 150.0 )
		PORT MAP ( p_in => Q_4 , v_in => Q_5 , out_i => Q_3 );

	i2 : ENTITY WORK.i(behav)
		PORT MAP ( m => net_147, p => electrical_ref, ac_phase => 0.0 , ac_mag => 0.001 , i => Q_3 );

	s1 : ENTITY WORK.s(behav)
		PORT MAP ( n2 => net_147, n1 => Charge, ctrl => Q_2 );
		
		Charge_current == Q_3 ;
END ARCHITECTURE struct;
----------------------------------------------------------------------


