--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Resistor                                                 --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------

LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;

ENTITY R IS
    PORT (QUANTITY R : RESISTANCE := 1.0e+3; 
          TERMINAL p,m  : ELECTRICAL);
END ENTITY R;
ARCHITECTURE behav OF R IS
    QUANTITY v ACROSS i THROUGH p TO m;
BEGIN
    v == i*R;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Ideal Switch                                             --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------

LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;

ENTITY S IS
    PORT (QUANTITY CTRL : IN REAL := 0.0;
          TERMINAL n1,n2  : ELECTRICAL);
END ENTITY S;
ARCHITECTURE behav OF S IS
    QUANTITY v ACROSS i THROUGH n1 to n2;
    SIGNAL sw_on : BOOLEAN;
BEGIN
    sw_on <= CTRL'ABOVE(0.0);
    BREAK ON sw_on;

    IF (sw_on AND (CTRL > 0.0)) USE
        v == 0.0;
    ELSE
        i == 0.0;
    END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Multiplier                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY MUL IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MUL;
ARCHITECTURE behav OF MUL IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
    temp_val == INPUT0*INPUT1;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Two-Point Element with Hysteresis                        --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY TPH IS
    GENERIC (Y0 : REAL := 0.0;
             TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY VAL1 : IN REAL := 1.0;
          QUANTITY VAL2 : IN REAL := -1.0;
          QUANTITY THRES1 : IN REAL := 0.0;
          QUANTITY THRES2 : IN REAL := 0.0;
          QUANTITY VAL : OUT REAL);
END ENTITY TPH;
ARCHITECTURE behav OF TPH IS
  QUANTITY temp_val : REAL := 0.0;
  SIGNAL sig : REAL := VAL1;
  SIGNAL upper_crossing : BOOLEAN := FALSE;
  SIGNAL lower_crossing : BOOLEAN := TRUE;
BEGIN
     ASSERT (THRES1 <= THRES2) REPORT "Threshold 1 should be less than Threshold 2" SEVERITY error;

    upper_crossing <= input'ABOVE(THRES2);
    lower_crossing <= NOT input'ABOVE(THRES1);

    BREAK ON upper_crossing, lower_crossing;

    PROCESS
    BEGIN
        sig <= Y0;
        WAIT;
    END PROCESS;
    
    PROCESS (upper_crossing,lower_crossing)
    BEGIN
        IF (INPUT<THRES1) THEN
            sig <= VAL1;
        ELSIF (INPUT > THRES2) THEN
            sig <= VAL2;
        ELSIF ((INPUT > THRES1) AND (sig = VAL1)) THEN
            sig <= VAL1;
        ELSIF ((INPUT < THRES2) AND (sig = VAL2)) THEN
            sig <= VAL2;
        END IF;
    END PROCESS;

-- IF DOMAIN = QUIESCENT_DOMAIN USE
--  temp_val == Y0;
-- ELSE
     temp_val == sig;
-- END USE;

    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY CO2_CNT IS
 PORT (
  TERMINAL VCU_pow_in : ELECTRICAL;
  QUANTITY CO2_OUT : IN REAL := 0.0;
  QUANTITY CO2_CNT_ONOFF : IN REAL := 0.0;
  QUANTITY CO2_Upper_Lim : IN REAL := 0.0;
  QUANTITY CO2_Under_Lim : IN REAL := 0.0;
  QUANTITY CO2_GAIKI_ON : OUT REAL 
 );
BEGIN 
END ENTITY CO2_CNT;

ARCHITECTURE struct OF CO2_CNT IS
 TERMINAL net_5 : ELECTRICAL;
 QUANTITY Q_2 : real := 0.0;
 QUANTITY Q_4 : real := 0.0;
 QUANTITY Q_5 : real := 0.0;
 QUANTITY Q_6 : real := 0.0;
BEGIN
 r6 : ENTITY WORK.r(behav)
  PORT MAP ( m => ground, p => net_5, r => 70.0 );

 s2 : ENTITY WORK.s(behav)
  PORT MAP ( n2 => net_5, n1 => VCU_pow_in, ctrl => CO2_CNT_ONOFF );

 mul12 : ENTITY WORK.mul(behav)
  GENERIC MAP ( ts => 0.0 )
  PORT MAP ( val => Q_6 , input1 => 1.0e-06 , input0 => CO2_Under_Lim );

 mul1 : ENTITY WORK.mul(behav)
  GENERIC MAP ( ts => 0.0 )
  PORT MAP ( val => Q_5 , input1 => 1.0e-06 , input0 => CO2_Upper_Lim );

 tph1 : ENTITY WORK.tph(behav)
  GENERIC MAP ( ts => 0.0 , y0 => 0.0 )
  PORT MAP ( val => Q_4 , thres2 => Q_5 , thres1 => Q_6 , val2 => 1.0 , val1 => 0.0 , input => CO2_OUT );

 mul859 : ENTITY WORK.mul(behav)
  GENERIC MAP ( ts => 0.0 )
  PORT MAP ( val => Q_2 , input1 => CO2_CNT_ONOFF , input0 => Q_4 );
 CO2_GAIKI_ON == Q_2 ;
END ARCHITECTURE struct;
----------------------------------------------------------------------

