--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Power                                                    --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY pow IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY EXP : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL);
END ENTITY pow;
ARCHITECTURE behav OF pow IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT**exp;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Multiplier                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY MUL IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MUL;
ARCHITECTURE behav OF MUL IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
    temp_val == INPUT0*INPUT1;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Negator                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY NEG IS
    GENERIC(TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY NEG;
ARCHITECTURE behav OF NEG IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
	temp_val == -INPUT;
	VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Unit Delay                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY UDELAY IS
    GENERIC (TS : REAL := 0.0;
             Y0 : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
        QUANTITY VAL : OUT REAL);
END ENTITY UDELAY;
ARCHITECTURE behav OF UDELAY IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT'DELAYED(TS);

  IF (DOMAIN = QUIESCENT_DOMAIN) USE
     VAL == Y0;
  ELSIF (DOMAIN = TIME_DOMAIN) USE
     IF (NOW < TS) USE
       VAL == Y0;
     ELSE
       VAL == temp_val'ZOH(TS);
     END USE;
  ELSE
     VAL == temp_val'ZOH(TS);
  END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Summation                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY SUM IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY SUM;
ARCHITECTURE behav OF SUM IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT0 + INPUT1;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Integrator                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY INTG IS
    GENERIC (Y0 : REAL := 0.0;  
             TS : REAL := 0.0); 
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY KI : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL := Y0);
END ENTITY INTG;
ARCHITECTURE behav OF INTG IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
    BREAK temp_val => Y0;
    temp_val'DOT == KI*INPUT;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY CO2_PNT IS
	GENERIC ( H : REAL :=0.01
	);
	PORT (
		QUANTITY CO2_OUT : OUT REAL ;
		QUANTITY GAIKI_ON : IN REAL := 0.0;
		QUANTITY CO2_Out_concentration : IN REAL := 0.0;
		QUANTITY Car_Volume : IN REAL := 0.0;
		QUANTITY Out_AirChange_Vol : IN REAL := 0.0;
		QUANTITY Crew_CO2 : IN REAL := 0.0
	);

BEGIN 
END ENTITY CO2_PNT;

ARCHITECTURE struct OF CO2_PNT IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_11 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
	QUANTITY Q_12 : real := 0.0;
	QUANTITY Q_14 : real := 0.0;
	QUANTITY Q_15 : real := 0.0;
	QUANTITY Q_16 : real := 0.0;
BEGIN
	pow115 : ENTITY WORK.pow(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_14 , exp => -1.0 , input => Car_Volume );

	mul1 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_16 , input1 => 1.0e-06 , input0 => CO2_Out_concentration );

	mul1022 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_15 , input1 => Out_AirChange_Vol , input0 => Q_16 );

	neg67 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_10 , input => Q_15 );

	mul1015 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_11 , input1 => Q_14 , input0 => Q_2 );

	udelay3 : ENTITY WORK.udelay(behav)
		GENERIC MAP ( y0 => 0.0 , ts => H -- Expression
		)
		PORT MAP ( val => Q_12 , input => Q_11 );

	mul1014 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_9 , input1 => Out_AirChange_Vol , input0 => Q_12 );

	sum262 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_8 , input1 => Q_9 , input0 => Q_10 );

	neg68 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , input => Q_8 );

	mul8 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , input1 => GAIKI_ON , input0 => Q_7 );

	sum4 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , input1 => Crew_CO2 , input0 => Q_5 );

	intg5 : ENTITY WORK.intg(behav)
		GENERIC MAP ( ts => 0.0 , y0 => 0.002523 )
		PORT MAP ( val => Q_2 , ki => 1.0 , input => Q_3 );
	CO2_OUT == Q_11 ;
END ARCHITECTURE struct;
----------------------------------------------------------------------

