--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Multiplier                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY MUL IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MUL;
ARCHITECTURE behav OF MUL IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
    temp_val == INPUT0*INPUT1;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Summation                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY SUM IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY SUM;
ARCHITECTURE behav OF SUM IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT0 + INPUT1;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Heat Flow Source                                         --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.THERMAL_SYSTEMS.ALL;
USE IEEE.MECHANICAL_SYSTEMS.ALL;
USE IEEE.MATH_REAL.MATH_2_PI;

ENTITY h IS
  PORT(
    QUANTITY value : IN HEAT_FLOW := 1.0;
    QUANTITY AC_MAG : IN HEAT_FLOW := 1.0e-3;
    QUANTITY AC_PHASE : IN ANGLE := 0.0;
    TERMINAL th1, th2 : thermal);
END ENTITY h;
ARCHITECTURE behav OF h IS
  QUANTITY t ACROSS h_val THROUGH th1 TO th2;
  QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
  IF (domain = quiescent_domain) OR (domain = time_domain) USE
    h_val == value;
  ELSE
    h_val == ac_spec;
  END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY CREW_PNT IS
	PORT (
		QUANTITY Crew_Adult_Man : IN REAL := 0.0 ;
		QUANTITY Crew_Adult_Woman : IN REAL := 0.0 ;
		QUANTITY Crew_child : IN REAL := 0.0 ;
		QUANTITY Adult_Woman_Heat_Coefficient : IN REAL := 0.9 ;
		QUANTITY Adult_Woman_CO2_Coefficient : IN REAL := 0.9 ;
		QUANTITY Child_Heat_Coefficient : IN REAL := 0.5 ;
		QUANTITY Child_CO2_Coefficient : IN REAL := 0.5 ;
		QUANTITY CO2_Emissions : IN REAL := 6.39e-6 ;
		QUANTITY Human_Heat : IN REAL := 69.0 ;
		QUANTITY Crew_Emissions : OUT REAL ;
		TERMINAL Crew_Heat : THERMAL
	);

BEGIN 
END ENTITY CREW_PNT;

ARCHITECTURE struct OF CREW_PNT IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_11 : real := 0.0;
	QUANTITY Q_12 : real := 0.0;
	QUANTITY Q_13 : real := 0.0;
	QUANTITY Q_14 : real := 0.0;
BEGIN
	mul12 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_14 , input1 => Adult_Woman_CO2_Coefficient , input0 => Crew_Adult_Woman );

	mul5 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_13 , input1 => Child_CO2_Coefficient , input0 => Crew_child );

	mul1 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , input1 => Adult_Woman_Heat_Coefficient , input0 => Crew_Adult_Woman );

	mul2 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , input1 => Child_Heat_Coefficient , input0 => Crew_child );

	sum3 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_12 , input1 => Crew_Adult_Man , input0 => Q_14 );

	sum1 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_11 , input1 => Q_12 , input0 => Q_13 );

	mul13 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Crew_Emissions , input1 => CO2_Emissions , input0 => Q_11 );

	sum2 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_6 , input1 => Q_7 , input0 => Crew_Adult_Man );

	sum4 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , input1 => Q_5 , input0 => Q_6 );

	mul857 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , input1 => Human_Heat , input0 => Q_4 );

	h1 : ENTITY WORK.h(behav)
		PORT MAP ( th2 => Crew_Heat, th1 => thermal_ref, ac_phase => 0.0 , ac_mag => 0.001 , value => Q_2 );
END ARCHITECTURE struct;
----------------------------------------------------------------------

