--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Torque Sensor                                            --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY fm_rot IS
  PORT(
    QUANTITY torque : OUT TORQUE;
    TERMINAL rot1, rot2 : ROTATIONAL_V);
END ENTITY fm_rot;
ARCHITECTURE behav OF fm_rot IS
  QUANTITY omega_zero ACROSS m_val THROUGH rot1 TO rot2;
BEGIN
  m_val == torque;
  omega_zero == 0.0;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

------------------------------------------------------------------------------------------------------------------------
-------------   Copyright (C) 2020 Digital Twins Inc.  ----------------------
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;
USE IEEE.MATH_REAL.ALL;

---------- ENTITY DECLARATION gear_simple ----------
ENTITY	gear_simple IS
	GENERIC(

		N1_0          : REAL :=0.0 ;
		PHI1_0,PHI2_0 : ANGLE :=0.0 );
	PORT(
		QUANTITY Ratio    : IN REAL := 0.0; 
		TERMINAL ROT1,ROT2 : ROTATIONAL_V ;
		QUANTITY Power_i,Power_o : OUT real;
		QUANTITY PHI1,PHI2 : OUT ANGLE     ;
		QUANTITY N1,N2     : OUT REAL     );
END ENTITY gear_simple;
---------- VHDLAMS MODEL gear_simple ----------



---------- ARCHITECTURE DECLARATION arch_gear_simple ----------

ARCHITECTURE arch_gear_simple OF gear_simple IS

	CONSTANT N2OM : REAL := 2.0 * MATH_PI / 60.0 ; --rpm TO rad/s
	CONSTANT OM2N : REAL := 60.0 / ( 2.0 * MATH_PI ) ; --rad/s TO rpm
    QUANTITY omega_i  ACROSS torque_i  THROUGH rot1 to ROTATIONAL_V_REF;
    QUANTITY omega_o  ACROSS torque_o  THROUGH ROTATIONAL_V_REF to rot2;

BEGIN

	BREAK
		PHI1 => PHI1_0 ,
		PHI2 => PHI2_0 ,
		omega_i => N1_0 * N2OM ;

	--omega_o == omega_i / R;
    omega_i == -omega_o * Ratio ; 
	torque_o == torque_i * Ratio ;

	PHI1 == omega_i'INTEG + PHI1_0 ;
	PHI2 == omega_o'INTEG + PHI2_0 ;

	N1 == omega_i * OM2N ;
	N2 == omega_o * OM2N ;
  
    Power_i == omega_i * torque_i;
    Power_o == omega_o * torque_o;

END ARCHITECTURE arch_gear_simple;
---------- END VHDLAMS MODEL gear_simple ----------
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--------------   Copyright (C) 2020 Digital Twins Inc.  ----------------------



LIBRARY IEEE ;
USE IEEE.MECHANICAL_SYSTEMS.ALL ;

ENTITY IDEALPLANETARY IS
	GENERIC(
		SUN_PHI0     : ANGLE :=0.0        ;
		CARRIER_PHI0 : ANGLE :=0.0        ;
		RING_PHI0    : ANGLE :=0.0        ;

		RHO        : REAL  :=100.0/50.0
		);
	PORT(
		TERMINAL SUN     : ROTATIONAL_V ;
		TERMINAL CARRIER : ROTATIONAL_V ;
		TERMINAL RING    : ROTATIONAL_V  
		);
END ENTITY ;
ARCHITECTURE BEHAV OF IDEALPLANETARY IS
	QUANTITY SUN_PHI     ACROSS SUN_TAU     THROUGH SUN     TO ROTATIONAL_V_REF ;
	QUANTITY CARRIER_PHI ACROSS CARRIER_TAU THROUGH CARRIER TO ROTATIONAL_V_REF ;
	QUANTITY RING_PHI    ACROSS RING_TAU    THROUGH RING    TO ROTATIONAL_V_REF ;
BEGIN
	BREAK
		SUN_PHI     => SUN_PHI0     ,
		CARRIER_PHI => CARRIER_PHI0 ,
		RING_PHI    => RING_PHI0    ;



	(1.0 + 1.0/rho)*CARRIER_PHI == SUN_PHI + 1.0/rho*RING_PHI;
	RING_TAU == SUN_TAU/rho;
	CARRIER_TAU == -(1.0 + 1.0/rho)*SUN_TAU;


END ARCHITECTURE BEHAV ;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Mass                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY mass_rot IS
  GENERIC(
    phi0  : ANGLE := 0.0;
    omega0 : ANGULAR_VELOCITY := 0.0);
  PORT(
        QUANTITY j : MOMENT_INERTIA := 1.0;
        TERMINAL rot1 : ROTATIONAL_V );
END ENTITY mass_rot;
ARCHITECTURE behav of mass_rot IS
  QUANTITY omega ACROSS m THROUGH rot1 TO rotational_v_ref;
  QUANTITY phi : ANGLE;
  QUANTITY acc : ANGULAR_ACCELERATION;
BEGIN
  IF (domain = quiescent_domain) USE
    phi == phi0;
    omega == omega0;
  ELSE
    phi'dot == omega;
    omega'dot == acc;
  END USE;
    m == j*acc;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Simplorer2 IS
	PORT (
		TERMINAL TO_Preta : ROTATIONAL_V;
		TERMINAL TO_TireR : ROTATIONAL_V;
		TERMINAL TO_TireL : ROTATIONAL_V;
		QUANTITY Inertia : IN REAL := 0.0;
		QUANTITY Def_Ratio : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Simplorer2;

ARCHITECTURE struct OF Simplorer2 IS
	TERMINAL net_5 : ROTATIONAL_V;
	TERMINAL net_6 : ROTATIONAL_V;
	TERMINAL net_4 : ROTATIONAL_V;
	TERMINAL net_3 : ROTATIONAL_V;
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
	QUANTITY Q_11 : real := 0.0;
	QUANTITY Q_12 : real := 0.0;
	QUANTITY Q_13 : real := 0.0;
BEGIN
	gear_simple1 : ENTITY WORK.gear_simple(arch_gear_simple)
		GENERIC MAP ( phi2_0 => 0.0 , phi1_0 => 0.0 , n1_0 => 0.0 )
		PORT MAP ( rot2 => net_3, rot1 => TO_Preta, n2 => Q_8 , n1 => Q_9 , phi2 => Q_10 , phi1 => Q_11 , power_o => Q_12 , power_i => Q_13 , ratio => Def_Ratio );

	idealplanetary5 : ENTITY WORK.idealplanetary(behav)
		GENERIC MAP ( rho => 2.0 , ring_phi0 => 0.0 , carrier_phi0 => 0.0 , sun_phi0 => 0.0 )
		PORT MAP ( ring => rotational_velocity_ref, carrier => net_6, sun => net_3);

	gear_simple2 : ENTITY WORK.gear_simple(arch_gear_simple)
		GENERIC MAP ( phi2_0 => 0.0 , phi1_0 => 0.0 , n1_0 => 0.0 )
		PORT MAP ( rot2 => net_5, rot1 => net_4, n2 => Q_2 , n1 => Q_3 , phi2 => Q_4 , phi1 => Q_5 , power_o => Q_6 , power_i => Q_7 , ratio => -1.0 );

	idealplanetary8 : ENTITY WORK.idealplanetary(behav)
		GENERIC MAP ( rho => 2.0 , ring_phi0 => 0.0 , carrier_phi0 => 0.0 , sun_phi0 => 0.0 )
		PORT MAP ( ring => net_4, carrier => net_6, sun => TO_TireL);

	idealplanetary7 : ENTITY WORK.idealplanetary(behav)
		GENERIC MAP ( rho => 2.0 , ring_phi0 => 0.0 , carrier_phi0 => 0.0 , sun_phi0 => 0.0 )
		PORT MAP ( ring => net_5, carrier => net_6, sun => TO_TireR);

	mass_rot1 : ENTITY WORK.mass_rot(behav)
		GENERIC MAP ( omega0 => 0.0 , phi0 => 0.0 )
		PORT MAP ( rot1 => net_5, j => Inertia );
END ARCHITECTURE struct;
----------------------------------------------------------------------


LIBRARY ieee;
USE ieee.all;

ENTITY DF_PNT IS
	PORT (
		TERMINAL rot_tire2 : ROTATIONAL_V;
		TERMINAL rot_tire1 : ROTATIONAL_V;
		TERMINAL rot_pera : ROTATIONAL_V;
		QUANTITY Diff_Ratio : IN REAL := 0.0;
		QUANTITY Inertia : IN REAL := 0.0 
	);
BEGIN 
END ENTITY DF_PNT;

ARCHITECTURE struct OF DF_PNT IS
	TERMINAL net_161 : ROTATIONAL_V;
	QUANTITY Q_2 : real := 0.0;
BEGIN
	fm_rot2 : ENTITY WORK.fm_rot(behav)
		PORT MAP ( rot2 => net_161, rot1 => rot_pera, torque => Q_2 );

	SubSheet10: ENTITY WORK.Simplorer2(struct)
		PORT MAP ( to_preta => net_161, to_tirer => rot_tire2, to_tirel => rot_tire1, Inertia => Inertia , Def_Ratio => Diff_Ratio );
END ARCHITECTURE struct;
----------------------------------------------------------------------
