--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Gain                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY GAIN IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY KP : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL);
END ENTITY GAIN;
ARCHITECTURE behav OF GAIN IS
BEGIN
	VAL == KP*INPUT'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Negator                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY NEG IS
    GENERIC(TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY NEG;
ARCHITECTURE behav OF NEG IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
	temp_val == -INPUT;
	VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Summation                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY SUM IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY SUM;
ARCHITECTURE behav OF SUM IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT0 + INPUT1;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Limiter                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY LMT IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY UL : IN REAL := 0.0;
          QUANTITY LL : IN REAL := 0.0;
          QUANTITY VAL : OUT REAL);
END ENTITY LMT;
ARCHITECTURE behav OF LMT IS
  QUANTITY temp_val : REAL := 0.0;
  SIGNAL lower_crossing : BOOLEAN := FALSE;
  SIGNAL upper_crossing : BOOLEAN := FALSE;
BEGIN
    ASSERT (UL >= LL) REPORT "Upper Limit should be greater than Lower limit" SEVERITY error;

    lower_crossing <= NOT INPUT'ABOVE(LL);
    upper_crossing <= INPUT'ABOVE(UL);
    BREAK ON lower_crossing;
    BREAK ON upper_crossing;

    IF ((lower_crossing) AND (INPUT < LL)) USE
        temp_val == LL;
    ELSIF ((upper_crossing) AND (INPUT > UL)) USE
        temp_val == UL;
    ELSE
        temp_val == INPUT;
    END USE;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Driver_Model IS
	PORT (
		QUANTITY target_vehicle_speed : IN REAL := 0.0;
		QUANTITY throttle_cont : OUT REAL;
		QUANTITY brake_cont : OUT REAL;
		QUANTITY vehicle_speed : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Driver_Model;

ARCHITECTURE struct OF Driver_Model IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
BEGIN
	gain1 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_9 , kp => 3.6 , input => vehicle_speed );

	neg5 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_8 , input => Q_9 );

	sum13 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , input1 => target_vehicle_speed , input0 => Q_8 );

	lmt3 : ENTITY WORK.lmt(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , ll => -10000.0 , ul => 0.0 , input => Q_4 );

	neg3 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_6 , input => Q_7 );

	gain2 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , kp => 10.0 , input => Q_6 );

	lmt2 : ENTITY WORK.lmt(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , ll => 0.0 , ul => 1000.0 , input => Q_4 );

	gain13 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , kp => 10.0 , input => Q_3 );

	throttle_cont == Q_2;
	brake_cont == Q_5;
END ARCHITECTURE struct;
----------------------------------------------------------------------

