--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Heat Flow Sensor                                         --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.THERMAL_SYSTEMS.ALL;

ENTITY tfm IS
  PORT(
    QUANTITY heat: OUT HEAT_FLOW;
    TERMINAL th1, th2: THERMAL);
END ENTITY tfm;
ARCHITECTURE behav OF tfm IS
  QUANTITY t_zero ACROSS h THROUGH th1 TO th2;
BEGIN
  t_zero == 0.0;
  h == heat;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Thermometer                                              --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.THERMAL_SYSTEMS.ALL;

ENTITY thm IS
  PORT(
    QUANTITY temp: OUT TEMPERATURE;
    TERMINAL th1 : THERMAL);
END ENTITY thm;
ARCHITECTURE behav OF thm IS
  QUANTITY t ACROSS th1 TO thermal_ref;
BEGIN
  t == temp;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Multiplier                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY MUL IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MUL;
ARCHITECTURE behav OF MUL IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
    temp_val == INPUT0*INPUT1;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Power                                                    --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY pow IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY EXP : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL);
END ENTITY pow;
ARCHITECTURE behav OF pow IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT**exp;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Maximum                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY MAX IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MAX;
ARCHITECTURE behav OF MAX IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == REALMAX(INPUT0,INPUT1);
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Negator                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY NEG IS
    GENERIC(TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY NEG;
ARCHITECTURE behav OF NEG IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
	temp_val == -INPUT;
	VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Summation                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY SUM IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY SUM;
ARCHITECTURE behav OF SUM IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT0 + INPUT1;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Sign                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY sign IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY AMPL : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL);
END ENTITY sign;
ARCHITECTURE behav OF sign IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  IF (INPUT >= 0.0) USE
    temp_val == AMPL;
  ELSE
    temp_val == -AMPL;
  END USE;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Reciprocal Value                                         --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY fktres IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY fktres;
ARCHITECTURE behav OF fktres IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  IF (INPUT = 0.0) USE
	temp_val == 0.0;
  ELSE
	temp_val == (1.0/INPUT);
  END USE;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Rth_jurges_mps6 IS
	PORT (
		QUANTITY Rth_mps_out : OUT REAL;
		QUANTITY Flow_V : IN REAL := 0.0;
		QUANTITY Port3 : OUT REAL 
	);
BEGIN 
END ENTITY Rth_jurges_mps6;

ARCHITECTURE struct OF Rth_jurges_mps6 IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
	QUANTITY Q_11 : real := 0.0;
	QUANTITY Q_12 : real := 0.0;
	QUANTITY Q_13 : real := 0.0;
	QUANTITY Q_14 : real := 0.0;
BEGIN
	max2 : ENTITY WORK.max(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_11 , input1 => 1.0e-06 , input0 => Flow_V );

	neg1 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_12 , input => 5.0 );

	pow1 : ENTITY WORK.pow(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_14 , exp => 0.78 , input => Q_11 );

	HTC2_Jurges : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_9 , input1 => 7.1 , input0 => Q_14 );

	mul3 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_13 , input1 => Q_11 , input0 => 3.94 );

	HTC1_Jurges : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , input1 => Q_13 , input0 => 5.57 );

	sum2 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_10 , input1 => Q_11 , input0 => Q_12 );

	sign1 : ENTITY WORK.sign(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_8 , ampl => 1.0 , input => Q_10 );

	HTC2_Jurges2 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , input1 => Q_9 , input0 => Q_8 );

	neg2 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_6 , input => Q_8 );

	HTC1_Jurges2 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , input1 => Q_6 , input0 => Q_7 );

	HTC_Jurges_Result : ENTITY WORK.max(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , input1 => Q_4 , input0 => Q_5 );

	Rth_Jurges_Result : ENTITY WORK.fktres(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , input => Q_3 );

	Rth_mps_out == Q_2;
	Port3 == Q_3;
END ARCHITECTURE struct;
----------------------------------------------------------------------


LIBRARY ieee;
USE ieee.all;

ENTITY Rth_Jurges_kmh6 IS
	PORT (
		QUANTITY Rth_kmh_out : OUT REAL;
		QUANTITY Speed_Kmh : IN REAL := 0.0;
		QUANTITY Port3 : OUT REAL 
	);
BEGIN 
END ENTITY Rth_Jurges_kmh6;

ARCHITECTURE struct OF Rth_Jurges_kmh6 IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
	QUANTITY Q_11 : real := 0.0;
	QUANTITY Q_12 : real := 0.0;
	QUANTITY Q_13 : real := 0.0;
	QUANTITY Q_14 : real := 0.0;
	QUANTITY Q_15 : real := 0.0;
BEGIN
	max2 : ENTITY WORK.max(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_15 , input1 => 1.0e-06 , input0 => Speed_Kmh );

	neg1 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_12 , input => 5.0 );

	Car_Speed_mps : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_11 , input1 => 0.277777777777778 , input0 => Q_15 );

	pow1 : ENTITY WORK.pow(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_14 , exp => 0.78 , input => Q_11 );

	HTC2_Jurges : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_9 , input1 => 7.1 , input0 => Q_14 );

	mul3 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_13 , input1 => Q_11 , input0 => 3.94 );

	HTC1_Jurges : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , input1 => Q_13 , input0 => 5.57 );

	sum2 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_10 , input1 => Q_11 , input0 => Q_12 );

	sign1 : ENTITY WORK.sign(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_8 , ampl => 1.0 , input => Q_10 );

	HTC2_Jurges2 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , input1 => Q_9 , input0 => Q_8 );

	neg2 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_6 , input => Q_8 );

	HTC1_Jurges2 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , input1 => Q_6 , input0 => Q_7 );

	HTC_Jurges_Result : ENTITY WORK.max(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , input1 => Q_4 , input0 => Q_5 );

	Rth_Jurges_Result : ENTITY WORK.fktres(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , input => Q_3 );

	Rth_kmh_out == Q_2;
	Port3 == Q_3;
END ARCHITECTURE struct;
----------------------------------------------------------------------

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Memory                                                   --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY MEMORY IS
    GENERIC (Y0 : REAL := 0.0; 
             TS : REAL := 0.0); 
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MEMORY;
ARCHITECTURE sml_behav OF memory IS
--  COMPONENT sml_memory IS
--    PORT(
--      QUANTITY in_val : IN REAL;
--      QUANTITY out_val : OUT REAL);
--  END COMPONENT;

--  ATTRIBUTE sml_output : STRING;
--  ATTRIBUTE sml_output OF sml_memory : COMPONENT IS "VAL => out_val";

--  ATTRIBUTE sml_model : STRING;
--  ATTRIBUTE sml_model OF sml_memory : COMPONENT IS "INTERN  GAIN  GAIN1   ( INPUT:=in_val,KP:=1,TS:=0) ;";
BEGIN
--  mem1 : sml_memory PORT MAP (in_val => input, out_val => val);

-- TF@07/15/12 as long as sml attribute doesn't work
  IF (DOMAIN = QUIESCENT_DOMAIN) USE
    VAL == Y0;
  ELSIF (DOMAIN = TIME_DOMAIN) USE
    IF (NOW < TS) USE
      VAL == Y0;
    ELSE
      VAL == INPUT'DELAYED(TS);
    END USE;
  ELSE
      VAL == INPUT'DELAYED(TS);
  END USE;

END ARCHITECTURE sml_behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////
--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Thermal Resistance                                       --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.THERMAL_SYSTEMS.ALL;

ENTITY rth IS
  PORT(
    QUANTITY k : IN THERMAL_RESISTANCE := 1.0;
    TERMINAL th1, th2 : THERMAL);
END ENTITY rth;
ARCHITECTURE behav OF rth IS
  QUANTITY t ACROSS h THROUGH th1 TO th2;
BEGIN
  t == h*k;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Rth_radiation6 IS
	PORT (
		QUANTITY Port4 : OUT REAL;
		QUANTITY Port3 : OUT REAL;
		QUANTITY Port2 : IN REAL := 0.0;
		QUANTITY Port1 : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Rth_radiation6;

ARCHITECTURE struct OF Rth_radiation6 IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
BEGIN
	sum3 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_9 , input1 => Port1 , input0 => Port2 );

	mul1 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_8 , input1 => 0.5 , input0 => Q_9 );

	max1 : ENTITY WORK.max(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , input1 => 1.0e-06 , input0 => Q_8 );

	pow1 : ENTITY WORK.pow(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_6 , exp => 3.0 , input => Q_7 );

	mul2 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , input1 => 4.0 , input0 => Q_6 );

	mul3 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , input1 => 5.670367e-08 , input0 => Q_5 );

	mul4 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , input1 => 0.837 , input0 => Q_4 );

	fktres1 : ENTITY WORK.fktres(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , input => Q_3 );

	Port3 == Q_2;
	Port4 == Q_3;
END ARCHITECTURE struct;
----------------------------------------------------------------------

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Heat Flow Source                                         --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.THERMAL_SYSTEMS.ALL;
USE IEEE.MECHANICAL_SYSTEMS.ALL;
USE IEEE.MATH_REAL.MATH_2_PI;

ENTITY h IS
  PORT(
    QUANTITY value : IN HEAT_FLOW := 1.0;
    QUANTITY AC_MAG : IN HEAT_FLOW := 1.0e-3;
    QUANTITY AC_PHASE : IN ANGLE := 0.0;
    TERMINAL th1, th2 : thermal);
END ENTITY h;
ARCHITECTURE behav OF h IS
  QUANTITY t ACROSS h_val THROUGH th1 TO th2;
  QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
  IF (domain = quiescent_domain) OR (domain = time_domain) USE
    h_val == value;
  ELSE
    h_val == ac_spec;
  END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Thermal Capacitance                                      --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.THERMAL_SYSTEMS.ALL;

ENTITY cth IS
  PORT(
    QUANTITY c_th : IN THERMAL_CAPACITANCE := 1.0; 
    QUANTITY t0 : IN TEMPERATURE := 0.0;
    TERMINAL th1 : THERMAL);
END ENTITY cth;
ARCHITECTURE behav OF cth IS
  QUANTITY t ACROSS h THROUGH th1 TO thermal_ref;
  QUANTITY h_int : real := t0;
BEGIN
  IF (domain = quiescent_domain) USE
    h_int == t0 * c_th;
    t == t0;
  ELSE
    h_int'dot == h;
    t == h_int / c_th;
  END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY GL_Cabin_PNT1 IS
	PORT (
		TERMINAL QT_Outer : THERMAL;
		TERMINAL QT_Inner : THERMAL;
		QUANTITY Glass_Density : IN REAL := 2700.0;
		QUANTITY Glass_Cp : IN REAL := 840.0;
		QUANTITY Glass_Ramda : IN REAL := 1.0;
		QUANTITY Glass_Thickness : IN REAL := 0.005;
		QUANTITY Glass_Area : IN REAL := 1.137;
		QUANTITY Qin_GlassAbsorp_Wpm : IN REAL := 0.0;
		QUANTITY Qin_CabinInner_Wpm : IN REAL := 0.0;
		QUANTITY T0_init : IN REAL := 0.0;
		QUANTITY Vair_mps : IN REAL := 0.0;
		QUANTITY Vcar_kmh : IN REAL := 0.0 
	);
BEGIN 
END ENTITY GL_Cabin_PNT1;

ARCHITECTURE struct OF GL_Cabin_PNT1 IS
	TERMINAL net_20 : THERMAL;
	TERMINAL net_14 : THERMAL;
	TERMINAL net_27 : THERMAL;
	TERMINAL net_26 : THERMAL;
	TERMINAL net_21 : THERMAL;
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
	QUANTITY Q_11 : real := 0.0;
	QUANTITY Q_12 : real := 0.0;
	QUANTITY Q_13 : real := 0.0;
	QUANTITY Q_14 : real := 0.0;
	QUANTITY Q_15 : real := 0.0;
	QUANTITY Q_16 : real := 0.0;
	QUANTITY Q_17 : real := 0.0;
	QUANTITY Q_18 : real := 0.0;
	QUANTITY Q_19 : real := 0.0;
	QUANTITY Q_20 : real := 0.0;
	QUANTITY Q_21 : real := 0.0;
	QUANTITY Q_22 : real := 0.0;
	QUANTITY Q_23 : real := 0.0;
	QUANTITY Q_24 : real := 0.0;
	QUANTITY Q_25 : real := 0.0;
	QUANTITY Q_26 : real := 0.0;
	QUANTITY Q_27 : real := 0.0;
	QUANTITY Q_28 : real := 0.0;
	QUANTITY Q_29 : real := 0.0;
	QUANTITY Q_30 : real := 0.0;
	QUANTITY Q_31 : real := 0.0;
	QUANTITY Q_32 : real := 0.0;
	QUANTITY Q_33 : real := 0.0;
	QUANTITY Q_34 : real := 0.0;
	QUANTITY Q_35 : real := 0.0;
	CONSTANT Hmin : real := 0.01;
BEGIN
	tfm7 : ENTITY WORK.tfm(behav)
		PORT MAP ( th2 => net_26, th1 => QT_Inner, heat => Q_35 );

	tfm6 : ENTITY WORK.tfm(behav)
		PORT MAP ( th2 => QT_Outer, th1 => net_21, heat => Q_34 );

	thm3 : ENTITY WORK.thm(behav)
		PORT MAP ( th1 => net_27, temp => Q_30 );

	thm1 : ENTITY WORK.thm(behav)
		PORT MAP ( th1 => net_14, temp => Q_33 );

	thm2 : ENTITY WORK.thm(behav)
		PORT MAP ( th1 => net_20, temp => Q_29 );

	thm4 : ENTITY WORK.thm(behav)
		PORT MAP ( th1 => QT_Outer, temp => Q_28 );

	thm5 : ENTITY WORK.thm(behav)
		PORT MAP ( th1 => QT_Inner, temp => Q_22 );

	mul5 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_16 , input1 => Glass_Area , input0 => Qin_CabinInner_Wpm );

	mul4 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_15 , input1 => Glass_Area , input0 => Qin_GlassAbsorp_Wpm );

	mul977 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_14 , input1 => Glass_Thickness , input0 => Glass_Area );

	pow78 : ENTITY WORK.pow(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_8 , exp => -1.0 , input => Glass_Area );

	mul947 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_6 , input1 => 0.5 , input0 => Glass_Thickness );

	Rth_mps: ENTITY WORK.Rth_jurges_mps6(struct)
		PORT MAP ( Rth_mps_out => Q_9 , Flow_V => Vair_mps , Port3 => Q_32 );

	Rth_kmh: ENTITY WORK.Rth_Jurges_kmh6(struct)
		PORT MAP ( Rth_kmh_out => Q_11 , Speed_Kmh => Vcar_kmh , Port3 => Q_31 );

	memory4 : ENTITY WORK.memory(sml_behav)
		GENERIC MAP ( ts => Hmin -- Expression
		, y0 => 273.15 )
		PORT MAP ( val => Q_20 , input => Q_30 );

	memory1 : ENTITY WORK.memory(sml_behav)
		GENERIC MAP ( ts => Hmin -- Expression
		, y0 => 273.15 )
		PORT MAP ( val => Q_26 , input => Q_29 );

	memory2 : ENTITY WORK.memory(sml_behav)
		GENERIC MAP ( ts => Hmin -- Expression
		, y0 => 273.15 )
		PORT MAP ( val => Q_27 , input => Q_28 );

	Rth_rad2: ENTITY WORK.Rth_radiation6(struct)
		PORT MAP ( Port4 => Q_25 , Port3 => Q_24 , Port2 => Q_26 , Port1 => Q_27 );

	mul1 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_23 , input1 => Q_8 , input0 => Q_24 );

	rth4 : ENTITY WORK.rth(behav)
		PORT MAP ( th2 => net_21, th1 => net_20, k => Q_23 );

	memory3 : ENTITY WORK.memory(sml_behav)
		GENERIC MAP ( ts => Hmin -- Expression
		, y0 => 273.15 )
		PORT MAP ( val => Q_21 , input => Q_22 );

	Rth_rad1: ENTITY WORK.Rth_radiation6(struct)
		PORT MAP ( Port4 => Q_19 , Port3 => Q_18 , Port2 => Q_20 , Port1 => Q_21 );

	mul18 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_17 , input1 => Q_8 , input0 => Q_18 );

	rth1 : ENTITY WORK.rth(behav)
		PORT MAP ( th2 => net_27, th1 => net_26, k => Q_17 );

	Cabin_HeatUp : ENTITY WORK.h(behav)
		PORT MAP ( th2 => QT_Inner, th1 => thermal_ref, ac_phase => 0.0 , ac_mag => 0.001 , value => Q_16 );

	Glass_Absorp_HeatUp : ENTITY WORK.h(behav)
		PORT MAP ( th2 => net_14, th1 => thermal_ref, ac_phase => 0.0 , ac_mag => 0.001 , value => Q_15 );

	mul978 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_13 , input1 => Q_14 , input0 => Glass_Density );

	mul948 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_12 , input1 => Q_13 , input0 => Glass_Cp );

	Glass_HeatMass01 : ENTITY WORK.cth(behav)
		PORT MAP ( th1 => net_14, t0 => T0_init , c_th => Q_12 );

	mul3 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_10 , input1 => Q_8 , input0 => Q_11 );

	rth5 : ENTITY WORK.rth(behav)
		PORT MAP ( th2 => net_20, th1 => net_21, k => Q_10 );

	mul2 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , input1 => Q_8 , input0 => Q_9 );

	rth2 : ENTITY WORK.rth(behav)
		PORT MAP ( th2 => net_26, th1 => net_27, k => Q_7 );

	mul974 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , input1 => Q_6 , input0 => Glass_Area );

	pow96 : ENTITY WORK.pow(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , exp => -1.0 , input => Q_5 );

	mul979 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , input1 => Glass_Ramda , input0 => Q_4 );

	pow97 : ENTITY WORK.pow(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , exp => -1.0 , input => Q_3 );

	R2_Glass_ThickHalf : ENTITY WORK.rth(behav)
		PORT MAP ( th2 => net_14, th1 => net_27, k => Q_2 );

	R1_Glass_ThickHalf : ENTITY WORK.rth(behav)
		PORT MAP ( th2 => net_20, th1 => net_14, k => Q_2 );
END ARCHITECTURE struct;
----------------------------------------------------------------------

