--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Limiter                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY LMT IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY UL : IN REAL := 0.0;
          QUANTITY LL : IN REAL := 0.0;
          QUANTITY VAL : OUT REAL);
END ENTITY LMT;
ARCHITECTURE behav OF LMT IS
  QUANTITY temp_val : REAL := 0.0;
  SIGNAL lower_crossing : BOOLEAN := FALSE;
  SIGNAL upper_crossing : BOOLEAN := FALSE;
BEGIN
    ASSERT (UL >= LL) REPORT "Upper Limit should be greater than Lower limit" SEVERITY error;

    lower_crossing <= NOT INPUT'ABOVE(LL);
    upper_crossing <= INPUT'ABOVE(UL);
    BREAK ON lower_crossing;
    BREAK ON upper_crossing;

    IF ((lower_crossing) AND (INPUT < LL)) USE
        temp_val == LL;
    ELSIF ((upper_crossing) AND (INPUT > UL)) USE
        temp_val == UL;
    ELSE
        temp_val == INPUT;
    END USE;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Negator                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY NEG IS
    GENERIC(TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY NEG;
ARCHITECTURE behav OF NEG IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
	temp_val == -INPUT;
	VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Constant                                                 --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.MATH_2_PI;

ENTITY CONST IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY CONST : IN REAL := 1.0;
          QUANTITY AC_MAG : REAL := 1.0e-3;
          QUANTITY AC_PHASE : REAL := 0.0;
          QUANTITY VAL : OUT REAL := 0.0);
END ENTITY CONST;
ARCHITECTURE behav OF CONST IS
    QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
    IF (domain = quiescent_domain) OR (domain = time_domain) USE
		val == const'ZOH(ts);
    ELSE
        val == ac_spec;
    END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Power                                                    --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY pow IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY EXP : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL);
END ENTITY pow;
ARCHITECTURE behav OF pow IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT**exp;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Summation                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY SUM IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY SUM;
ARCHITECTURE behav OF SUM IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT0 + INPUT1;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Gain                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY GAIN IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY KP : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL);
END ENTITY GAIN;
ARCHITECTURE behav OF GAIN IS
BEGIN
	VAL == KP*INPUT'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Derivative                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY DIFF IS
    GENERIC (Y0 : REAL := 0.0;  
             TS : REAL := 0.0); 
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY KD : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL);
END ENTITY DIFF;
ARCHITECTURE behav OF DIFF IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  IF (DOMAIN = QUIESCENT_DOMAIN) USE
    temp_val == Y0;
    VAL == Y0;
  ELSE 
    temp_val == KD * INPUT'DOT;
    VAL == temp_val'ZOH(TS);
  END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Comparator                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY COMP IS
   GENERIC (TS : REAL := 0.0);
   PORT (QUANTITY INPUT : IN REAL := 0.0;
         QUANTITY VAL1 : IN REAL := 1.0;
         QUANTITY VAL2 : IN REAL := -1.0;
         QUANTITY THRES : IN REAL := 0.0;
         QUANTITY VAL : OUT REAL);
END ENTITY COMP;
ARCHITECTURE behav OF COMP IS
  QUANTITY temp_val : REAL := 0.0;
  SIGNAL crossing : BOOLEAN := FALSE;
BEGIN
    crossing <= NOT INPUT'ABOVE(THRES);
    IF (crossing AND (INPUT < THRES)) USE
        temp_val == VAL1;
    ELSE
        temp_val == VAL2;
    END USE;
    BREAK ON crossing;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Cooling_Heating_Switch1 IS
	PORT (
		QUANTITY Out_val : OUT REAL;
		QUANTITY CNTL_Input : IN REAL := 0.0;
		QUANTITY Heating_Input : IN REAL := 0.0;
		QUANTITY Cooling_Input : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Cooling_Heating_Switch1;

ARCHITECTURE struct OF Cooling_Heating_Switch1 IS
	QUANTITY Q_2 : real := 0.0;
BEGIN
	ComparatorBlock : ENTITY WORK.comp(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , thres => 1.0e-16 , val2 => Heating_Input , val1 => Cooling_Input , input => CNTL_Input );

	Out_val == Q_2;
END ARCHITECTURE struct;
----------------------------------------------------------------------

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Absolute Value                                           --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY fktabs IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
         QUANTITY VAL : OUT REAL);
END ENTITY fktabs;
ARCHITECTURE behav OF fktabs IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == abs(INPUT);
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Multiplier                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY MUL IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MUL;
ARCHITECTURE behav OF MUL IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
    temp_val == INPUT0*INPUT1;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Unit Delay                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY UDELAY IS
    GENERIC (TS : REAL := 0.0;
             Y0 : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
        QUANTITY VAL : OUT REAL);
END ENTITY UDELAY;
ARCHITECTURE behav OF UDELAY IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT'DELAYED(TS);

  IF (DOMAIN = QUIESCENT_DOMAIN) USE
     VAL == Y0;
  ELSIF (DOMAIN = TIME_DOMAIN) USE
     IF (NOW < TS) USE
       VAL == Y0;
     ELSE
       VAL == temp_val'ZOH(TS);
     END USE;
  ELSE
     VAL == temp_val'ZOH(TS);
  END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY HVAC_CNT IS
	GENERIC ( Hmin : REAL := 0.01
	);
	PORT (
		QUANTITY Pb_Voltage : IN REAL := 0.0;
		QUANTITY aircon_current : OUT REAL;
		QUANTITY HV_Voltage : IN REAL := 0.0;
		QUANTITY Cool_Heat_Switch : IN REAL := 0.0;
		QUANTITY blower_current : OUT REAL;
		QUANTITY air_con_power : OUT REAL;
		QUANTITY HVAC_Power_W : IN REAL := 0.0;
		QUANTITY Cabin_Temp : IN REAL := 0.0;
		QUANTITY Target_Temp : IN REAL := 0.0 
	);
BEGIN 
END ENTITY HVAC_CNT;

ARCHITECTURE struct OF HVAC_CNT IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
	QUANTITY Q_11 : real := 0.0;
	QUANTITY Q_12 : real := 0.0;
	QUANTITY Q_13 : real := 0.0;
	QUANTITY Q_14 : real := 0.0;
	QUANTITY Q_15 : real := 0.0;
	QUANTITY Q_16 : real := 0.0;
	QUANTITY Q_17 : real := 0.0;
	QUANTITY Q_18 : real := 0.0;
	QUANTITY Q_19 : real := 0.0;
	QUANTITY Q_20 : real := 0.0;
	QUANTITY Q_21 : real := 0.0;
	QUANTITY Q_22 : real := 0.0;
	QUANTITY Q_23 : real := 0.0;
	QUANTITY Q_24 : real := 0.0;
	QUANTITY Q_25 : real := 0.0;
BEGIN
	lmt6 : ENTITY WORK.lmt(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_25 , ll => 330.0 , ul => 10000.0 , input => HV_Voltage );

	neg66 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_24 , input => Cabin_Temp );

	const5 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_20 , ac_phase => 0.0 , ac_mag => 0.001 , const => -500.0 );

	const6 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_19 , ac_phase => 0.0 , ac_mag => 0.001 , const => 500.0 );

	pow2 : ENTITY WORK.pow(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_6 , exp => -1.0 , input => Pb_Voltage );

	pow76 : ENTITY WORK.pow(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_12 , exp => -1.0 , input => Q_25 );

	sum255 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_23 , input1 => Target_Temp , input0 => Q_24 );

	gain1 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_22 , kp => 50.0 , input => Q_23 );

	diff1 : ENTITY WORK.diff(behav)
		GENERIC MAP ( ts => 0.0 , y0 => 0.0 )
		PORT MAP ( val => Q_21 , kd => 2000.0 , input => Q_23 );

	sum256 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_18 , input1 => Q_21 , input0 => Q_22 );

	SubSheet4: ENTITY WORK.Cooling_Heating_Switch1(struct)
		PORT MAP ( Out_val => Q_17 , CNTL_Input => Cool_Heat_Switch , Heating_Input => Q_19 , Cooling_Input => Q_20 );

	gain2 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_16 , kp => Q_17 , input => Q_18 );

	sum258 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_15 , input1 => HVAC_Power_W , input0 => Q_16 );

	lmt5 : ENTITY WORK.lmt(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_13 , ll => 0.0 , ul => HVAC_Power_W , input => Q_15 );

	air_con_power : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_14 , input1 => 0.0 , input0 => Q_13 );

	fktabs3 : ENTITY WORK.fktabs(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_8 , input => Q_13 );

	mul946 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_11 , input1 => Q_8 , input0 => Q_12 );

	udelay1 : ENTITY WORK.udelay(behav)
		GENERIC MAP ( y0 => 0.0 , ts => Hmin -- Expression
		)
		PORT MAP ( val => Q_10 , input => Q_11 );

	neg1 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_9 , input => Q_10 );

	lmt1 : ENTITY WORK.lmt(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , ll => 0.0 , ul => 1000000.0 , input => Q_8 );

	gain3 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , kp => 0.064 , input => Q_7 );

	mul14 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , input1 => Q_5 , input0 => Q_6 );

	udelay2 : ENTITY WORK.udelay(behav)
		GENERIC MAP ( y0 => 0.0 , ts => Hmin -- Expression
		)
		PORT MAP ( val => Q_3 , input => Q_4 );

	neg20 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , input => Q_3 );

	blower_current == Q_2;
	aircon_current == Q_9;
	air_con_power == Q_14;
END ARCHITECTURE struct;
----------------------------------------------------------------------

