--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Heat Flow Sensor                                         --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.THERMAL_SYSTEMS.ALL;

ENTITY tfm IS
  PORT(
    QUANTITY heat: OUT HEAT_FLOW;
    TERMINAL th1, th2: THERMAL);
END ENTITY tfm;
ARCHITECTURE behav OF tfm IS
  QUANTITY t_zero ACROSS h THROUGH th1 TO th2;
BEGIN
  t_zero == 0.0;
  h == heat;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Thermometer                                              --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.THERMAL_SYSTEMS.ALL;

ENTITY thm IS
  PORT(
    QUANTITY temp: OUT TEMPERATURE;
    TERMINAL th1 : THERMAL);
END ENTITY thm;
ARCHITECTURE behav OF thm IS
  QUANTITY t ACROSS th1 TO thermal_ref;
BEGIN
  t == temp;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Thermal Capacitance                                      --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.THERMAL_SYSTEMS.ALL;

ENTITY cth IS
  PORT(
    QUANTITY c_th : IN THERMAL_CAPACITANCE := 1.0; 
    QUANTITY t0 : IN TEMPERATURE := 293.0;
    TERMINAL th1 : THERMAL);
END ENTITY cth;
ARCHITECTURE behav OF cth IS
  QUANTITY t ACROSS h THROUGH th1 TO thermal_ref;
  QUANTITY h_int : real := t0;
BEGIN
  IF (domain = quiescent_domain) USE
    h_int == t0 * c_th;
    t == t0;
  ELSE
    h_int'dot == h;
    t == h_int / c_th;
  END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Constant                                                 --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.MATH_2_PI;

ENTITY CONST IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY CONST : IN REAL := 1.0;
          QUANTITY AC_MAG : REAL := 1.0e-3;
          QUANTITY AC_PHASE : REAL := 0.0;
          QUANTITY VAL : OUT REAL := 0.0);
END ENTITY CONST;
ARCHITECTURE behav OF CONST IS
    QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
    IF (domain = quiescent_domain) OR (domain = time_domain) USE
		val == const'ZOH(ts);
    ELSE
        val == ac_spec;
    END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Multiplier                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY MUL IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MUL;
ARCHITECTURE behav OF MUL IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
    temp_val == INPUT0*INPUT1;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Summation                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY SUM IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY SUM;
ARCHITECTURE behav OF SUM IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT0 + INPUT1;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Maximum                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY MAX IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MAX;
ARCHITECTURE behav OF MAX IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == REALMAX(INPUT0,INPUT1);
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

-- ----------------------------------------------------------------------------
-- Copyright (C) 2004-2011 VDA/FAT
--
-- This model is a component of the open source library created by the VDA/FAT 
-- working group number 30 and is covered by this license agreement. This model
-- including any updates, modifications, revisions, copies, and documentation
-- are copyrighted works of the VDA/FAT. Use of this model indicates your
-- complete and unconditional acceptance of the terms and conditions set forth
-- in this license agreement.
--  
-- The VDA/FAT grants a non-exclusive license to use, reproduce, modify and
-- distribute this model under the condition, that:
-- (a) no fee or other consideration is charged for any distribution except 
--     compilations distributed in accordance with Section (d) of this license 
--     agreement;
-- (b) the comment text embedded in this model is included verbatim in each
--     copy of this model made or distributed by you, whether or not such
--     version is modified;
-- (c) any modified version must include a conspicuous notice that this model
--     has been modified and the date of modification; and
-- (d) any compilations sold by you that include this model must include a 
--     conspicuous notice that this model is available from the VDA/FAT in 
--     its original form at no charge.
--
-- THIS MODEL IS LICENSED TO YOU "AS IT IS" AND WITH NO WARRANTIES, EXPRESSED
-- OR IMPLIED. THE VDA/FAT AND ALL COMPANIES CONTRIBUTING TO THIS LIBRARY
-- SPECIFICALLY DISCLAIM ALL IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
-- FOR A PARTICULAR PURPOSE. THE VDA/FAT AND ALL COMPANIES ORGANIZED WITHIN
-- MUST NOT HAVE ANY RESPONSIBILITY FOR ANY DAMAGES, FINANCIAL OR LEGAL CLAIMS 
-- WHATEVER.
-- ----------------------------------------------------------------------------

--
-- Author(s):
-- E. Hessel
--
-- Validator:
-- 
--
-- Source:              
-- tlu_2d_vda.vhd
--
-- Development simulator:
-- SystemVision 3.2       
--
-- Tested on:
-- -- ------------------------------------------------------------------------------
-- Version  Simulator    Version   OS       Validator        Date
-- -- ------------------------------------------------------------------------------
-- 1.0      SystemVision 4.1       W2000    E. Hessel        2005/02/02
-- 
--
-- Modification History:
-- -- ------------------------------------------------------------------------------
-- Version    Author   		Date        Description
-- -- ------------------------------------------------------------------------------
-- 1.0        J. Haase          2005/01/20  Original version
--
--
--
--
-- ----------------------------------------------------------------------------
-- $Version: 3.0.0 $
-- $Revision: 2627 $
-- $Date: 2010-12-20 19:11:06 +0100 (Mon, 20 Dec 2010) $
-- $Author: andre $
-- ----------------------------------------------------------------------------
	

--/**
--	
-- TLU Real Quantity Input/Real Quantity Output (Conversion Table from Arrays).
-- <p>Real quantity source controlled by two inputs (real quantity) 
-- via a table (linear interpolation).</p> 
-- <p>Parameters:</p>
-- <pre>
-- 1st array IN1_VALUES: (x1, x2, ..., xn)
-- 2nd array IN2_VALUES: (y1, y2, ..., ym)
-- 3rd array OUT_VALUES: (
-- f(x1,y1),   f(x2,y1),  ...,   f( xn,y1),
-- f(x1,y2),   f(x2,y2),  ...,   f( xn,y2),
-- ... 
-- f(x1,ym),   f(x2,ym),  ...,   f( xn,ym)
-- ).
-- </pre>
-- <p>For more details see the description of the function LOOKUP_2D
-- of the package TLU_VDA.</p>
--
-- @generic   IN1_VALUES	 array with 1st real input values []
-- @generic   IN2_VALUES	 array with 2nd real input values []
-- @generic   OUT_VALUES	 array with corresponding output values []
-- 
-- @port      Q_IN1	 1st quantity input
-- @port      Q_IN2	 2nd quantity input
-- @port      Q_OUT	 quantity output
--	
-- @library   FUNDAMENTALS_VDA 
-- @structure functions/table_look_up/tlu_models/tlu_2d_vda
-- @test      tlu_2d_vda_test
--
--*/					



library FUNDAMENTALS_VDA;
    use FUNDAMENTALS_VDA.TLU_VDA.all;


entity TLU_2D_VDA  is
    generic  (IN1_VALUES  : REAL_VECTOR := (0.0, 1.0);
              IN2_VALUES  : REAL_VECTOR := (0.0, 1.0);
              OUT_VALUES  : REAL_VECTOR := (0.0, 2.5, 1.2, 3.7) -- array with corresponding output values
              );
    port     (quantity Q_IN1 : in  REAL;
              quantity Q_IN2 : in  REAL;
              quantity Q_OUT : out REAL   -- quantity output
	      );
end entity TLU_2D_VDA;

architecture BASIC of TLU_2D_VDA is
    
begin

    Q_OUT == LOOKUP_2D(Q_IN1, Q_IN2, IN1_VALUES, IN2_VALUES, OUT_VALUES);

end architecture BASIC;
-- ----------------------------------------------------------------------------
-- Copyright (C) 2004-2011 VDA/FAT
-- ----------------------------------------------------------------------------


--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Comparator                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY COMP IS
   GENERIC (TS : REAL := 0.0);
   PORT (QUANTITY INPUT : IN REAL := 0.0;
         QUANTITY VAL1 : IN REAL := 1.0;
         QUANTITY VAL2 : IN REAL := -1.0;
         QUANTITY THRES : IN REAL := 0.0;
         QUANTITY VAL : OUT REAL);
END ENTITY COMP;
ARCHITECTURE behav OF COMP IS
  QUANTITY temp_val : REAL := 0.0;
  SIGNAL crossing : BOOLEAN := FALSE;
BEGIN
    crossing <= NOT INPUT'ABOVE(THRES);
    IF (crossing AND (INPUT < THRES)) USE
        temp_val == VAL1;
    ELSE
        temp_val == VAL2;
    END USE;
    BREAK ON crossing;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Cooling_Heating_Switch_a1 IS
	PORT (
		QUANTITY Out_val : OUT REAL;
		QUANTITY CNTL_Input : IN REAL := 0.0;
		QUANTITY Heating_Input : IN REAL := 0.0;
		QUANTITY Cooling_Input : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Cooling_Heating_Switch_a1;

ARCHITECTURE struct OF Cooling_Heating_Switch_a1 IS
	QUANTITY Q_2 : real := 0.0;
BEGIN
	ComparatorBlock : ENTITY WORK.comp(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , thres => 1.0e-16 , val2 => Heating_Input , val1 => Cooling_Input , input => CNTL_Input );

	Out_val == Q_2;
END ARCHITECTURE struct;
----------------------------------------------------------------------

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Heat Flow Source                                         --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.THERMAL_SYSTEMS.ALL;
USE IEEE.MECHANICAL_SYSTEMS.ALL;
USE IEEE.MATH_REAL.MATH_2_PI;

ENTITY h IS
  PORT(
    QUANTITY value : IN HEAT_FLOW := 1.0;
    QUANTITY AC_MAG : IN HEAT_FLOW := 1.0e-3;
    QUANTITY AC_PHASE : IN ANGLE := 0.0;
    TERMINAL th1, th2 : thermal);
END ENTITY h;
ARCHITECTURE behav OF h IS
  QUANTITY t ACROSS h_val THROUGH th1 TO th2;
  QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
  IF (domain = quiescent_domain) OR (domain = time_domain) USE
    h_val == value;
  ELSE
    h_val == ac_spec;
  END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Cooling_Heating_Switch_b1 IS
	PORT (
		QUANTITY Out_val : OUT REAL;
		QUANTITY CNTL_Input : IN REAL := 0.0;
		QUANTITY Heating_Input : IN REAL := 0.0;
		QUANTITY Cooling_Input : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Cooling_Heating_Switch_b1;

ARCHITECTURE struct OF Cooling_Heating_Switch_b1 IS
	QUANTITY Q_2 : real := 0.0;
BEGIN
	ComparatorBlock : ENTITY WORK.comp(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , thres => 1.0e-16 , val2 => Heating_Input , val1 => Cooling_Input , input => CNTL_Input );

	Out_val == Q_2;
END ARCHITECTURE struct;
----------------------------------------------------------------------


LIBRARY ieee;
USE ieee.all;

ENTITY Cooling_and_Heating_Aircon IS
	PORT (
		TERMINAL Aircon_HeatPower_Output : THERMAL;
		TERMINAL Terminator : THERMAL;
		QUANTITY CNTL_In : IN REAL := 0.0;
		QUANTITY Temp_Refrigerant_Input : IN REAL := 0.0;
		QUANTITY HeaterPower_Input : IN REAL := 0.0;
		QUANTITY Aircon_COP : OUT REAL;
		QUANTITY Aircon_OutletTemp_C : IN REAL := 7.0;
		QUANTITY Outside_AirTemp_C : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Cooling_and_Heating_Aircon;

ARCHITECTURE struct OF Cooling_and_Heating_Aircon IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
	QUANTITY Q_11 : real := 0.0;
BEGIN
	mul2 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_11 , input1 => -1.0 , input0 => Aircon_OutletTemp_C );

	Refrigerant : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , ac_phase => 0.0 , ac_mag => 0.001 , const => 21000.0 );

	Circulating_Water : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , ac_phase => 0.0 , ac_mag => 0.001 , const => 12600.0 );

	sum1 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_10 , input1 => Outside_AirTemp_C , input0 => Q_11 );

	max1 : ENTITY WORK.max(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_9 , input1 => 0.0 , input0 => Q_10 );

	Aircon_MapTable2D : ENTITY WORK.tlu_2d_vda(basic)
		GENERIC MAP ( out_values => ( 2.796,  2.796,  2.891,  2.418,  2.186,  2.186,  2.796,  2.796,  2.891,  2.418,  2.186,  2.186,  1.946,  1.946,  2.125,  1.912,  1.74,  1.74,  2.0,  2.0,  2.142,  1.8, 1.555,  1.555,  2.0,  2.0,  2.142,  1.8,  1.555,  1.555 ), in2_values => ( 300.0,  400.0,  800.0,  1000.0,  1200.0 ), in1_values => ( 10.0,  13.0,  23.0,  33.0,  43.0,  50.0 ))
		PORT MAP ( q_out => Q_8 , q_in2 => HeaterPower_Input , q_in1 => Q_9 );

	mul1 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , input1 => -1.0 , input0 => Q_8 );

	mul554 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_6 , input1 => Q_7 , input0 => HeaterPower_Input );

	SubSheet1: ENTITY WORK.Cooling_Heating_Switch_a1(struct)
		PORT MAP ( Out_val => Q_5 , CNTL_Input => CNTL_In , Heating_Input => HeaterPower_Input , Cooling_Input => Q_6 );

	Heater1 : ENTITY WORK.h(behav)
		PORT MAP ( th2 => Aircon_HeatPower_Output, th1 => Terminator, ac_phase => 0.0 , ac_mag => 0.001 , value => Q_5 );

	SubSheet2: ENTITY WORK.Cooling_Heating_Switch_b1(struct)
		PORT MAP ( Out_val => Q_2 , CNTL_Input => CNTL_In , Heating_Input => Q_3 , Cooling_Input => Q_4 );

	Aircon_HeatMass : ENTITY WORK.cth(behav)
		PORT MAP ( th1 => Aircon_HeatPower_Output, t0 => Temp_Refrigerant_Input , c_th => Q_2 );

	Aircon_COP == Q_8;
END ARCHITECTURE struct;
----------------------------------------------------------------------

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Thermal Resistance                                       --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.THERMAL_SYSTEMS.ALL;

ENTITY rth IS
  PORT(
    QUANTITY k : IN THERMAL_RESISTANCE := 1.0;
    TERMINAL th1, th2 : THERMAL);
END ENTITY rth;
ARCHITECTURE behav OF rth IS
  QUANTITY t ACROSS h THROUGH th1 TO th2;
BEGIN
  t == h*k;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

LIBRARY ieee;
USE ieee.all;

ENTITY Cooling_Heating_Switch IS
	PORT (
		QUANTITY Out_val : OUT REAL;
		QUANTITY CNTL_Input : IN REAL := 0.0;
		QUANTITY Heating_Input : IN REAL := 0.0;
		QUANTITY Cooling_Input : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Cooling_Heating_Switch;

ARCHITECTURE struct OF Cooling_Heating_Switch IS
	QUANTITY Q_2 : real := 0.0;
BEGIN
	ComparatorBlock : ENTITY WORK.comp(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , thres => 1.0e-16 , val2 => Heating_Input , val1 => Cooling_Input , input => CNTL_Input );

	Out_val == Q_2;
END ARCHITECTURE struct;
----------------------------------------------------------------------

LIBRARY ieee;
USE ieee.all;

ENTITY HVAC_PNT IS
	PORT (
	TERMINAL Human_Heat_W : THERMAL ;
	TERMINAL Outlet_HeatLoss : THERMAL ;
	TERMINAL Body_HeatLoss : THERMAL ;
	TERMINAL Room_Temp_K : THERMAL ;
	TERMINAL Glass_HeatLoss : THERMAL ;
	TERMINAL HVAC_Temp_K : THERMAL ;
	TERMINAL Defroster_Temp_K : THERMAL ;
	TERMINAL GlassRR_HeatLoss : THERMAL ;
	QUANTITY Temp_Initial_Refrigerant : IN REAL := 0.0 ;
	QUANTITY Temp_Initial : IN REAL := 0.0 ;
	QUANTITY Recirculated_Rate : IN REAL := 0.0 ;
	QUANTITY HeaterPower_Input : IN REAL := 0.0 ;
	QUANTITY CNTL_AC_Cool_and_Heat : IN REAL := 0.0 ;
	QUANTITY Outside_AirTemp_K : IN REAL := 0.0 ;
	QUANTITY Glass_HeatLoss_W : OUT REAL ;
	QUANTITY GlassRR_HeatLoss_W : OUT REAL ;
	QUANTITY Body_Loss_W : OUT REAL ;
	QUANTITY Outlet_Loss_W : OUT REAL ;
	QUANTITY HVAC_to_Room_W : OUT REAL ;
	QUANTITY HVAC_to_Def_W : OUT REAL ;
	QUANTITY Def_to_Room_W : OUT REAL 
	);
BEGIN 
END ENTITY HVAC_PNT;

ARCHITECTURE struct OF HVAC_PNT IS
	TERMINAL net_7 : THERMAL;
	TERMINAL net_68 : THERMAL;
	TERMINAL net_34 : THERMAL;
	TERMINAL net_73 : THERMAL;
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
	QUANTITY Q_11 : real := 0.0;
	QUANTITY Q_12 : real := 0.0;
	QUANTITY Q_15 : real := 0.0;
	QUANTITY Q_16 : real := 0.0;
	QUANTITY Q_17 : real := 0.0;
	QUANTITY Q_18 : real := 0.0;
	QUANTITY Q_19 : real := 0.0;
	QUANTITY Q_24 : real := 0.0;
	QUANTITY Q_28 : real := 0.0;
	QUANTITY Q_31 : real := 0.0;
BEGIN
	Heat2 : ENTITY WORK.tfm(behav)
		PORT MAP ( th2 => Outlet_HeatLoss, th1 => net_73, heat => Outlet_Loss_W );

	Temp2 : ENTITY WORK.thm(behav)
		PORT MAP ( th1 => HVAC_Temp_K, temp => Q_31 );

	Heat3 : ENTITY WORK.tfm(behav)
		PORT MAP ( th2 => Body_HeatLoss, th1 => Room_Temp_K, heat => Body_Loss_W );

	Cabin_Air : ENTITY WORK.cth(behav)
		PORT MAP ( th1 => Room_Temp_K, t0 => Temp_Initial , c_th => 3172.054365 );

	Temp1 : ENTITY WORK.thm(behav)
		PORT MAP ( th1 => Room_Temp_K, temp => Q_28 );

	Heat5 : ENTITY WORK.tfm(behav)
		PORT MAP ( th2 => net_34, th1 => HVAC_Temp_K, heat => HVAC_to_Room_W );

	Heat1 : ENTITY WORK.tfm(behav)
		PORT MAP ( th2 => Glass_HeatLoss, th1 => Defroster_Temp_K, heat => Glass_HeatLoss_W );

	Aircon_Outlet_temp_C : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_16 , ac_phase => 0.0 , ac_mag => 0.001 , const => 7.0 );

	Aircon_Outlet_temp_C2 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_12 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0225*0.75/(1.0-Q_24) -- Expression
		);

	RecAir_rate : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_24 , input1 => 1.0 , input0 => Recirculated_Rate );

	sum302 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_17 , input1 => -273.15 , input0 => Outside_AirTemp_K );

	Heat4 : ENTITY WORK.tfm(behav)
		PORT MAP ( th2 => GlassRR_HeatLoss, th1 => Room_Temp_K, heat => GlassRR_HeatLoss_W );

	Heat6 : ENTITY WORK.tfm(behav)
		PORT MAP ( th2 => Room_Temp_K, th1 => net_7, heat => Def_to_Room_W );

	Heat8 : ENTITY WORK.tfm(behav)
		PORT MAP ( th2 => net_68, th1 => HVAC_Temp_K, heat => HVAC_to_Def_W );

	Temp4 : ENTITY WORK.thm(behav)
		PORT MAP ( th1 => Defroster_Temp_K, temp => Q_19 );

	const183 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_10 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0165 );

	const189 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_11 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.004 );

	const190 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_8 , ac_phase => 0.0 , ac_mag => 0.001 , const => 1.0e+16 );

	const229 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0165 );

	const231 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0165 );

	const232 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	Human_Heat_W : ENTITY WORK.tfm(behav)
		PORT MAP ( th2 => Human_Heat_W, th1 => Room_Temp_K, heat => Q_18 );

	SubSheet1: ENTITY WORK.Cooling_and_Heating_Aircon(struct)
		PORT MAP ( aircon_heatpower_output => HVAC_Temp_K, terminator => thermal_ref, CNTL_In => CNTL_AC_Cool_and_Heat , Temp_Refrigerant_Input => Temp_Initial_Refrigerant , HeaterPower_Input => HeaterPower_Input , Aircon_COP => Q_15 , Aircon_OutletTemp_C => Q_16 , Outside_AirTemp_C => Q_17 );

	Cabin_Outlet_Rth : ENTITY WORK.rth(behav)
		PORT MAP ( th2 => net_73, th1 => Room_Temp_K, k => Q_12 );

	SubSheet4: ENTITY WORK.Cooling_Heating_Switch(struct)
		PORT MAP ( Out_val => Q_9 , CNTL_Input => CNTL_AC_Cool_and_Heat , Heating_Input => Q_10 , Cooling_Input => Q_11 );

	R_HVAC_VentAirFlow : ENTITY WORK.rth(behav)
		PORT MAP ( th2 => Room_Temp_K, th1 => net_34, k => Q_9 );

	SubSheet2: ENTITY WORK.Cooling_Heating_Switch(struct)
		PORT MAP ( Out_val => Q_6 , CNTL_Input => CNTL_AC_Cool_and_Heat , Heating_Input => Q_7 , Cooling_Input => Q_8 );

	R_HVAC_Defroster : ENTITY WORK.rth(behav)
		PORT MAP ( th2 => Defroster_Temp_K, th1 => net_68, k => Q_6 );

	SubSheet3: ENTITY WORK.Cooling_Heating_Switch(struct)
		PORT MAP ( Out_val => Q_2 , CNTL_Input => CNTL_AC_Cool_and_Heat , Heating_Input => Q_4 , Cooling_Input => Q_5 );

	R_HVAC_DefToRoom : ENTITY WORK.rth(behav)
		PORT MAP ( th2 => net_7, th1 => Defroster_Temp_K, k => Q_2 );
		
END ARCHITECTURE struct;
----------------------------------------------------------------------

