--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Mass                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY mass_rot IS
  GENERIC(
    phi0  : ANGLE := 0.0;
    omega0 : ANGULAR_VELOCITY := 0.0);
  PORT(
        QUANTITY j : MOMENT_INERTIA := 1.0;
        TERMINAL rot1 : ROTATIONAL_V );
END ENTITY mass_rot;
ARCHITECTURE behav of mass_rot IS
  QUANTITY omega ACROSS m THROUGH rot1 TO rotational_v_ref;
  QUANTITY phi : ANGLE;
  QUANTITY acc : ANGULAR_ACCELERATION;
BEGIN
  IF (domain = quiescent_domain) USE
    phi == phi0;
    omega == omega0;
  ELSE
    phi'dot == omega;
    omega'dot == acc;
  END USE;
    m == j*acc;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Voltmeter                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;
                              
ENTITY VM IS
    PORT (QUANTITY V : OUT VOLTAGE;
          TERMINAL p,m : ELECTRICAL);
END ENTITY VM;
ARCHITECTURE behav of VM IS
    QUANTITY vg across p to m;
BEGIN
    V == vg;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Angular Velocity Sensor                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY vm_rot IS
  PORT(
    QUANTITY omega: OUT ANGULAR_VELOCITY; 
    TERMINAL rot1: ROTATIONAL_V);
END ENTITY vm_rot;
ARCHITECTURE behav OF vm_rot IS
  QUANTITY omega_val ACROSS rot1 TO rotational_v_ref;
  QUANTITY phi: ANGLE;
BEGIN
  omega_val == omega;
  omega == phi'dot;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Torque Sensor                                            --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY fm_rot IS
  PORT(
    QUANTITY torque : OUT TORQUE;
    TERMINAL rot1, rot2 : ROTATIONAL_V);
END ENTITY fm_rot;
ARCHITECTURE behav OF fm_rot IS
  QUANTITY omega_zero ACROSS m_val THROUGH rot1 TO rot2;
BEGIN
  m_val == torque;
  omega_zero == 0.0;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Wattmeter                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;
USE IEEE.ENERGY_SYSTEMS.POWER;

ENTITY wm_rot IS
  PORT(
    QUANTITY power : OUT POWER;
    TERMINAL rotv1, rotv2, rotm1, rotm2 : rotational_v);
END ENTITY wm_rot;
ARCHITECTURE behav OF wm_rot IS
  QUANTITY omega_in ACROSS rotv1 TO rotv2;
  QUANTITY omega_zero ACROSS m THROUGH rotm1 TO rotm2;
  QUANTITY phi_in : ANGULAR_VELOCITY;
BEGIN
  omega_zero == 0.0;
  power == m*omega_in;
  omega_in == phi_in'dot;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Torque Source                                            --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;
USE IEEE.MATH_REAL.MATH_2_PI;

ENTITY f_rot IS
  PORT(
    QUANTITY value : TORQUE := 1.0;
    QUANTITY AC_MAG : IN TORQUE := 1.0e-3;
    QUANTITY AC_PHASE : IN ANGLE := 0.0;
    TERMINAL rot1, rot2 : rotational_v);
END ENTITY f_rot;
ARCHITECTURE behav OF f_rot IS
  QUANTITY omega ACROSS m THROUGH rot1 TO rot2;
  QUANTITY phi : ANGLE;
  QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
  IF (domain = quiescent_domain) OR (domain = time_domain) USE
    m == value;
    omega == phi'dot;
  ELSE
    m == ac_spec;
    omega == phi'dot;
  END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Resistor                                                 --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------

LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;

ENTITY R IS
    PORT (QUANTITY R : RESISTANCE := 1.0e+3; 
          TERMINAL p,m  : ELECTRICAL);
END ENTITY R;
ARCHITECTURE behav OF R IS
    QUANTITY v ACROSS i THROUGH p TO m;
BEGIN
    v == i*R;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Capacitor                                                 --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------

LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;

ENTITY C IS
    GENERIC (V0     : VOLTAGE := 0.0;
			 Use_V0 : BOOLEAN := true);
    PORT (QUANTITY C : CAPACITANCE := 1.0e-6; 
          TERMINAL p,m  : ELECTRICAL);
END ENTITY C;
ARCHITECTURE behav OF c IS
    QUANTITY v ACROSS i THROUGH p TO m;
    QUANTITY charge : CHARGE := C*V0;
BEGIN
    IF (domain = quiescent_domain) USE
      if (Use_V0) use
		  charge == C*V0;
          v == V0;
	  else
		  charge == C*v;
    	  i == 0.0;
	  end use;
    ELSE
      charge == C * v ;
      i == charge'dot;
   END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Limiter                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY LMT IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY UL : IN REAL := 0.0;
          QUANTITY LL : IN REAL := 0.0;
          QUANTITY VAL : OUT REAL);
END ENTITY LMT;
ARCHITECTURE behav OF LMT IS
  QUANTITY temp_val : REAL := 0.0;
  SIGNAL lower_crossing : BOOLEAN := FALSE;
  SIGNAL upper_crossing : BOOLEAN := FALSE;
BEGIN
    ASSERT (UL >= LL) REPORT "Upper Limit should be greater than Lower limit" SEVERITY error;

    lower_crossing <= NOT INPUT'ABOVE(LL);
    upper_crossing <= INPUT'ABOVE(UL);
    BREAK ON lower_crossing;
    BREAK ON upper_crossing;

    IF ((lower_crossing) AND (INPUT < LL)) USE
        temp_val == LL;
    ELSIF ((upper_crossing) AND (INPUT > UL)) USE
        temp_val == UL;
    ELSE
        temp_val == INPUT;
    END USE;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Gain                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY GAIN IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY KP : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL);
END ENTITY GAIN;
ARCHITECTURE behav OF GAIN IS
BEGIN
	VAL == KP*INPUT'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Constant                                                 --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.MATH_2_PI;

ENTITY CONST IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY CONST : IN REAL := 1.0;
          QUANTITY AC_MAG : REAL := 1.0e-3;
          QUANTITY AC_PHASE : REAL := 0.0;
          QUANTITY VAL : OUT REAL := 0.0);
END ENTITY CONST;
ARCHITECTURE behav OF CONST IS
    QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
    IF (domain = quiescent_domain) OR (domain = time_domain) USE
		val == const'ZOH(ts);
    ELSE
        val == ac_spec;
    END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Absolute Value                                           --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY fktabs IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
         QUANTITY VAL : OUT REAL);
END ENTITY fktabs;
ARCHITECTURE behav OF fktabs IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == abs(INPUT);
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

-------------   Copyright (C) 2020 Digital Twins Inc.  ----------------------
---------- VHDLAMS MODEL mg2_mot_loss_map---------

library fundamentals_vda;
	use fundamentals_vda.tlu_vda.all;

---------- ENTITY DECLARATION mg2_mot_loss_map ----------
ENTITY	mg2_mot_loss_map IS

generic ( IN_TRQ : real_vector :=(-230.0,-207.0,-200.0,-175.0,-150.0,-125.0,-100.0,-75.0,-50.0,-25.0,0.0,25.0,50.0,75.0,100.0,125.0,150.0,175.0,200.0,207.0,230.0);  -- [Nm]
		  IN_RPM : real_vector :=(0.0,400.0,1000.0,1500.0,2000.0,2500.0,3000.0,3500.0,4000.0,4500.0,5000.0,5500.0,6000.0,6500.0,7000.0,8000.0,9000.0,10000.0,11000.0,12000.0,13500.0); --[rpm]
          OUT_MOTLOSS :real_vector := ( 15.8, 8.1, 7.1, 4.7, 3.2, 2.1, 1.3, 0.8, 0.4,0.1,0.0,0.1, 0.4, 0.8, 1.3, 2.1, 3.2, 4.7, 7.1, 8.1,15.8,  -- [kW]
										17.1, 8.5, 7.4, 4.9, 3.4, 2.2, 1.3, 0.8, 0.4,0.1,0.0,0.1, 0.4, 0.8, 1.3, 2.2, 3.4, 4.9, 7.4, 8.5,17.1,
										17.4, 8.7, 7.5, 5.0, 3.5, 2.3, 1.4, 0.9, 0.5,0.2,0.0,0.2, 0.5, 0.9, 1.4, 2.3, 3.5, 5.0, 7.5, 8.7,17.4,
										17.6, 8.9, 7.7, 5.2, 3.6, 2.4, 1.5, 1.0, 0.6,0.2,0.1,0.2, 0.6, 1.0, 1.5, 2.4, 3.6, 5.2, 7.7, 8.9,17.6,
										17.9, 9.0, 7.8, 5.3, 3.7, 2.5, 1.6, 1.0, 0.6,0.3,0.1,0.3, 0.6, 1.0, 1.6, 2.5, 3.7, 5.3, 7.8, 9.0,17.9,
										18.2, 9.2, 8.0, 5.4, 3.8, 2.6, 1.7, 1.1, 0.7,0.3,0.1,0.3, 0.7, 1.1, 1.7, 2.6, 3.8, 5.4, 8.0, 9.2,18.2,
										12.3, 9.2, 8.2, 5.6, 3.9, 2.7, 1.8, 1.2, 0.7,0.4,0.1,0.4, 0.7, 1.2, 1.8, 2.7, 3.9, 5.6, 8.2, 9.2,12.3,
										10.8, 8.9, 8.3, 6.2, 4.0, 2.9, 1.9, 1.3, 0.8,0.4,0.2,0.4, 0.8, 1.3, 1.9, 2.9, 4.0, 6.2, 8.3, 8.9,10.8,
										14.8,12.2,11.5, 8.7, 5.8, 3.0, 2.1, 1.4, 0.9,0.5,0.2,0.5, 0.9, 1.4, 2.1, 3.0, 5.8, 8.7,11.5,12.2,14.8,
										14.9,12.7,12.0, 9.6, 7.2, 4.8, 2.4, 1.5, 0.8,0.6,0.2,0.6, 0.8, 1.5, 2.4, 4.8, 7.2, 9.6,12.0,12.7,14.9,
										 9.3, 8.2, 7.9, 6.7, 5.4, 4.2, 3.0, 1.8, 0.8,0.8,0.2,0.8, 0.8, 1.8, 3.0, 4.2, 5.4, 6.7, 7.9, 8.2, 9.3,
										24.1,20.9,19.9,16.4,12.9, 9.5, 6.0, 2.5, 0.7,1.7,0.3,1.7, 0.7, 2.5, 6.0, 9.5,12.9,16.4,19.9,20.9,24.1,
										29.8,25.7,24.5,20.1,15.8,11.4, 7.0, 2.6, 1.2,0.7,0.3,0.7, 1.2, 2.6, 7.0,11.4,15.8,20.1,24.5,25.7,29.8,
										15.7,13.9,13.4,11.4, 9.4, 7.4, 5.4, 3.4, 1.4,0.7,0.4,0.7, 1.4, 3.4, 5.4, 7.4, 9.4,11.4,13.4,13.9,15.7,
										24.0,21.1,20.3,17.2,14.1,11.0, 7.9, 4.7, 1.6,0.8,0.4,0.8, 1.6, 4.7, 7.9,11.0,14.1,17.2,20.3,21.1,24.0,
										10.3, 9.3, 9.0, 7.8, 6.7, 5.5, 4.4, 3.3, 2.1,1.0,0.6,1.0, 2.1, 3.3, 4.4, 5.5, 6.7, 7.8, 9.0, 9.3,10.3,
										18.7,16.7,16.1,14.0,11.9, 9.7, 7.6, 5.4, 3.3,1.1,0.7,1.1, 3.3, 5.4, 7.6, 9.7,11.9,14.0,16.1,16.7,18.7,
										26.7,23.8,23.0,19.9,16.8,13.8,10.7, 7.6, 4.5,1.5,0.9,1.5, 4.5, 7.6,10.7,13.8,16.8,19.9,23.0,23.8,26.7,
										36.2,32.3,31.2,27.0,22.8,18.6,14.4,10.3, 6.1,1.9,1.1,1.9, 6.1,10.3,14.4,18.6,22.8,27.0,3.20,32.3,36.2,
										58.5,52.2,50.3,43.4,36.6,29.8,23.0,16.2, 9.3,2.5,1.2,2.5, 9.3,16.2,23.0,29.8,36.6,43.4,50.3,52.2,58.5,
										76.4,68.2,65.8,56.9,48.0,39.1,30.2,21.3,12.4,3.5,1.5,3.5,12.4,21.3,30.2,39.1,48.0,56.9,65.8,68.2,76.4));

port ( quantity q_in_trq :in real := 0.0;    -- [Nm]
       quantity q_in_rpm :in real := 0.0;    -- [rpm]
       quantity q_out_motloss :out real );   -- [kW]

END ENTITY mg2_mot_loss_map;

---------- ARCHITECTURE DECLARATION arch_mg2_mot_loss_map ----------
ARCHITECTURE arch_mg2_mot_loss_map OF mg2_mot_loss_map IS

    -- function that makes a value within bounds 
    function bounds  ( value, lower, upper : real ) return real is
     variable result : real;
    begin
	
	if value > upper then
		result := upper;
    elsif value < lower then
		result := lower;
	else
		result := value;
	end if;

    return result;
    end function bounds;

BEGIN

    q_out_motloss == lookup_2d(bounds(q_in_trq,-230.0,230.0),
							   bounds(q_in_rpm,0.0,13500.0),
							   IN_TRQ,
							   IN_RPM,
							   OUT_MOTLOSS);

END ARCHITECTURE arch_mg2_mot_loss_map;
---------- END VHDLAMS MODEL mg2_mot_loss_map ----------

--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

-------------   Copyright (C) 2020 Digital Twins Inc.  ----------------------
---------- VHDLAMS MODEL mg2_inv_loss_map ----------

library fundamentals_vda;
	use fundamentals_vda.tlu_vda.all;

---------- ENTITY DECLARATION mg2_inv_loss_map ----------
ENTITY	mg2_inv_loss_map IS

generic ( IN_TRQ : real_vector :=(-230.0,-207.0,-200.0,-175.0,-150.0,-125.0,-100.0,-75.0,-50.0,-25.0,0.0,25.0,50.0,75.0,100.0,125.0,150.0,175.0,200.0,207.0,230.0);  -- [Nm]
		  IN_RPM : real_vector :=(0.0,400.0,1000.0,1500.0,2000.0,2500.0,3000.0,3500.0,4000.0,4500.0,5000.0,5500.0,6000.0,6500.0,7000.0,8000.0,9000.0,10000.0,11000.0,12000.0,13500.0); --[rpm]
          OUT_INVLOSS :real_vector := ( 3.58,2.06,1.83,1.32,0.97,0.68,0.47,0.32,0.20,0.08,0.00,0.08,0.20,0.30,0.50,0.70,1.00,1.30,1.80,2.10,3.60,
										3.81,2.13,1.88,1.34,0.99,0.69,0.48,0.33,0.21,0.09,0.00,0.09,0.21,0.30,0.50,0.70,1.00,1.30,1.90,2.10,3.80,
										3.84,2.13,1.88,1.35,0.99,0.69,0.48,0.33,0.21,0.09,0.00,0.09,0.21,0.30,0.50,0.70,1.00,1.40,1.90,2.10,3.80,
										3.86,2.14,1.89,1.35,0.99,0.70,0.48,0.33,0.21,0.09,0.00,0.09,0.21,0.30,0.50,0.70,1.00,1.40,1.90,2.10,3.90,
										3.88,2.15,1.89,1.35,0.99,0.70,0.48,0.33,0.21,0.09,0.00,0.09,0.21,0.30,0.50,0.70,1.00,1.40,1.90,2.20,3.90,
										3.90,2.15,1.90,1.35,0.99,0.70,0.48,0.33,0.21,0.09,0.00,0.09,0.21,0.30,0.50,0.70,1.00,1.40,1.90,2.20,3.90,
										3.90,2.11,1.91,1.36,0.98,0.70,0.49,0.33,0.20,0.09,0.00,0.09,0.20,0.30,0.50,0.70,1.00,1.40,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,0.97,0.71,0.48,0.33,0.21,0.08,0.00,0.08,0.21,0.30,0.50,0.70,1.00,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,0.73,0.50,0.33,0.19,0.10,0.00,0.10,0.19,0.30,0.50,0.70,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,0.57,0.35,0.15,0.13,0.00,0.13,0.15,0.40,0.60,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,0.68,0.42,0.12,0.17,0.00,0.17,0.12,0.40,0.70,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.30,0.58,0.04,0.44,0.00,0.44,0.04,0.60,1.30,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.55,0.25,0.09,0.00,0.09,0.25,0.60,1.40,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.69,0.28,0.10,0.02,0.10,0.28,0.70,1.40,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.92,0.31,0.11,0.03,0.11,0.31,0.90,1.40,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.92,0.35,0.15,0.07,0.15,0.35,0.90,1.40,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.92,0.53,0.16,0.10,0.16,0.53,0.90,1.40,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.92,0.66,0.19,0.13,0.19,0.66,0.90,1.40,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.92,0.78,0.23,0.15,0.23,0.78,0.90,1.40,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.92,1.04,0.28,0.17,0.28,1.04,0.90,1.40,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.92,1.43,0.35,0.20,0.35,1.43,0.90,1.40,1.10,1.40,1.50,1.90,2.10,3.90));

port ( quantity q_in_trq :in real := 0.0;    -- [Nm]
       quantity q_in_rpm :in real := 0.0;    -- [rpm]
       quantity q_out_invloss :out real );   -- [kW]

END ENTITY mg2_inv_loss_map;

---------- ARCHITECTURE DECLARATION arch_mg2_inv_loss_map ----------
ARCHITECTURE arch_mg2_inv_loss_map OF mg2_inv_loss_map IS

    -- function that makes a value within bounds 
    function bounds  ( value, lower, upper : real ) return real is
     variable result : real;
    begin
	
	if value > upper then
		result := upper;
    elsif value < lower then
		result := lower;
	else
		result := value;
	end if;

    return result;
    end function bounds;

BEGIN

    q_out_invloss == lookup_2d(bounds(q_in_trq,-230.0,230.0),
							   bounds(q_in_rpm,0.0,13500.0),
							   IN_TRQ,
							   IN_RPM,
							   OUT_INVLOSS);

END ARCHITECTURE arch_mg2_inv_loss_map;
---------- END VHDLAMS MODEL mg2_inv_loss_map ----------

--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

-------------   Copyright (C) 2020 Digital Twins Inc.  ----------------------

library ieee;
--library fundamentals_vda;
    use ieee.electrical_systems.all;
--    use fundamentals_vda.tlu_vda.all;
	USE IEEE.MATH_REAL.ALL;

ENTITY mg2_power_calc IS
	PORT (
	QUANTITY t : IN real := 0.0;
	QUANTITY n : IN real := 0.0;
	QUANTITY loss : IN real := 0.0;
	QUANTITY loss2 : IN real := 0.0;   
	QUANTITY kinshi_flg : IN real := 0.0;
--	QUANTITY power_out : OUT real;
--	QUANTITY power_base : OUT real;
	QUANTITY power : OUT real);
END ENTITY mg2_power_calc;
ARCHITECTURE behav OF mg2_power_calc IS

BEGIN
	BREAK
		power => 0.0;



	if( kinshi_flg > 0.5) use
		power == 0.0;

	elsif( (n*t) < 0.0 ) use


	power == ((n*t)+((loss+loss2)*1000.0));    

	else


	power == ((n*t)+((loss+loss2)*1000.0));    

	end use;

END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Macro3_12 IS
	PORT (
		QUANTITY pmg2 : OUT REAL;
		QUANTITY tmg2 : IN REAL := 0.0;
		QUANTITY nmg2 : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Macro3_12;

ARCHITECTURE struct OF Macro3_12 IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
BEGIN
	lmt1 : ENTITY WORK.lmt(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , ll => -240.0 , ul => 240.0 , input => tmg2 );

	gain1 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_8 , kp => 9.5493046514663 , input => nmg2 );

	kaisei_kinshi_flg : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	fktabs1 : ENTITY WORK.fktabs(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_6 , input => Q_8 );

	mg2_mot_loss_map3 : ENTITY WORK.mg2_mot_loss_map(arch_mg2_mot_loss_map)
		PORT MAP ( q_out_motloss => Q_5 , q_in_rpm => Q_6 , q_in_trq => Q_7 );

	mg2_inv_loss_map1 : ENTITY WORK.mg2_inv_loss_map(arch_mg2_inv_loss_map)
		PORT MAP ( q_out_invloss => Q_4 , q_in_rpm => Q_6 , q_in_trq => Q_7 );

	mg2_power_calc1 : ENTITY WORK.mg2_power_calc(behav)
		PORT MAP ( power => Q_2 , kinshi_flg => Q_3 , loss2 => Q_4 , loss => Q_5 , n => nmg2 , t => tmg2 );

	pmg2 == Q_2;
END ARCHITECTURE struct;
----------------------------------------------------------------------

--///////////////////////////////////////////////////////////////////////////////////////////////////

-------------   Copyright (C) 2020 Digital Twins Inc.  ----------------------

LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;
USE ieee.mechanical_systems.all;
USE IEEE.MATH_REAL.ALL;


ENTITY i_calc1 IS
	GENERIC (
		--MAX_V : real := 280.0;--500.0;
		MAX_V : real := 500.0;--500.0;	LK kido 08.02.22
		MIN_V : real := 1.0;
		LMT_I : real := 100.0);

    PORT(   QUANTITY out_i : out real;
--			QUANTITY current_t : in real;
--			QUANTITY max_v : in real := 500.0;
--			QUANTITY min_v : in real := 1.0;
--			QUANTITY lmt_i : in real := 100.0;
			QUANTITY v_in : in real;
			QUANTITY p_in : in real :=0.0);

END ENTITY i_calc1;
ARCHITECTURE behav OF i_calc1 IS

QUANTITY tmp_i : real ;
QUANTITY tmp_v : real ;

BEGIN
--    BREAK
--	tmp_i => 0.0,
--	out_i => 0.0;

tmp_v == realmin(realmax(v_in, MIN_V), MAX_V);
	if(tmp_v = 0.0) use 
	tmp_i == 0.0 ; 
	else 
	tmp_i == p_in/ tmp_v  ;
 	end use ; 
out_i == realmin(realmax(tmp_i, -LMT_I), LMT_I) ;

--	tmp_v == bound_guard(v_in, MAX_V, MIN_V);
----	p_in == v_in * tmp_i;
--	p_in == tmp_v * tmp_i; 
--	out_i == bound_guard(tmp_i, LMT_I, -LMT_I);

--	if (tmp_i>lmt_i) use
--		out_i == lmt_i * 1.0;
--	elsif (tmp_i<-lmt_i) use
--		out_i == -lmt_i * 1.0;
--	else
--		out_i == tmp_i * 1.0;
-- 	end use;

--	p_in == v_in * out_i;


END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Current Source                                           --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------

LIBRARY IEEE;
USE IEEE.MATH_REAL.MATH_2_PI;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY I IS 
    PORT (QUANTITY I : IN CURRENT := 1.0; 
          QUANTITY AC_MAG : IN CURRENT := 1.0e-3;
          QUANTITY AC_PHASE : IN ANGLE := 0.0;
          TERMINAL p,m: ELECTRICAL);
END ENTITY I;
ARCHITECTURE behav OF I IS
    QUANTITY v ACROSS ic THROUGH p TO m;
    QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
    IF (domain = quiescent_domain) OR (domain = time_domain) USE
	  ic == I;
    ELSE
      ic == ac_spec;
    END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY MG_PNT IS
	PORT (
		TERMINAL Nmg2_t : ROTATIONAL_V;
		TERMINAL nm : ELECTRICAL;
		TERMINAL np : ELECTRICAL;
		QUANTITY TMG2 : IN REAL := 0.0 
	);
BEGIN 
END ENTITY MG_PNT;

ARCHITECTURE struct OF MG_PNT IS
	TERMINAL n0035 : ELECTRICAL;
	TERMINAL n0098 : ROTATIONAL_V;
	TERMINAL net_17 : ROTATIONAL_V;
	TERMINAL n0138 : ROTATIONAL_V;
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
BEGIN
	mass_MG2 : ENTITY WORK.mass_rot(behav)
		GENERIC MAP ( omega0 => 0.0 , phi0 => 0.0 )
		PORT MAP ( rot1 => net_17, j => 0.0234 );

	vm1 : ENTITY WORK.vm(behav)
		PORT MAP ( m => nm, p => N0035, v => Q_4 );

	vm_rot1 : ENTITY WORK.vm_rot(behav)
		PORT MAP ( rot1 => N0138, omega => Q_6 );

	fm_rot1 : ENTITY WORK.fm_rot(behav)
		PORT MAP ( rot2 => N0138, rot1 => N0098, torque => Q_5 );

	wm_rot1 : ENTITY WORK.wm_rot(behav)
		PORT MAP ( rotm2 => net_17, rotm1 => N0138, rotv2 => rotational_velocity_ref, rotv1 => N0138, power => Q_8 );

	fm_rot2 : ENTITY WORK.fm_rot(behav)
		PORT MAP ( rot2 => Nmg2_t, rot1 => net_17, torque => Q_7 );

	f_rot1 : ENTITY WORK.f_rot(behav)
		PORT MAP ( rot2 => N0098, rot1 => rotational_velocity_ref, ac_phase => 0.0 , ac_mag => 0.001 , value => TMG2 );

	r1 : ENTITY WORK.r(behav)
		PORT MAP ( m => nm, p => N0035, r => 100000.0 );

	c1 : ENTITY WORK.c(behav)
		GENERIC MAP ( use_v0 => true , v0 => 0.0 )
		PORT MAP ( m => nm, p => N0035, c => 0.001 );

	r2 : ENTITY WORK.r(behav)
		PORT MAP ( m => N0035, p => np, r => 0.01 );

	PMG2_calculation: ENTITY WORK.Macro3_12(struct)
		PORT MAP ( pmg2 => Q_3 , tmg2 => Q_5 , nmg2 => Q_6 );

	i_calc11 : ENTITY WORK.i_calc1(behav)
		GENERIC MAP ( lmt_i => 150.0 )
		PORT MAP ( p_in => Q_3 , v_in => Q_4 , out_i => Q_2 );

	i2 : ENTITY WORK.i(behav)
		PORT MAP ( m => nm, p => N0035, ac_phase => 0.0 , ac_mag => 0.001 , i => Q_2 );

	c2 : ENTITY WORK.c(behav)
		GENERIC MAP ( use_v0 => false , v0 => 0.0 )
		PORT MAP ( m => nm, p => N0035, c => 0.001 );
END ARCHITECTURE struct;
----------------------------------------------------------------------
