--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Constant                                                 --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.MATH_2_PI;

ENTITY CONST IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY CONST : IN REAL := 1.0;
          QUANTITY AC_MAG : REAL := 1.0e-3;
          QUANTITY AC_PHASE : REAL := 0.0;
          QUANTITY VAL : OUT REAL := 0.0);
END ENTITY CONST;
ARCHITECTURE behav OF CONST IS
    QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
    IF (domain = quiescent_domain) OR (domain = time_domain) USE
		val == const'ZOH(ts);
    ELSE
        val == ac_spec;
    END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Multiplier                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY MUL IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MUL;
ARCHITECTURE behav OF MUL IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
    temp_val == INPUT0*INPUT1;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Summation                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY SUM IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY SUM;
ARCHITECTURE behav OF SUM IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT0 + INPUT1;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Sine                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY FKTSINE IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY fktsine;
ARCHITECTURE behav OF fktsine IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == sin(INPUT);
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Cosine                                                   --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY fktcos IS
      GENERIC (TS : REAL := 0.0); 
      PORT (QUANTITY INPUT : IN REAL;
            QUANTITY VAL : OUT REAL);
END ENTITY fktcos;
ARCHITECTURE behav OF fktcos IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == cos(INPUT);
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Maximum                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY MAX IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MAX;
ARCHITECTURE behav OF MAX IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == REALMAX(INPUT0,INPUT1);
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Reciprocal Value                                         --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY fktres IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY fktres;
ARCHITECTURE behav OF fktres IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  IF (INPUT = 0.0) USE
	temp_val == 0.0;
  ELSE
	temp_val == (1.0/INPUT);
  END USE;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Root                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
-- 6.0.25     | FI  | 05/20/03 | comment out the ASSERT statement that checks if the input is negative in the Root Block
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY rootn IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY ROOT : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL);
END ENTITY rootn;
ARCHITECTURE behav OF rootn IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  ASSERT (ROOT /= 0.0) REPORT "Root cannot be zero" SEVERITY error;
  --ASSERT ((INPUT'ABOVE(0.0)) OR (INPUT >= 0.0)) REPORT "Input to root block cannot be negative" SEVERITY error;
  temp_val == INPUT**(1.0/ROOT);
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Power                                                    --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY pow IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY EXP : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL);
END ENTITY pow;
ARCHITECTURE behav OF pow IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT**exp;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;
USE ieee.math_real.all;

ENTITY Rotation_Matrix IS
	PORT (
		QUANTITY SIN_Ad : OUT REAL;
		QUANTITY COS_Ad : OUT REAL;
		QUANTITY SIN_Beta : OUT REAL;
		QUANTITY COS_Beta : OUT REAL;
		QUANTITY Nzd_normal : IN REAL := 0.0;
		QUANTITY Nyd_normal : IN REAL := 0.0;
		QUANTITY Nxd_normal : IN REAL := 0.0;
		QUANTITY Psai_CarAzimuthAngle_deg : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Rotation_Matrix;

ARCHITECTURE struct OF Rotation_Matrix IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
	QUANTITY Q_11 : real := 0.0;
	QUANTITY Q_12 : real := 0.0;
	QUANTITY Q_13 : real := 0.0;
	QUANTITY Q_14 : real := 0.0;
	QUANTITY Q_15 : real := 0.0;
	QUANTITY Q_16 : real := 0.0;
	QUANTITY Q_17 : real := 0.0;
	QUANTITY Q_18 : real := 0.0;
	QUANTITY Q_19 : real := 0.0;
	QUANTITY Q_20 : real := 0.0;
	QUANTITY Q_21 : real := 0.0;
	QUANTITY Q_22 : real := 0.0;
	QUANTITY Q_23 : real := 0.0;
	QUANTITY Q_24 : real := 0.0;
	QUANTITY Q_25 : real := 0.0;
	QUANTITY Q_26 : real := 0.0;
	QUANTITY Q_27 : real := 0.0;
	QUANTITY Q_28 : real := 0.0;
	QUANTITY Q_29 : real := 0.0;
	QUANTITY Q_30 : real := 0.0;
	QUANTITY Q_31 : real := 0.0;
BEGIN
	mul1 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_31 , input1 => MATH_PI/180.0 -- Expression
		, input0 => Psai_CarAzimuthAngle_deg );

	mul5 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_28 , input1 => Q_2 , input0 => Nyd_normal );

	mul6 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_22 , input1 => 1.0 , input0 => Nzd_normal );

	Omega_Angle : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_30 , input1 => (-MATH_PI) -- Expression
		, input0 => Q_31 );

	SIN_Omega : ENTITY WORK.fktsine(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , input => Q_30 );

	mul3 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_25 , input1 => Q_3 , input0 => Nxd_normal );

	COS_Omega : ENTITY WORK.fktcos(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_26 , input => Q_30 );

	mul2 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_29 , input1 => Q_26 , input0 => Nxd_normal );

	sum2 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_27 , input1 => Q_28 , input0 => Q_29 );

	Nx : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_12 , input1 => 1.0 , input0 => Q_27 );

	mul4 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_24 , input1 => Q_26 , input0 => Nyd_normal );

	sum1 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_23 , input1 => Q_24 , input0 => Q_25 );

	Ny : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_10 , input1 => 1.0 , input0 => Q_23 );

	Nz : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_9 , input1 => 1.0 , input0 => Q_22 );

	max1 : ENTITY WORK.max(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_21 , input1 => 1.0e-16 , input0 => Q_13 );

	Rec_SQRT_Nx2_Ny2_Nz2 : ENTITY WORK.fktres(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_15 , input => Q_21 );

	Nz1 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_20 , input1 => Q_9 , input0 => Q_15 );

	max2 : ENTITY WORK.max(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_16 , input1 => 1.0e-16 , input0 => Q_4 );

	Rec_SQRT_Nx2_Ny2 : ENTITY WORK.fktres(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_18 , input => Q_16 );

	Nz3 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_19 , input1 => Q_18 , input0 => Q_12 );

	Nz4 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_17 , input1 => Q_18 , input0 => Q_10 );

	Nz2 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_14 , input1 => Q_15 , input0 => Q_16 );

	const124 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_13 , ac_phase => 0.0 , ac_mag => 0.001 , const => SQRT(Q_11) );

	pow125 : ENTITY WORK.pow(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_6 , exp => 2.0 , input => Q_12 );

	sum290 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_11 , input1 => Q_5 , input0 => Q_8 );

	pow1 : ENTITY WORK.pow(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , exp => 2.0 , input => Q_10 );

	pow2 : ENTITY WORK.pow(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_8 , exp => 2.0 , input => Q_9 );

	sum305 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , input1 => Q_6 , input0 => Q_7 );

	const123 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , ac_phase => 0.0 , ac_mag => 0.001 , const => SQRT(Q_5) );

	mul1078 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , input1 => -1.0 , input0 => Q_3 );

	SIN_Beta == Q_14;
	SIN_Ad == Q_17;
	COS_Ad == Q_19;
	COS_Beta == Q_20;
END ARCHITECTURE struct;
----------------------------------------------------------------------


LIBRARY ieee;
USE ieee.all;
USE ieee.math_real.all;

ENTITY Solar_Calculation IS
	PORT (
		QUANTITY Solar_JG_Wpm : OUT REAL;
		QUANTITY Solar_JTS_Wpm : OUT REAL;
		QUANTITY Solar_JS_Wpm : OUT REAL;
		QUANTITY Solar_JD_Wpm : OUT REAL;
		QUANTITY COS_Sita_In : IN REAL := 0.0;
		QUANTITY COS_Beta_In : IN REAL := 0.0;
		QUANTITY P_Atm_trans : IN REAL := 0.0;
		QUANTITY Solar_Altitude_h : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Solar_Calculation;

ARCHITECTURE struct OF Solar_Calculation IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
	QUANTITY Q_11 : real := 0.0;
	QUANTITY Q_12 : real := 0.0;
	QUANTITY Q_13 : real := 0.0;
	QUANTITY Q_14 : real := 0.0;
	QUANTITY Q_15 : real := 0.0;
	QUANTITY Q_16 : real := 0.0;
	QUANTITY Q_17 : real := 0.0;
	QUANTITY Q_18 : real := 0.0;
	QUANTITY Q_19 : real := 0.0;
	QUANTITY Q_20 : real := 0.0;
	QUANTITY Q_21 : real := 0.0;
	QUANTITY Q_22 : real := 0.0;
	QUANTITY Q_23 : real := 0.0;
	QUANTITY Q_24 : real := 0.0;
	QUANTITY Q_25 : real := 0.0;
	QUANTITY Q_26 : real := 0.0;
	QUANTITY Q_27 : real := 0.0;
	QUANTITY Q_28 : real := 0.0;
	QUANTITY Q_29 : real := 0.0;
	QUANTITY Q_30 : real := 0.0;
	QUANTITY Q_31 : real := 0.0;
	QUANTITY Q_32 : real := 0.0;
	QUANTITY Q_33 : real := 0.0;
	QUANTITY Q_34 : real := 0.0;
BEGIN
	SolarConst_I0 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_18 , ac_phase => 0.0 , ac_mag => 0.001 , const => 1367.0 );

	mul1 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_34 , input1 => MATH_PI/180.0 -- Expression
		, input0 => Solar_Altitude_h );

	P : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_9 , input1 => 1.0 , input0 => P_Atm_trans );

	sum1 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_30 , input1 => 1.0 , input0 => COS_Beta_In );

	mul11 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_24 , input1 => -1.0 , input0 => COS_Beta_In );

	SIN_h : ENTITY WORK.fktsine(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , input => Q_34 );

	fktres1 : ENTITY WORK.fktres(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_33 , input => Q_4 );

	P_inv_sin_h : ENTITY WORK.pow(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , exp => Q_33 , input => Q_9 );

	mul2 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_32 , input1 => COS_Sita_In , input0 => Q_3 );

	mul3 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_25 , input1 => Q_18 , input0 => Q_32 );

	mul4 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_31 , input1 => Q_10 , input0 => Q_14 );

	mul5 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_29 , input1 => Q_5 , input0 => Q_31 );

	sum3 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_22 , input1 => Q_29 , input0 => Q_2 );

	VF_S : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_28 , input1 => 0.5 , input0 => Q_30 );

	mul13 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_27 , input1 => Q_28 , input0 => Q_29 );

	mul6 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_26 , input1 => Q_18 , input0 => Q_27 );

	sum4 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_16 , input1 => Q_25 , input0 => Q_26 );

	sum2 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_23 , input1 => 1.0 , input0 => Q_24 );

	VF_G : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_21 , input1 => 0.5 , input0 => Q_23 );

	mul7 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_20 , input1 => Q_21 , input0 => Q_22 );

	Reflectivity_of_ground : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_19 , input1 => 0.1 , input0 => Q_20 );

	mul8 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_17 , input1 => Q_18 , input0 => Q_19 );

	sum5 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_15 , input1 => Q_16 , input0 => Q_17 );

	mul1082 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_13 , input1 => -1.0 , input0 => Q_3 );

	mul1097 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_14 , input1 => Q_4 , input0 => Q_12 );

	sum309 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_12 , input1 => 1.0 , input0 => Q_13 );

	mul9 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_11 , input1 => -0.32 , input0 => Q_4 );

	sum6 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_10 , input1 => 0.66 , input0 => Q_11 );

	sum7 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , input1 => 0.4 , input0 => Q_8 );

	mul10 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_8 , input1 => -0.3 , input0 => Q_9 );

	mul1142 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_6 , input1 => Q_4 , input0 => Q_7 );

	sum8 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , input1 => 0.5 , input0 => Q_6 );

	mul1157 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , input1 => Q_3 , input0 => Q_4 );

	Solar_JTS_Wpm == Q_15;
	Solar_JG_Wpm == Q_17;
	Solar_JD_Wpm == Q_25;
	Solar_JS_Wpm == Q_26;
END ARCHITECTURE struct;
----------------------------------------------------------------------

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Memory                                                   --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY MEMORY IS
    GENERIC (Y0 : REAL := 0.0; 
             TS : REAL := 0.0); 
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MEMORY;
ARCHITECTURE sml_behav OF memory IS
--  COMPONENT sml_memory IS
--    PORT(
--      QUANTITY in_val : IN REAL;
--      QUANTITY out_val : OUT REAL);
--  END COMPONENT;

--  ATTRIBUTE sml_output : STRING;
--  ATTRIBUTE sml_output OF sml_memory : COMPONENT IS "VAL => out_val";

--  ATTRIBUTE sml_model : STRING;
--  ATTRIBUTE sml_model OF sml_memory : COMPONENT IS "INTERN  GAIN  GAIN1   ( INPUT:=in_val,KP:=1,TS:=0) ;";
BEGIN
--  mem1 : sml_memory PORT MAP (in_val => input, out_val => val);

-- TF@07/15/12 as long as sml attribute doesn't work
  IF (DOMAIN = QUIESCENT_DOMAIN) USE
    VAL == Y0;
  ELSIF (DOMAIN = TIME_DOMAIN) USE
    IF (NOW < TS) USE
      VAL == Y0;
    ELSE
      VAL == INPUT'DELAYED(TS);
    END USE;
  ELSE
      VAL == INPUT'DELAYED(TS);
  END USE;

END ARCHITECTURE sml_behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Comparator                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY COMP IS
   GENERIC (TS : REAL := 0.0);
   PORT (QUANTITY INPUT : IN REAL := 0.0;
         QUANTITY VAL1 : IN REAL := 1.0;
         QUANTITY VAL2 : IN REAL := -1.0;
         QUANTITY THRES : IN REAL := 0.0;
         QUANTITY VAL : OUT REAL);
END ENTITY COMP;
ARCHITECTURE behav OF COMP IS
  QUANTITY temp_val : REAL := 0.0;
  SIGNAL crossing : BOOLEAN := FALSE;
BEGIN
    crossing <= NOT INPUT'ABOVE(THRES);
    IF (crossing AND (INPUT < THRES)) USE
        temp_val == VAL1;
    ELSE
        temp_val == VAL2;
    END USE;
    BREAK ON crossing;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;
USE ieee.math_real.all;

ENTITY Solar_Module IS
	PORT (
		QUANTITY Solar_absorbed_Wm : OUT REAL;
		QUANTITY Solar_transmission_Wm : OUT REAL;
		QUANTITY Solar_JG_Wm : OUT REAL;
		QUANTITY Solar_JS_Wm : OUT REAL;
		QUANTITY Solar_JD_Wm : OUT REAL;
		QUANTITY Solar_JTS_Wm : OUT REAL;
		QUANTITY OnOff_SolarRadiation : IN REAL := 0.0;
		QUANTITY Solar_absorption_rate : IN REAL := 0.0;
		QUANTITY Solar_transmittance : IN REAL := 0.0;
		QUANTITY Solar_Azimuth_A_deg : IN REAL := 0.0;
		QUANTITY NZ_d : IN REAL := 0.0;
		QUANTITY NY_d : IN REAL := 0.0;
		QUANTITY NX_d : IN REAL := 0.0;
		QUANTITY P_trans : IN REAL := 0.0;
		QUANTITY SolarAltitude_h_deg : IN REAL := 0.0;
		QUANTITY CarAzimuth_Psai_deg : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Solar_Module;

ARCHITECTURE struct OF Solar_Module IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
	QUANTITY Q_11 : real := 0.0;
	QUANTITY Q_12 : real := 0.0;
	QUANTITY Q_13 : real := 0.0;
	QUANTITY Q_14 : real := 0.0;
	QUANTITY Q_15 : real := 0.0;
	QUANTITY Q_16 : real := 0.0;
	QUANTITY Q_17 : real := 0.0;
	QUANTITY Q_18 : real := 0.0;
	QUANTITY Q_19 : real := 0.0;
	QUANTITY Q_20 : real := 0.0;
	QUANTITY Q_21 : real := 0.0;
	QUANTITY Q_22 : real := 0.0;
	QUANTITY Q_23 : real := 0.0;
	QUANTITY Q_24 : real := 0.0;
	QUANTITY Q_25 : real := 0.0;
	QUANTITY Q_26 : real := 0.0;
	QUANTITY Q_27 : real := 0.0;
	QUANTITY Q_28 : real := 0.0;
	QUANTITY Q_29 : real := 0.0;
	QUANTITY Q_30 : real := 0.0;
	QUANTITY Q_31 : real := 0.0;
	QUANTITY Q_32 : real := 0.0;
	QUANTITY Q_33 : real := 0.0;
	QUANTITY Q_34 : real := 0.0;
	QUANTITY Q_35 : real := 0.0;
	QUANTITY Q_36 : real := 0.0;
	CONSTANT Hmin : real := 0.01;
BEGIN
	SubSheet1: ENTITY WORK.Rotation_Matrix(struct)
		PORT MAP ( SIN_Ad => Q_35 , COS_Ad => Q_36 , SIN_Beta => Q_33 , COS_Beta => Q_34 , Nzd_normal => NZ_d , Nyd_normal => NY_d , Nxd_normal => NX_d , Psai_CarAzimuthAngle_deg => CarAzimuth_Psai_deg );

	mul1 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_30 , input1 => MATH_PI/180.0 -- Expression
		, input0 => Solar_Azimuth_A_deg );

	max1 : ENTITY WORK.max(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_12 , input1 => 1.0e-16 , input0 => SolarAltitude_h_deg );

	const93 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_20 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const155 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_15 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	CosAd : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_31 , input1 => 1.0 , input0 => Q_36 );

	SinAd : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_28 , input1 => 1.0 , input0 => Q_35 );

	CosBeta : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_10 , input1 => 1.0 , input0 => Q_34 );

	SinBeta : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , input1 => 1.0 , input0 => Q_33 );

	CosA : ENTITY WORK.fktcos(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_32 , input => Q_30 );

	CosAd2 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_27 , input1 => Q_31 , input0 => Q_32 );

	SinA : ENTITY WORK.fktsine(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_29 , input => Q_30 );

	CosAd1 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_26 , input1 => Q_28 , input0 => Q_29 );

	Cos_A_Ad : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , input1 => Q_26 , input0 => Q_27 );

	max3 : ENTITY WORK.max(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_25 , input1 => 0.0 , input0 => Q_2 );

	SubSheet2: ENTITY WORK.Solar_Calculation(struct)
		PORT MAP ( Solar_JG_Wpm => Q_22 , Solar_JTS_Wpm => Q_17 , Solar_JS_Wpm => Q_23 , Solar_JD_Wpm => Q_24 , COS_Sita_In => Q_25 , COS_Beta_In => Q_10 , P_Atm_trans => P_trans , Solar_Altitude_h => Q_12 );

	mul3 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_21 , input1 => Solar_transmittance , input0 => Q_17 );

	memory4 : ENTITY WORK.memory(sml_behav)
		GENERIC MAP ( ts => Hmin*300.0 -- Expression
		, y0 => 0.0 )
		PORT MAP ( val => Q_19 , input => Q_21 );

	OnOff_Switch1 : ENTITY WORK.comp(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_18 , thres => 1.0e-16 , val2 => Q_19 , val1 => Q_20 , input => OnOff_SolarRadiation );

	mul4 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_16 , input1 => Solar_absorption_rate , input0 => Q_17 );

	memory1 : ENTITY WORK.memory(sml_behav)
		GENERIC MAP ( ts => Hmin*300.0 -- Expression
		, y0 => 0.0 )
		PORT MAP ( val => Q_14 , input => Q_16 );

	OnOff_Switch2 : ENTITY WORK.comp(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_13 , thres => 1.0e-16 , val2 => Q_14 , val1 => Q_15 , input => OnOff_SolarRadiation );

	mul2 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_11 , input1 => MATH_PI/180.0 -- Expression
		, input0 => Q_12 );

	Sin_h : ENTITY WORK.fktsine(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_9 , input => Q_11 );

	Cos_h : ENTITY WORK.fktcos(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_8 , input => Q_11 );

	mul1024 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , input1 => Q_9 , input0 => Q_10 );

	mul1039 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_6 , input1 => Q_7 , input0 => Q_8 );

	mul1054 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , input1 => Q_5 , input0 => Q_6 );

	sum266 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , input1 => Q_3 , input0 => Q_4 );

	Solar_absorbed_Wm == Q_13;
	Solar_JTS_Wm == Q_17;
	Solar_transmission_Wm == Q_18;
	Solar_JG_Wm == Q_22;
	Solar_JS_Wm == Q_23;
	Solar_JD_Wm == Q_24;
END ARCHITECTURE struct;
----------------------------------------------------------------------


LIBRARY ieee;
USE ieee.all;

ENTITY SOLAR_PNT IS
	PORT (
		QUANTITY Out_Wpm_DoorRR_SolarTotal : OUT REAL;
		QUANTITY Out_Wpm_DoorRL_SolarTotal : OUT REAL;
		QUANTITY Out_Wpm_FrameR_SolarTotal : OUT REAL;
		QUANTITY Out_Wpm_FrameL_SolarTotal : OUT REAL;
		QUANTITY Out_Wpm_Roof_SolarTotal : OUT REAL;
		QUANTITY Out_Wpm_BackGate_SolarTotal : OUT REAL;
		QUANTITY Out_Wpm_Floor_SolarTotal : OUT REAL;
		QUANTITY Out_Wpm_DoorFL_SolarTotal : OUT REAL;
		QUANTITY Out_Wpm_DoorFR_SolarTotal : OUT REAL;
		QUANTITY Out_Wpm_GlassRR_SolarAbsorp : OUT REAL;
		QUANTITY Out_Wpm_GlassRR_SolarTrans : OUT REAL;
		QUANTITY Out_Wpm_GlassSideRR_SolarAbsorp : OUT REAL;
		QUANTITY Out_Wpm_GlassSideRR_SolarTrans : OUT REAL;
		QUANTITY Out_Wpm_GlassSideRL_SolarAbsorp : OUT REAL;
		QUANTITY Out_Wpm_GlassSideRL_SolarTrans : OUT REAL;
		QUANTITY Out_Wpm_GlassSideFR_SolarAbsorp : OUT REAL;
		QUANTITY Out_Wpm_GlassSideFR_SolarTrans : OUT REAL;
		QUANTITY Out_Wpm_GlassSideFL_SolarTrans : OUT REAL;
		QUANTITY Out_Wpm_GlassSideFL_SolarAbsorp : OUT REAL;
		QUANTITY Out_Wpm_GlassWS_SolarAbsorp : OUT REAL;
		QUANTITY Out_Wpm_GlassWS_SolarTrans : OUT REAL;
		QUANTITY SolarRadiation_OnOff : IN REAL := 0.0 
	);
BEGIN 
END ENTITY SOLAR_PNT;

ARCHITECTURE struct OF SOLAR_PNT IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
	QUANTITY Q_11 : real := 0.0;
	QUANTITY Q_12 : real := 0.0;
	QUANTITY Q_13 : real := 0.0;
	QUANTITY Q_14 : real := 0.0;
	QUANTITY Q_15 : real := 0.0;
	QUANTITY Q_16 : real := 0.0;
	QUANTITY Q_17 : real := 0.0;
	QUANTITY Q_18 : real := 0.0;
	QUANTITY Q_19 : real := 0.0;
	QUANTITY Q_20 : real := 0.0;
	QUANTITY Q_21 : real := 0.0;
	QUANTITY Q_22 : real := 0.0;
	QUANTITY Q_23 : real := 0.0;
	QUANTITY Q_24 : real := 0.0;
	QUANTITY Q_25 : real := 0.0;
	QUANTITY Q_26 : real := 0.0;
	QUANTITY Q_27 : real := 0.0;
	QUANTITY Q_28 : real := 0.0;
	QUANTITY Q_29 : real := 0.0;
	QUANTITY Q_30 : real := 0.0;
	QUANTITY Q_31 : real := 0.0;
	QUANTITY Q_32 : real := 0.0;
	QUANTITY Q_33 : real := 0.0;
	QUANTITY Q_34 : real := 0.0;
	QUANTITY Q_35 : real := 0.0;
	QUANTITY Q_36 : real := 0.0;
	QUANTITY Q_37 : real := 0.0;
	QUANTITY Q_38 : real := 0.0;
	QUANTITY Q_39 : real := 0.0;
	QUANTITY Q_40 : real := 0.0;
	QUANTITY Q_41 : real := 0.0;
	QUANTITY Q_42 : real := 0.0;
	QUANTITY Q_43 : real := 0.0;
	QUANTITY Q_44 : real := 0.0;
	QUANTITY Q_45 : real := 0.0;
	QUANTITY Q_46 : real := 0.0;
	QUANTITY Q_47 : real := 0.0;
	QUANTITY Q_48 : real := 0.0;
	QUANTITY Q_49 : real := 0.0;
	QUANTITY Q_50 : real := 0.0;
	QUANTITY Q_51 : real := 0.0;
	QUANTITY Q_52 : real := 0.0;
	QUANTITY Q_53 : real := 0.0;
	QUANTITY Q_54 : real := 0.0;
	QUANTITY Q_55 : real := 0.0;
	QUANTITY Q_56 : real := 0.0;
	QUANTITY Q_57 : real := 0.0;
	QUANTITY Q_58 : real := 0.0;
	QUANTITY Q_59 : real := 0.0;
	QUANTITY Q_60 : real := 0.0;
	QUANTITY Q_61 : real := 0.0;
	QUANTITY Q_62 : real := 0.0;
	QUANTITY Q_63 : real := 0.0;
	QUANTITY Q_64 : real := 0.0;
	QUANTITY Q_65 : real := 0.0;
	QUANTITY Q_66 : real := 0.0;
	QUANTITY Q_67 : real := 0.0;
	QUANTITY Q_68 : real := 0.0;
	QUANTITY Q_69 : real := 0.0;
	QUANTITY Q_70 : real := 0.0;
	QUANTITY Q_71 : real := 0.0;
	QUANTITY Q_72 : real := 0.0;
	QUANTITY Q_73 : real := 0.0;
	QUANTITY Q_74 : real := 0.0;
	QUANTITY Q_75 : real := 0.0;
	QUANTITY Q_76 : real := 0.0;
	QUANTITY Q_77 : real := 0.0;
	QUANTITY Q_78 : real := 0.0;
	QUANTITY Q_79 : real := 0.0;
	QUANTITY Q_80 : real := 0.0;
	QUANTITY Q_81 : real := 0.0;
	QUANTITY Q_82 : real := 0.0;
	QUANTITY Q_83 : real := 0.0;
	QUANTITY Q_84 : real := 0.0;
	QUANTITY Q_85 : real := 0.0;
	QUANTITY Q_86 : real := 0.0;
	QUANTITY Q_87 : real := 0.0;
	QUANTITY Q_88 : real := 0.0;
	QUANTITY Q_89 : real := 0.0;
	QUANTITY Q_90 : real := 0.0;
	QUANTITY Q_91 : real := 0.0;
	QUANTITY Q_92 : real := 0.0;
	QUANTITY Q_93 : real := 0.0;
	QUANTITY Q_94 : real := 0.0;
	QUANTITY Q_95 : real := 0.0;
	QUANTITY Q_96 : real := 0.0;
	QUANTITY Q_97 : real := 0.0;
	QUANTITY Q_98 : real := 0.0;
	QUANTITY Q_99 : real := 0.0;
	QUANTITY Q_100 : real := 0.0;
	QUANTITY Q_101 : real := 0.0;
	QUANTITY Q_102 : real := 0.0;
	QUANTITY Q_103 : real := 0.0;
	QUANTITY Q_104 : real := 0.0;
	QUANTITY Q_105 : real := 0.0;
	QUANTITY Q_106 : real := 0.0;
	QUANTITY Q_107 : real := 0.0;
	QUANTITY Q_108 : real := 0.0;
	QUANTITY Q_109 : real := 0.0;
	QUANTITY Q_110 : real := 0.0;
	QUANTITY Q_111 : real := 0.0;
	QUANTITY Q_112 : real := 0.0;
	QUANTITY Q_113 : real := 0.0;
	QUANTITY Q_114 : real := 0.0;
	QUANTITY Q_115 : real := 0.0;
	QUANTITY Q_116 : real := 0.0;
	QUANTITY Q_117 : real := 0.0;
	QUANTITY Q_118 : real := 0.0;
	QUANTITY Q_119 : real := 0.0;
	QUANTITY Q_120 : real := 0.0;
	QUANTITY Q_121 : real := 0.0;
	QUANTITY Q_122 : real := 0.0;
	QUANTITY Q_123 : real := 0.0;
	QUANTITY Q_124 : real := 0.0;
	QUANTITY Q_125 : real := 0.0;
	QUANTITY Q_126 : real := 0.0;
	QUANTITY Q_127 : real := 0.0;
	QUANTITY Q_128 : real := 0.0;
	QUANTITY Q_129 : real := 0.0;
	QUANTITY Q_130 : real := 0.0;
	QUANTITY Q_131 : real := 0.0;
	QUANTITY Q_132 : real := 0.0;
	QUANTITY Q_133 : real := 0.0;
	QUANTITY Q_134 : real := 0.0;
	QUANTITY Q_135 : real := 0.0;
	QUANTITY Q_136 : real := 0.0;
	QUANTITY Q_137 : real := 0.0;
	QUANTITY Q_138 : real := 0.0;
	QUANTITY Q_139 : real := 0.0;
	QUANTITY Q_140 : real := 0.0;
	QUANTITY Q_141 : real := 0.0;
	QUANTITY Q_142 : real := 0.0;
	QUANTITY Q_143 : real := 0.0;
	QUANTITY Q_144 : real := 0.0;
	QUANTITY Q_145 : real := 0.0;
	QUANTITY Q_146 : real := 0.0;
	QUANTITY Q_147 : real := 0.0;
	QUANTITY Q_148 : real := 0.0;
	QUANTITY Q_149 : real := 0.0;
	QUANTITY Q_150 : real := 0.0;
	QUANTITY Q_151 : real := 0.0;
	QUANTITY Q_152 : real := 0.0;
	QUANTITY Q_153 : real := 0.0;
	QUANTITY Q_154 : real := 0.0;
	QUANTITY Q_155 : real := 0.0;
	QUANTITY Q_156 : real := 0.0;
	QUANTITY Q_157 : real := 0.0;
	QUANTITY Q_158 : real := 0.0;
	QUANTITY Q_159 : real := 0.0;
	QUANTITY Q_160 : real := 0.0;
	QUANTITY Q_161 : real := 0.0;
	QUANTITY Q_162 : real := 0.0;
	QUANTITY Q_163 : real := 0.0;
	QUANTITY Q_164 : real := 0.0;
	QUANTITY Q_165 : real := 0.0;
	QUANTITY Q_166 : real := 0.0;
	QUANTITY Q_167 : real := 0.0;
	QUANTITY Q_168 : real := 0.0;
	QUANTITY Q_169 : real := 0.0;
	QUANTITY Q_170 : real := 0.0;
	QUANTITY Q_171 : real := 0.0;
BEGIN
	NXd : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_171 , ac_phase => 0.0 , ac_mag => 0.001 , const => -0.04544 );

	NYd : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_170 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0008511 );

	NZd : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_169 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.08908 );

	const6 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_168 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.53 );

	const1 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_167 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.42 );

	Solar_Altitude_Angle_h : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_16 , ac_phase => 0.0 , ac_mag => 0.001 , const => 63.0 );

	Atmospheric_Transmittance_P : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_15 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.74 );

	Solar_Azimuth_Angle_A : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_11 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	Car_Azimuth_Angle_Psai : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_17 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const2 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_156 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.3 );

	const3 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_157 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.63 );

	NZd1 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_158 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.02436 );

	NYd1 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_159 , ac_phase => 0.0 , ac_mag => 0.001 , const => -0.09685 );

	NXd1 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_160 , ac_phase => 0.0 , ac_mag => 0.001 , const => -0.005231 );

	NXd2 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_149 , ac_phase => 0.0 , ac_mag => 0.001 , const => -0.005108 );

	NYd2 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_148 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.09688 );

	NZd2 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_147 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.02425 );

	const4 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_146 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.63 );

	const5 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_145 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.3 );

	NXd3 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_138 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.001892 );

	NYd3 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_137 , ac_phase => 0.0 , ac_mag => 0.001 , const => -0.09701 );

	NZd3 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_136 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.02419 );

	const7 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_135 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.4 );

	const8 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_134 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.3 );

	NXd4 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_127 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.001891 );

	NYd4 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_126 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.09701 );

	NZd4 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_125 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.02419 );

	const9 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_124 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.4 );

	const10 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_123 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.3 );

	NXd5 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_116 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.07703 );

	NYd5 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_115 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0006664 );

	NZd5 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_114 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.06376 );

	const11 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_113 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.4 );

	const12 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_112 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.3 );

	const13 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_101 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.5 );

	const14 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_102 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	NZd6 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_103 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.09996 );

	NYd6 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_104 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0005014 );

	NXd6 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_105 , ac_phase => 0.0 , ac_mag => 0.001 , const => -0.002874 );

	NXd7 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_94 , ac_phase => 0.0 , ac_mag => 0.001 , const => 1.0 );

	NYd7 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_93 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	NZd7 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_92 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const15 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_91 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const16 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_90 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.5 );

	NXd8 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_83 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	NYd8 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_82 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	NZd8 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_81 , ac_phase => 0.0 , ac_mag => 0.001 , const => -1.0 );

	const17 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_80 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const18 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_79 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.5 );

	NXd9 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_72 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	NYd9 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_71 , ac_phase => 0.0 , ac_mag => 0.001 , const => -1.0 );

	NZd9 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_70 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const19 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_69 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const20 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_68 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.5 );

	NXd10 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_61 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	NYd10 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_60 , ac_phase => 0.0 , ac_mag => 0.001 , const => 1.0 );

	NZd10 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_59 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const21 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_58 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const22 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_57 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.5 );

	NXd11 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_50 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	NYd11 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_49 , ac_phase => 0.0 , ac_mag => 0.001 , const => -1.0 );

	NZd11 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_48 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const23 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_47 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const24 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_46 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.5 );

	NXd12 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_39 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	NYd12 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_38 , ac_phase => 0.0 , ac_mag => 0.001 , const => 1.0 );

	NZd12 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_37 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const25 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_36 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const26 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_35 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.5 );

	NXd16 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_28 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	NYd16 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_27 , ac_phase => 0.0 , ac_mag => 0.001 , const => -1.0 );

	NZd16 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_26 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const33 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_25 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const34 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_24 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.5 );

	NXd17 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_14 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	NYd17 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_13 , ac_phase => 0.0 , ac_mag => 0.001 , const => 1.0 );

	NZd17 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_12 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const35 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_10 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.0 );

	const36 : ENTITY WORK.const(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_9 , ac_phase => 0.0 , ac_mag => 0.001 , const => 0.5 );

	mul43 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_8 , input1 => 1.0 , input0 => SolarRadiation_OnOff );

	SubSheet1: ENTITY WORK.Solar_Module(struct)
		PORT MAP ( Solar_absorbed_Wm => Q_161 , Solar_transmission_Wm => Q_162 , Solar_JG_Wm => Q_163 , Solar_JS_Wm => Q_164 , Solar_JD_Wm => Q_165 , Solar_JTS_Wm => Q_166 , OnOff_SolarRadiation => Q_8 , Solar_absorption_rate => Q_167 , Solar_transmittance => Q_168 , Solar_Azimuth_A_deg => Q_11 , NZ_d => Q_169 , NY_d => Q_170 , NX_d => Q_171 , P_trans => Q_15 , SolarAltitude_h_deg => Q_16 , CarAzimuth_Psai_deg => Q_17 );

	SubSheet2: ENTITY WORK.Solar_Module(struct)
		PORT MAP ( Solar_absorbed_Wm => Q_150 , Solar_transmission_Wm => Q_151 , Solar_JG_Wm => Q_152 , Solar_JS_Wm => Q_153 , Solar_JD_Wm => Q_154 , Solar_JTS_Wm => Q_155 , OnOff_SolarRadiation => Q_8 , Solar_absorption_rate => Q_156 , Solar_transmittance => Q_157 , Solar_Azimuth_A_deg => Q_11 , NZ_d => Q_158 , NY_d => Q_159 , NX_d => Q_160 , P_trans => Q_15 , SolarAltitude_h_deg => Q_16 , CarAzimuth_Psai_deg => Q_17 );

	SubSheet3: ENTITY WORK.Solar_Module(struct)
		PORT MAP ( Solar_absorbed_Wm => Q_139 , Solar_transmission_Wm => Q_140 , Solar_JG_Wm => Q_141 , Solar_JS_Wm => Q_142 , Solar_JD_Wm => Q_143 , Solar_JTS_Wm => Q_144 , OnOff_SolarRadiation => Q_8 , Solar_absorption_rate => Q_145 , Solar_transmittance => Q_146 , Solar_Azimuth_A_deg => Q_11 , NZ_d => Q_147 , NY_d => Q_148 , NX_d => Q_149 , P_trans => Q_15 , SolarAltitude_h_deg => Q_16 , CarAzimuth_Psai_deg => Q_17 );

	SubSheet4: ENTITY WORK.Solar_Module(struct)
		PORT MAP ( Solar_absorbed_Wm => Q_128 , Solar_transmission_Wm => Q_129 , Solar_JG_Wm => Q_130 , Solar_JS_Wm => Q_131 , Solar_JD_Wm => Q_132 , Solar_JTS_Wm => Q_133 , OnOff_SolarRadiation => Q_8 , Solar_absorption_rate => Q_134 , Solar_transmittance => Q_135 , Solar_Azimuth_A_deg => Q_11 , NZ_d => Q_136 , NY_d => Q_137 , NX_d => Q_138 , P_trans => Q_15 , SolarAltitude_h_deg => Q_16 , CarAzimuth_Psai_deg => Q_17 );

	SubSheet5: ENTITY WORK.Solar_Module(struct)
		PORT MAP ( Solar_absorbed_Wm => Q_117 , Solar_transmission_Wm => Q_118 , Solar_JG_Wm => Q_119 , Solar_JS_Wm => Q_120 , Solar_JD_Wm => Q_121 , Solar_JTS_Wm => Q_122 , OnOff_SolarRadiation => Q_8 , Solar_absorption_rate => Q_123 , Solar_transmittance => Q_124 , Solar_Azimuth_A_deg => Q_11 , NZ_d => Q_125 , NY_d => Q_126 , NX_d => Q_127 , P_trans => Q_15 , SolarAltitude_h_deg => Q_16 , CarAzimuth_Psai_deg => Q_17 );

	SubSheet6: ENTITY WORK.Solar_Module(struct)
		PORT MAP ( Solar_absorbed_Wm => Q_106 , Solar_transmission_Wm => Q_107 , Solar_JG_Wm => Q_108 , Solar_JS_Wm => Q_109 , Solar_JD_Wm => Q_110 , Solar_JTS_Wm => Q_111 , OnOff_SolarRadiation => Q_8 , Solar_absorption_rate => Q_112 , Solar_transmittance => Q_113 , Solar_Azimuth_A_deg => Q_11 , NZ_d => Q_114 , NY_d => Q_115 , NX_d => Q_116 , P_trans => Q_15 , SolarAltitude_h_deg => Q_16 , CarAzimuth_Psai_deg => Q_17 );

	SubSheet7: ENTITY WORK.Solar_Module(struct)
		PORT MAP ( Solar_absorbed_Wm => Q_95 , Solar_transmission_Wm => Q_96 , Solar_JG_Wm => Q_97 , Solar_JS_Wm => Q_98 , Solar_JD_Wm => Q_99 , Solar_JTS_Wm => Q_100 , OnOff_SolarRadiation => Q_8 , Solar_absorption_rate => Q_101 , Solar_transmittance => Q_102 , Solar_Azimuth_A_deg => Q_11 , NZ_d => Q_103 , NY_d => Q_104 , NX_d => Q_105 , P_trans => Q_15 , SolarAltitude_h_deg => Q_16 , CarAzimuth_Psai_deg => Q_17 );

	SubSheet8: ENTITY WORK.Solar_Module(struct)
		PORT MAP ( Solar_absorbed_Wm => Q_84 , Solar_transmission_Wm => Q_85 , Solar_JG_Wm => Q_86 , Solar_JS_Wm => Q_87 , Solar_JD_Wm => Q_88 , Solar_JTS_Wm => Q_89 , OnOff_SolarRadiation => Q_8 , Solar_absorption_rate => Q_90 , Solar_transmittance => Q_91 , Solar_Azimuth_A_deg => Q_11 , NZ_d => Q_92 , NY_d => Q_93 , NX_d => Q_94 , P_trans => Q_15 , SolarAltitude_h_deg => Q_16 , CarAzimuth_Psai_deg => Q_17 );

	SubSheet9: ENTITY WORK.Solar_Module(struct)
		PORT MAP ( Solar_absorbed_Wm => Q_73 , Solar_transmission_Wm => Q_74 , Solar_JG_Wm => Q_75 , Solar_JS_Wm => Q_76 , Solar_JD_Wm => Q_77 , Solar_JTS_Wm => Q_78 , OnOff_SolarRadiation => Q_8 , Solar_absorption_rate => Q_79 , Solar_transmittance => Q_80 , Solar_Azimuth_A_deg => Q_11 , NZ_d => Q_81 , NY_d => Q_82 , NX_d => Q_83 , P_trans => Q_15 , SolarAltitude_h_deg => Q_16 , CarAzimuth_Psai_deg => Q_17 );

	SubSheet10: ENTITY WORK.Solar_Module(struct)
		PORT MAP ( Solar_absorbed_Wm => Q_62 , Solar_transmission_Wm => Q_63 , Solar_JG_Wm => Q_64 , Solar_JS_Wm => Q_65 , Solar_JD_Wm => Q_66 , Solar_JTS_Wm => Q_67 , OnOff_SolarRadiation => Q_8 , Solar_absorption_rate => Q_68 , Solar_transmittance => Q_69 , Solar_Azimuth_A_deg => Q_11 , NZ_d => Q_70 , NY_d => Q_71 , NX_d => Q_72 , P_trans => Q_15 , SolarAltitude_h_deg => Q_16 , CarAzimuth_Psai_deg => Q_17 );

	SubSheet11: ENTITY WORK.Solar_Module(struct)
		PORT MAP ( Solar_absorbed_Wm => Q_51 , Solar_transmission_Wm => Q_52 , Solar_JG_Wm => Q_53 , Solar_JS_Wm => Q_54 , Solar_JD_Wm => Q_55 , Solar_JTS_Wm => Q_56 , OnOff_SolarRadiation => Q_8 , Solar_absorption_rate => Q_57 , Solar_transmittance => Q_58 , Solar_Azimuth_A_deg => Q_11 , NZ_d => Q_59 , NY_d => Q_60 , NX_d => Q_61 , P_trans => Q_15 , SolarAltitude_h_deg => Q_16 , CarAzimuth_Psai_deg => Q_17 );

	SubSheet12: ENTITY WORK.Solar_Module(struct)
		PORT MAP ( Solar_absorbed_Wm => Q_40 , Solar_transmission_Wm => Q_41 , Solar_JG_Wm => Q_42 , Solar_JS_Wm => Q_43 , Solar_JD_Wm => Q_44 , Solar_JTS_Wm => Q_45 , OnOff_SolarRadiation => Q_8 , Solar_absorption_rate => Q_46 , Solar_transmittance => Q_47 , Solar_Azimuth_A_deg => Q_11 , NZ_d => Q_48 , NY_d => Q_49 , NX_d => Q_50 , P_trans => Q_15 , SolarAltitude_h_deg => Q_16 , CarAzimuth_Psai_deg => Q_17 );

	SubSheet13: ENTITY WORK.Solar_Module(struct)
		PORT MAP ( Solar_absorbed_Wm => Q_29 , Solar_transmission_Wm => Q_30 , Solar_JG_Wm => Q_31 , Solar_JS_Wm => Q_32 , Solar_JD_Wm => Q_33 , Solar_JTS_Wm => Q_34 , OnOff_SolarRadiation => Q_8 , Solar_absorption_rate => Q_35 , Solar_transmittance => Q_36 , Solar_Azimuth_A_deg => Q_11 , NZ_d => Q_37 , NY_d => Q_38 , NX_d => Q_39 , P_trans => Q_15 , SolarAltitude_h_deg => Q_16 , CarAzimuth_Psai_deg => Q_17 );

	SubSheet17: ENTITY WORK.Solar_Module(struct)
		PORT MAP ( Solar_absorbed_Wm => Q_18 , Solar_transmission_Wm => Q_19 , Solar_JG_Wm => Q_20 , Solar_JS_Wm => Q_21 , Solar_JD_Wm => Q_22 , Solar_JTS_Wm => Q_23 , OnOff_SolarRadiation => Q_8 , Solar_absorption_rate => Q_24 , Solar_transmittance => Q_25 , Solar_Azimuth_A_deg => Q_11 , NZ_d => Q_26 , NY_d => Q_27 , NX_d => Q_28 , P_trans => Q_15 , SolarAltitude_h_deg => Q_16 , CarAzimuth_Psai_deg => Q_17 );

	SubSheet18: ENTITY WORK.Solar_Module(struct)
		PORT MAP ( Solar_absorbed_Wm => Q_2 , Solar_transmission_Wm => Q_3 , Solar_JG_Wm => Q_4 , Solar_JS_Wm => Q_5 , Solar_JD_Wm => Q_6 , Solar_JTS_Wm => Q_7 , OnOff_SolarRadiation => Q_8 , Solar_absorption_rate => Q_9 , Solar_transmittance => Q_10 , Solar_Azimuth_A_deg => Q_11 , NZ_d => Q_12 , NY_d => Q_13 , NX_d => Q_14 , P_trans => Q_15 , SolarAltitude_h_deg => Q_16 , CarAzimuth_Psai_deg => Q_17 );

	Out_Wpm_FrameR_SolarTotal == Q_2;
	Out_Wpm_FrameL_SolarTotal == Q_18;
	Out_Wpm_DoorRR_SolarTotal == Q_29;
	Out_Wpm_DoorRL_SolarTotal == Q_40;
	Out_Wpm_DoorFR_SolarTotal == Q_51;
	Out_Wpm_DoorFL_SolarTotal == Q_62;
	Out_Wpm_Floor_SolarTotal == Q_73;
	Out_Wpm_BackGate_SolarTotal == Q_84;
	Out_Wpm_Roof_SolarTotal == Q_95;
	Out_Wpm_GlassRR_SolarAbsorp == Q_106;
	Out_Wpm_GlassRR_SolarTrans == Q_107;
	Out_Wpm_GlassSideRR_SolarAbsorp == Q_117;
	Out_Wpm_GlassSideRR_SolarTrans == Q_118;
	Out_Wpm_GlassSideRL_SolarAbsorp == Q_128;
	Out_Wpm_GlassSideRL_SolarTrans == Q_129;
	Out_Wpm_GlassSideFR_SolarAbsorp == Q_139;
	Out_Wpm_GlassSideFR_SolarTrans == Q_140;
	Out_Wpm_GlassSideFL_SolarAbsorp == Q_150;
	Out_Wpm_GlassSideFL_SolarTrans == Q_151;
	Out_Wpm_GlassWS_SolarAbsorp == Q_161;
	Out_Wpm_GlassWS_SolarTrans == Q_162;
END ARCHITECTURE struct;
----------------------------------------------------------------------

