--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Damper                                                   --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY damp_rot IS
  PORT(
    QUANTITY damping : IN ANGULAR_DAMPING := 1.0;
    TERMINAL rot1, rot2 : ROTATIONAL_V);
END ENTITY damp_rot;
ARCHITECTURE beha OF damp_rot IS
  QUANTITY omega ACROSS m THROUGH rot1 TO rot2;
  QUANTITY phi : ANGLE;
BEGIN
  m == damping*omega;
  omega == phi'dot;
END ARCHITECTURE beha;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Mass                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY mass_rot IS
  GENERIC(
    phi0  : ANGLE := 0.0;
    omega0 : ANGULAR_VELOCITY := 0.0);
  PORT(
        QUANTITY j : MOMENT_INERTIA := 1.0;
        TERMINAL rot1 : ROTATIONAL_V );
END ENTITY mass_rot;
ARCHITECTURE behav of mass_rot IS
  QUANTITY omega ACROSS m THROUGH rot1 TO rotational_v_ref;
  QUANTITY phi : ANGLE;
  QUANTITY acc : ANGULAR_ACCELERATION;
BEGIN
  IF (domain = quiescent_domain) USE
    phi == phi0;
    omega == omega0;
  ELSE
    phi'dot == omega;
    omega'dot == acc;
  END USE;
    m == j*acc;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

-- ----------------------------------------------------------------------------
-- Copyright (C) 2018 TOYOTA MOTOR CORPORATION
--
-- This model is a component of the open source library created by AK-30, ANSYS, TOYOTA MOTOR CORPORATION 
-- and is covered by this license agreement. This model
-- including any updates, modifications, revisions, copies, and documentation
-- are copyrighted works of the TOYOTA MOTOR CORPORATION. Use of this model indicates your
-- complete and unconditional acceptance of the terms and conditions set forth
-- in this license agreement.
--
-- TOYOTA MOTOR CORPORATION grants a non-exclusive license to use, reproduce, modify and
-- distribute this model under the condition, that:
--
-- (a) no fee or other consideration is charged for any distribution except
--     compilations distributed in accordance with Section (d) of this license
--     agreement;
-- (b) the comment text embedded in this model is included verbatim in each
--     copy of this model made or distributed by you, whether or not such
--     version is modified;
-- (c) any modified version must include a conspicuous notice that this model
--     has been modified and the date of modification; and
-- (d) any compilations sold by you that include this model must include a
--     conspicuous notice that this model is available from the VDA/FAT in
--     its original form at no charge.
--
-- THIS MODEL IS LICENSED TO YOU "AS IT IS" AND WITH NO WARRANTIES, EXPRESSED
-- OR IMPLIED. THE VDA/FAT AND ALL COMPANIES CONTRIBUTING TO THIS LIBRARY
-- SPECIFICALLY DISCLAIM ALL IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
-- FOR A PARTICULAR PURPOSE. THE TOYOTA MOTOR CORPORATION AND ALL COMPANIES ORGANIZED WITHIN
-- MUST NOT HAVE ANY RESPONSIBILITY FOR ANY DAMAGES, FINANCIAL OR LEGAL CLAIMS
-- WHATEVER.
--
----------------------------------------------------------------------------------

library ieee ; 
use ieee.mechanical_systems.all ; 

entity r2f is 

-- generic (
--    r : real := 0.281 ) ; 


 port (
	quantity r: real := 0.281;
	terminal n1 : rotational_v ;
    terminal t1 : translational_v ) ;

begin
    assert r > 0.0
      report "Radius R must be > 0.0"
      severity error;

end entity r2f ;
architecture beh of  r2f is 

	quantity omg across trq through n1 to rotational_v_ref ; 
	quantity v across  frc through  translational_v_ref to t1;  

begin 


	trq == frc * r ; 
    v   == -omg * r ; 

end architecture ;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Torque Sensor                                            --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY fm_rot IS
  PORT(
    QUANTITY torque : OUT TORQUE;
    TERMINAL rot1, rot2 : ROTATIONAL_V);
END ENTITY fm_rot;
ARCHITECTURE behav OF fm_rot IS
  QUANTITY omega_zero ACROSS m_val THROUGH rot1 TO rot2;
BEGIN
  m_val == torque;
  omega_zero == 0.0;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Angular Velocity Sensor                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY vm_rot IS
  PORT(
    QUANTITY omega: OUT ANGULAR_VELOCITY; 
    TERMINAL rot1: ROTATIONAL_V);
END ENTITY vm_rot;
ARCHITECTURE behav OF vm_rot IS
  QUANTITY omega_val ACROSS rot1 TO rotational_v_ref;
  QUANTITY phi: ANGLE;
BEGIN
  omega_val == omega;
  omega == phi'dot;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Force Sensor                                             --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY fm_tr IS
  PORT(
    QUANTITY f : OUT FORCE; 
    TERMINAL tr1, tr2: TRANSLATIONAL_V);
END ENTITY fm_tr;
ARCHITECTURE behav OF fm_tr IS
  QUANTITY v_zero ACROSS f_val THROUGH tr1 TO tr2;
BEGIN
  f_val == f;
  v_zero == 0.0;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Velocity Sensor                                          --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY vm_tr IS
  PORT(
    QUANTITY v : OUT VELOCITY;
    TERMINAL tr1: TRANSLATIONAL_V);
END ENTITY vm_tr;
ARCHITECTURE behav OF vm_tr IS
  QUANTITY v_val ACROSS tr1 TO translational_v_ref;
BEGIN
 v_val == v;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

-------------   Copyright (C) 2020 Digital Twins Inc.  ----------------------
--
-- Modification History:
-- ------------------------------------------------------------------
-- Version  Author            Date           Description
-- ------------------------------------------------------------------

---------- VHDLAMS MODEL rrc ----------

---------- ENTITY DECLARATION rrc ----------




LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

---------- ENTITY DECLARATION ----------
ENTITY	rrc IS

       PORT (
			  QUANTITY CTL    : IN real  := 0.0;
              QUANTITY RRC    : IN real  := 90.0;-- N/(Kg*g)*10-4
              QUANTITY Weight_F : IN real  := 200.0;-- Weight Force
              QUANTITY force_Rolling_Resistance : OUT  Force  ;

 		TERMINAL f1: translational_V
       );

END ENTITY rrc;

---------- ARCHITECTURE DECLARATION arch_rrc ----------
ARCHITECTURE arch_rrc OF rrc IS

  	QUANTITY F_RR: Force ;--Drug Force by RRC [Nm]
	QUANTITY velocity ACROSS force THROUGH f1 TO translational_V_REF;

BEGIN

-- equation start --
--    F_RR == RRC*1.0e-4 * Weight_F * PHYS_GRAVITY;
	F_RR == RRC*1.0e-4 * Weight_F ;
    force_Rolling_Resistance == F_RR;
if CTL >0.0 use
	IF velocity'ABOVE(0.001) USE
	    force == F_RR;
	ELSE
	    force == 0.0;	   
   end use;
	ELSE
	    force == 0.0;
end use;

break on velocity'above(0.0) ; 

END ARCHITECTURE arch_rrc; 
---------- END VHDLAMS MODEL rrc ----------

--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Multiplier                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY MUL IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MUL;
ARCHITECTURE behav OF MUL IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
    temp_val == INPUT0*INPUT1;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY TR_PNT IS
	PORT (
		TERMINAL Frc : TRANSLATIONAL_V;
		TERMINAL Trq : ROTATIONAL_V;
		QUANTITY Radius : IN REAL := 0.281;
		QUANTITY RRC : IN REAL := 0.0;
		QUANTITY SW_load_equation : IN REAL := 0.0;
		QUANTITY tire_power_roll_tire : OUT REAL;
		QUANTITY TireInertia : IN REAL := 0.1;
		QUANTITY Weight : IN REAL := 1.0 
	);
BEGIN 
END ENTITY TR_PNT;

ARCHITECTURE struct OF TR_PNT IS
	TERMINAL net_26 : TRANSLATIONAL_V;
	TERMINAL n0022 : TRANSLATIONAL_V;
	TERMINAL n0048 : ROTATIONAL_V;
	TERMINAL n0041 : ROTATIONAL_V;
	TERMINAL n0013 : TRANSLATIONAL_V;
	TERMINAL net_21 : ROTATIONAL_V;
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
BEGIN
	damp_rot1 : ENTITY WORK.damp_rot(beha)
		PORT MAP ( rot2 => net_21, rot1 => Trq, damping => 10000.0 );

	Inertia_o_Tire : ENTITY WORK.mass_rot(behav)
		GENERIC MAP ( omega0 => 0.0 , phi0 => 0.0 )
		PORT MAP ( rot1 => N0048, j => TireInertia );

	r2f2 : ENTITY WORK.r2f(beh)
		PORT MAP ( t1 => N0013, n1 => N0041, r => Radius );

	fm_rot1 : ENTITY WORK.fm_rot(behav)
		PORT MAP ( rot2 => N0041, rot1 => net_21, torque => Q_10 );

	vm_rot1 : ENTITY WORK.vm_rot(behav)
		PORT MAP ( rot1 => N0041, omega => Q_9 );

	Dive_Force : ENTITY WORK.fm_tr(behav)
		PORT MAP ( tr2 => N0022, tr1 => N0013, f => Q_8 );

	Speed_TireFace : ENTITY WORK.vm_tr(behav)
		PORT MAP ( tr1 => Frc, v => Q_3 );

	Dive_Force1 : ENTITY WORK.fm_tr(behav)
		PORT MAP ( tr2 => Frc, tr1 => N0022, f => Q_7 );

	fm_rot2 : ENTITY WORK.fm_rot(behav)
		PORT MAP ( rot2 => N0048, rot1 => N0041, torque => Q_6 );

	Dive_Force2 : ENTITY WORK.fm_tr(behav)
		PORT MAP ( tr2 => net_26, tr1 => N0022, f => Q_4 );

	rrc4 : ENTITY WORK.rrc(arch_rrc)
		PORT MAP ( f1 => net_26, force_rolling_resistance => Q_5 , weight_f => Weight , rrc => RRC , ctl => SW_load_equation );

	mul1 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , input1 => Q_3 , input0 => Q_4 );

	tire_power_roll_tire == Q_2;
END ARCHITECTURE struct;
----------------------------------------------------------------------

