--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Force Sensor                                             --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY fm_tr IS
  PORT(
    QUANTITY f : OUT FORCE; 
    TERMINAL tr1, tr2: TRANSLATIONAL_V);
END ENTITY fm_tr;
ARCHITECTURE behav OF fm_tr IS
  QUANTITY v_zero ACROSS f_val THROUGH tr1 TO tr2;
BEGIN
  f_val == f;
  v_zero == 0.0;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Velocity Sensor                                          --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY vm_tr IS
  PORT(
    QUANTITY v : OUT VELOCITY;
    TERMINAL tr1: TRANSLATIONAL_V);
END ENTITY vm_tr;
ARCHITECTURE behav OF vm_tr IS
  QUANTITY v_val ACROSS tr1 TO translational_v_ref;
BEGIN
 v_val == v;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Mass                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY mass_tr IS
  GENERIC(
    s0 : DISPLACEMENT := 0.0;
    v0 : VELOCITY := 0.0);
  PORT(
    QUANTITY m : MASS := 1.0;
    TERMINAL tr1 : TRANSLATIONAL_V);
END ENTITY mass_tr;
ARCHITECTURE behav OF mass_tr IS
  QUANTITY v ACROSS f THROUGH tr1 TO translational_v_ref;
  QUANTITY s : DISPLACEMENT;
  QUANTITY acc : ACCELERATION;
BEGIN
  IF (domain = quiescent_domain) USE
    s == s0;
    v == v0;
  ELSE
    s'dot == v;
    v'dot == acc;
  END USE;
    f == m*acc;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

-------------   Copyright (C) 2020 Digital Twins Inc.  ----------------------
------------------------------------------------------------------------------

library ieee ; 
use ieee.mechanical_systems.all ; 
use ieee.fundamental_constants.all ; 

entity weight_distrb is
  port (
	quantity CTL : real:= 0.0 ; --Load Equation SW 1 active
    quantity th : real:= 0.0 ; --slope angle
	quantity h : real := 0.5 ; -- height for gravity center ; 
    quantity WB : real := 1.0 ; -- wheele base length ; 
    quantity WBf : real := 0.5 ; -- distance from g-center (Front wheele)
    quantity WBr : real := 0.5 ; -- distance from g-center (Rear wheele)
    quantity Mass : MASS := 1.0 ; -- vehicle mass 
    quantity Ff, Fr : FORCE ; -- force at vehicle ; 
    quantity Nf, Nr : out real 
    ) ; 
end entity weight_distrb ;
-----------------------
architecture  dyn_distrb of weight_distrb is 
begin 

  ASSERT WB > 0.0
   report "WheeleBase WB must be greater than 0.0"
   severity error ; 

  ASSERT WB = WBf+WBr
   report "WheeleBase WB must be equal WBf+WBr"
   severity error ;

if CTL > 0.0 use
  if (WB = 0.0) use
    Nf == 0.0;
    Nr == 0.0;
  else
    Nf == -h/WB * (Ff-Fr) + WBr/WB *cos(th)* Mass * PHYS_GRAVITY/2.0 ; 
    Nr ==  h/WB * (Ff-Fr) + WBf/WB *cos(th)* Mass * PHYS_GRAVITY/2.0 ;
  end use;
else
Nf == 0.0;
Nr == 0.0;
end use;
  
end architecture dyn_distrb ;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

-------------   Copyright (C) 2020 Digital Twins Inc.  ----------------------

LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;
USE IEEE.ENERGY_SYSTEMS.POWER;

ENTITY resistance_air_00_b IS   
  PORT(
	QUANTITY th   	: IN real := 0.0;
  	QUANTITY CTL  	: IN real := 0.0;
	QUANTITY mass   	: IN mass := 1500.0;
    QUANTITY v_vehicle   : IN VELOCITY := 1.21;
    QUANTITY dens_air    : IN REAL := 1.21;
    QUANTITY c_airresi   : IN REAL    := 0.413;
    QUANTITY squ_project : IN REAL    := 2.606;

    QUANTITY power_air_resi : OUT Power;
    
    TERMINAL tr1 : TRANSLATIONAL_V);

END ENTITY resistance_air_00_b;
ARCHITECTURE behav OF resistance_air_00_b IS

  QUANTITY v ACROSS f THROUGH  tr1 to TRANSLATIONAL_V_REF ;
  QUANTITY s : DISPLACEMENT;

BEGIN

if CTL > 0.0 use
  -- chg. 2007/08/22 : sekisue@ansoft.co.jp
  --f == 0.5*dens_air*c_airresi*squ_project*v_vehicle*v_vehicle;
 f == 0.5*dens_air*c_airresi*squ_project*v_vehicle*v_vehicle+sin(th)*mass*PHYS_GRAVITY;

else 
f==0.0;
end use;
 v == s'dot;
 
  power_air_resi == f * v;
END ARCHITECTURE behav;

--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

-------------   Copyright (C) 2020 Digital Twins Inc.  ----------------------

LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;
USE IEEE.ENERGY_SYSTEMS.POWER;

ENTITY load_vehicle_00_a IS   
  PORT(
	QUANTITY th   	: IN real := 0.0;
	QUANTITY mass   	: IN mass := 1500.0;
    QUANTITY v_vehicle   : IN VELOCITY := 1.21;
    QUANTITY k_v2        : IN REAL    := 0.04279;
    QUANTITY k_v         : IN REAL    := 1.0;
    QUANTITY k_c         : IN REAL    := 199.3;
	QUANTITY CTL         : IN REAL    := 0.0;
    QUANTITY power_load : OUT Power;
    
    TERMINAL tr1 : TRANSLATIONAL_V);

END ENTITY load_vehicle_00_a;
ARCHITECTURE behav OF load_vehicle_00_a IS

  QUANTITY v ACROSS f THROUGH  tr1 to TRANSLATIONAL_V_REF ;
  QUANTITY v_kmph : DISPLACEMENT;
  QUANTITY s : DISPLACEMENT;

BEGIN

 v_kmph == v_vehicle * 3.6;

if CTL = 0.0 use

  if v_vehicle'ABOVE(0.001) use
      f == k_v2*v_kmph**2 + k_v*v_kmph + k_c+ sin(th)*mass*PHYS_GRAVITY;
  else
      f == 0.0;
  end use;

else

f==0.0;
end use;
  v == s'dot;
 
  power_load == f * v_vehicle;

END ARCHITECTURE behav;

--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY VL_PNT IS
	PORT (
		TERMINAL force_tire4 : TRANSLATIONAL_V;
		TERMINAL force_tire3 : TRANSLATIONAL_V;
		TERMINAL force_tire2 : TRANSLATIONAL_V;
		TERMINAL force_tire1 : TRANSLATIONAL_V;
		QUANTITY length_Wheel_Base_rear : IN REAL := 0.0;
		QUANTITY length_Wheel_Base_front : IN REAL := 0.0;
		QUANTITY length_Wheel_Base : IN REAL := 0.0;
		QUANTITY k_c : IN REAL := 0.0;
		QUANTITY k_v : IN REAL := 0.0;
		QUANTITY k_v2 : IN REAL := 0.0;
		QUANTITY SW_load_equation : IN REAL := 0.0;
		QUANTITY Theata : IN REAL := 0.0;
		QUANTITY Vehicle_Velocity : OUT REAL;
		QUANTITY VehicleWeight_tire4 : OUT REAL;
		QUANTITY VehicleWeight_tire3 : OUT REAL;
		QUANTITY VehicleWeight_tire2 : OUT REAL;
		QUANTITY VehicleWeight_tire1 : OUT REAL;
		QUANTITY Projected_Square : IN REAL := 0.0;
		QUANTITY Cd : IN REAL := 0.0;
		QUANTITY air_density : IN REAL := 0.0;
		QUANTITY height_center : IN REAL := 0.0;
		QUANTITY VehicleMass : IN REAL := 0.0 
	);
BEGIN 
END ENTITY VL_PNT;

ARCHITECTURE struct OF VL_PNT IS
	TERMINAL net_37 : TRANSLATIONAL_V;
	TERMINAL n0003 : TRANSLATIONAL_V;
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
	QUANTITY Q_11 : real := 0.0;
BEGIN
	ForceMeter : ENTITY WORK.fm_tr(behav)
		PORT MAP ( tr2 => N0003, tr1 => net_37, f => Q_7 );

	VelocityMeter : ENTITY WORK.vm_tr(behav)
		PORT MAP ( tr1 => net_37, v => Q_3 );

	mass_vehicle : ENTITY WORK.mass_tr(behav)
		GENERIC MAP ( v0 => 0.0 , s0 => 0.0 )
		PORT MAP ( tr1 => N0003, m => VehicleMass );

	fm_tr1 : ENTITY WORK.fm_tr(behav)
		PORT MAP ( tr2 => net_37, tr1 => force_tire1, f => Q_11 );

	fm_tr2 : ENTITY WORK.fm_tr(behav)
		PORT MAP ( tr2 => net_37, tr1 => force_tire2, f => Q_10 );

	fm_tr3 : ENTITY WORK.fm_tr(behav)
		PORT MAP ( tr2 => net_37, tr1 => force_tire3, f => Q_9 );

	fm_tr4 : ENTITY WORK.fm_tr(behav)
		PORT MAP ( tr2 => net_37, tr1 => force_tire4, f => Q_8 );

	weight_distrb1 : ENTITY WORK.weight_distrb(dyn_distrb)
		PORT MAP ( nr => Q_5 , nf => Q_6 , fr => 0.0 , ff => Q_7 , mass => VehicleMass , wbr => length_Wheel_Base_rear , wbf => length_Wheel_Base_front , wb => length_Wheel_Base , h => height_center , th => Theata , ctl => SW_load_equation );

	resistance_air_00_b1 : ENTITY WORK.resistance_air_00_b(behav)
		PORT MAP ( tr1 => net_37, power_air_resi => Q_4 , squ_project => Projected_Square , c_airresi => Cd , dens_air => air_density , v_vehicle => Q_3 , mass => VehicleMass , ctl => SW_load_equation , th => Theata );

	load_vehicle_00_a1 : ENTITY WORK.load_vehicle_00_a(behav)
		PORT MAP ( tr1 => net_37, power_load => Q_2 , ctl => SW_load_equation , k_c => k_c , k_v => k_v , k_v2 => k_v2 , v_vehicle => Q_3 , mass => VehicleMass , th => Theata );

	Vehicle_Velocity == Q_3;
	VehicleWeight_tire4 == Q_5;
	VehicleWeight_tire3 == Q_5;
	VehicleWeight_tire2 == Q_6;
	VehicleWeight_tire1 == Q_6;
END ARCHITECTURE struct;
----------------------------------------------------------------------


